package com.unis.accountability.businessmanagement.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.TaskPageVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.TaskSaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.TaskUpdateVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**粮食安全行政首长责任制----考核指标
 * @Auther:张新亮
 * @Date: 2019/9/18 0018 17:37
 * @Description:
 */
@FeignClient(name = "accountability-service")
@Component
public interface BizRespExaminationTaskClient {

    /**
     * 粮食安全行政首长责任制----考核指标----保存
     */
    @RequestMapping(method = RequestMethod.POST, value = "/examinationTask/save")
    ResponseWrapper save( @RequestBody TaskSaveVO taskSaveVO);



    /**
     * 粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细
     * @param id
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/examinationTask/findById/{id}")
    ResponseWrapper findById(@PathVariable("id") String id);
    /**
     * 粮食安全省长责任制--考核目标任务---根据inputId查询taskid
     * @param inputId
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---编辑", notes = "参数：taskVO")
    @GetMapping(value = "/examinationTask/taskId/{inputId}")
    ResponseWrapper getTaskIdByInputId(
            @PathVariable("inputId") String inputId
    );
    /**
     * 粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细--省市--牵头部门配合部门部门和自评部门专用
     * @param id
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/examinationTask/findByTaskInfo/{id}")
    ResponseWrapper findByTaskInfo(@PathVariable("id") String id);


    /**
     * 考核评分表管理---分页查询粮食安全行政首长责任制----考核指标----分页
     * @param TaskPageVO
     * @param page
     * @param size
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/examinationTask/findByPage/{page}/{size}")
    ResponseWrapper findByPage(@RequestBody TaskPageVO taskPageVO, @PathVariable Integer page, @PathVariable Integer size);





    /**
     * 粮食安全行政首长责任制----考核指标----修改
     */
    @RequestMapping(method = RequestMethod.POST, value = "/examinationTask/update")
    ResponseWrapper update( @RequestBody TaskUpdateVO taskUpdateVO);


    @ApiOperation(value = "粮食安全省长责任制--考核科室分发---编辑", notes = "参数：taskVO")
    @PostMapping(value = "/examinationTask/updateOpinion")
    ResponseWrapper updateOpinion(
            @RequestBody TaskUpdateVO taskUpdateVO
    );
    /**
     * 粮食安全行政首长责任制----考核指标----删除
     */
    @RequestMapping(method = RequestMethod.DELETE, value = "/examinationTask/deletes")
    ResponseWrapper deletes(@RequestBody DeleteVO deleteVO);

    /**
     *  粮食安全省长责任制--考核目标任务---查询可填分数
     * @param
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/examinationTask/findBySorce/{quotaId}/{responsibilityId}/{deptid}")
    ResponseWrapper findBySorce(@PathVariable("quotaId") String quotaId,@PathVariable("responsibilityId") String responsibilityId,@PathVariable("deptid") String deptid);


    @ApiOperation(value = "粮食安全省长责任制--区考核分配---批量发布", notes = "参数：组织名")
    @PostMapping(value = "/examinationTask/publishAll/{orgName}")
    ResponseWrapper publishAll(
            @PathVariable("orgName") String orgName
    );
    
    
    /**
     * 粮食安全省长责任制--考核目标任务---根据填报设置ID查询所有考核任务
     * @param bizRespResponsiBilityId
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细--牵头部门配合部门部门和自评部门专用", notes = "参数：bizRespResponsiBilityId ")
    @GetMapping(value = "/examinationTask/findTaskListByResponsiBilityId/{bizRespResponsiBilityId}")
    public ResponseWrapper findTaskListByResponsiBilityId(
    		@PathVariable("bizRespResponsiBilityId") String  bizRespResponsiBilityId
    		) ;
}