package com.unis.accountability.businessmanagement.client;

import com.unis.accountability.businessmanagement.common.vo.scoringWeight.BizRespScoringWeightPageVO;
import com.unis.accountability.businessmanagement.common.vo.scoringWeight.BizRespScoringWeightPublishVO;
import com.unis.accountability.businessmanagement.common.vo.scoringWeight.WeightSaveVO;
import com.unis.accountability.businessmanagement.common.vo.scoringWeight.WeightUpdateVO;
import com.unis.common.utils.ResponseWrapper;

import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;


/**
 * 粮食安全行政首长责任制-----考核评分权重
 */
@FeignClient(name = "accountability-service")
@Component
public interface BizRespScoringWeightClient {

	/**
	 *  考核评分权重--考核等级设置
	 * @param id
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/scoringWeight/findByWeightRank/{type}/{id}")
	ResponseWrapper findByWeightRank(@PathVariable("type") String type,@PathVariable("id") String id);

	/**
	 *  考核评分权重--考核等级设置
	 * @param type
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/scoringWeight/findByYear/{type}")
	ResponseWrapper findByYear(@PathVariable("type") String type);


	/**
	 * 考核评分权重--查询复制评分表可选年分
	 * @param year
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/scoringWeight/findByCopyYear")
	ResponseWrapper findByCopyYear();


	/**
	 *  考核评分权重--考核等级设置
	 * @param id
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/scoringWeight/findByYearAndStatus/{year}/{status}")
	ResponseWrapper findByYearAndStatus(@PathVariable("year") Integer year,@PathVariable("status") Integer status);

	/**
	 * 核评分权重----保存
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/scoringWeight/save")
	ResponseWrapper save( @RequestBody WeightSaveVO weightSaveVO);

	/**
	 * 核评分权重---修改
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/scoringWeight/update")
	ResponseWrapper update( @RequestBody WeightUpdateVO weightUpdateVO);


	/**
	 * 核评分权重----分页
	 * @param pageVO
	 * @param page
	 * @param size
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/scoringWeight/findByPage/{page}/{size}")
	 ResponseWrapper findByPage(@RequestBody BizRespScoringWeightPageVO pageVO, @PathVariable Integer page, @PathVariable Integer size);

	/**
	 *  考核评分权重--考核等级设置
	 * @param id
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/scoringWeight/findById//{id}")
	ResponseWrapper findById(@PathVariable("id") String id);

	/**
	 * 核评分权重---发布
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/scoringWeight/publish")
	ResponseWrapper publish(@RequestBody BizRespScoringWeightPublishVO publishVO);

	/**
	 * 核评分权重---删除
	 */
	@RequestMapping(method = RequestMethod.DELETE, value = "/scoringWeight/delete")
	ResponseWrapper delete(@RequestBody DeleteVO deleteVO);

}
