package com.unis.accountability.businessmanagement.client;

import com.unis.accountability.businessmanagement.common.vo.examinationTask.BigTaskQueryVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BigTaskVO;
import com.unis.accountability.businessmanagement.common.vo.opinion.BizRespDepartmentalOpinionVO;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @Auther:邹杰利
 * @Date: 2019/9/20
 * @Description:省级牵头部门
 */
@FeignClient(name = "accountability-service")
@Component
public interface ProvinceLeadDeptClient{

    @ApiOperation(value = "盟市长责任制--省级牵头部门--条件分页查询", notes = "参数：")
    @PostMapping(value = "/provinceLeadDept/{pageNum}/{pageSize}")
    ResponseWrapper getProvinceLeadDept(@RequestBody BigTaskQueryVO bigTaskQueryVO,
                                               @PathVariable("pageNum") Integer pageNum,
                                               @PathVariable("pageSize") Integer pageSize);


    @ApiOperation(value = "盟市长责任制--省级牵头部门--根据任务id查询详情", notes = "参数：id")
    @GetMapping(value = "/provinceLeadDept/{id}")
    ResponseWrapper getProvinceLeadDeptDetail(@PathVariable("id") String id);


    @ApiOperation(value = "盟市长责任制--省级牵头部门--更新省级牵头部门评分", notes = "参数：BizRespDepartmentalOpinionVO")
    @PutMapping(value = "/bizRespDepartmentalOpinion")
    ResponseWrapper updateBizRespDepartmentalOpinion(@RequestBody BizRespDepartmentalOpinionVO bizRespDepartmentalOpinionVO);


    @ApiOperation(value = "盟市长责任制--省级牵头部门--根据任务id查询省级配合部门意见", notes = "参数：id")
    @GetMapping(value = "/provinceCoordinateOpinion/{id}/{areaCode}/{coordinateDeptId}")
    ResponseWrapper getProvinceCoordinateOpinion(@PathVariable("id") String id,
                                                 @PathVariable("areaCode") String areaCode,
                                                 @PathVariable("coordinateDeptId") String coordinateDeptId);


    @ApiOperation(value = "盟市长责任制--省级牵头部门--根据任务id查询省级牵头部门意见", notes = "参数：id")
    @GetMapping(value = "/provinceLeadOpinion/{id}/{areaCode}")
    ResponseWrapper getProvinceLeadOpinion(@PathVariable("id") String id,
                                           @PathVariable("areaCode") String areaCode);


    @ApiOperation(value = "盟市长责任制--省级牵头部门--根据任务id查询省级牵头部门复评意见", notes = "参数：id")
    @GetMapping(value = "/provinceLeadAgainOpinion/{id}/{areaCode}")
    ResponseWrapper getProvinceLeadAgainOpinion(@PathVariable("id") String id,
                                                       @PathVariable("areaCode") String areaCode);


    @ApiOperation(value = "盟市长责任制--省级牵头部门--新增省级牵头部门复评分", notes = "参数：BizRespDepartmentalOpinionVO")
    @PostMapping(value = "/provinceLeadOpinion")
    ResponseWrapper insertProvinceLeadOpinion(@RequestBody BizRespDepartmentalOpinionVO bizRespDepartmentalOpinionVO);


    @ApiOperation(value = "盟市长责任制--省级牵头/配合部门--批量上报", notes = "参数：taskId")
    @PutMapping(value = "/provinceLeadOpinion/{year}/{type}/{updateBy}")
    ResponseWrapper updateTaskStatus(@PathVariable(value = "year") Integer year,
                                     @PathVariable(value = "type") String type,
                                     @PathVariable(value = "updateBy") String updateBy);


    @ApiOperation(value = "盟市长责任制--省级配合部门--上报", notes = "参数：taskId")
    @PutMapping(value = "/provinceCoordinateOpinionStatus/{oids}")
    ResponseWrapper updateProvinceCoordinateOpinionStatus(@PathVariable(value = "oids") String oids);
}