package com.unis.accountability.businessmanagement.controller;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPage;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPageVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmVO;
import com.unis.accountability.businessmanagement.common.vo.cityQtbm.*;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPublishVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.ZpbmVO;
import com.unis.accountability.businessmanagement.service.BizRespCityPhbmService;
import com.unis.accountability.businessmanagement.service.BizRespCityQtbmService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**州市任务分配管理
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/cityQtbm")
@Slf4j
@Api(value = "粮食安全省长责任制--市级牵头部门", tags = "粮食安全省长责任制--市级牵头部门")
public class BizRespCityQtbmController {
    @Autowired
    private BizRespCityQtbmService bizRespCityQtbmService;

    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级牵头部门----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody CityQtbmPage qtbmPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<CityQtbmPageVO>> result = bizRespCityQtbmService.findByPage(qtbmPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     *
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级牵头部门----查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}/{deptId}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id,
            @PathVariable("deptId") String deptId
    ) {
        try {
            QtbmVO qtbmVO=bizRespCityQtbmService.findById(id,deptId);
            System.out.println("粮食安全行政首长责任制----市级牵头部门----查看" + qtbmVO.toString());
            String dataJson= JSON.toJSONString(qtbmVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     * 更新--重点考核事项
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级牵头部门---编辑", notes = "参数：itemVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody QtbmUpdateVO qtbmUpdateVO
    ) {
        try {
            boolean flag = bizRespCityQtbmService.update(qtbmUpdateVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级牵头部门---提交", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody CityZpbmPublishVO cityZpbmPublishVO
    ) {
        try {
            bizRespCityQtbmService.publish(cityZpbmPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级牵头部门---批量提交", notes = "参数：")
    @PostMapping(value = "/publishALL")
    public ResponseWrapper publishALL(
            @RequestBody CityZpbmPublishVO cityZpbmPublishVO
    ) {
        try {
            bizRespCityQtbmService.publishALL(cityZpbmPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级牵头部门---根据年份部门状态查询明细", notes = "参数：")
    @PostMapping(value = "/fidByYearAndDeptIdAndStatus")
    public ResponseWrapper fidByYearAndDeptIdAndStatus(
            @RequestBody CityQtbmPage cityQtbmPage
    ) {
        try {
            List<CityQtbmPageVO> qtbmPageVOList=bizRespCityQtbmService.fidByYearAndDeptIdAndStatus(cityQtbmPage);
            String dataJson= JSON.toJSONString(qtbmPageVOList);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


    /**
     *
     * @param taskId 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级牵头部门----根据taskId和行政区划查询查看", notes = "参数：id ")
    @GetMapping(value = "/findByTaskIdAndAreaCode/{taskId}/{areaCode}")
    public ResponseWrapper findByTaskIdAndAreaCode(
            @PathVariable("taskId") String  taskId,
            @PathVariable("areaCode") String  areaCode
    ) {
        try {
            CityTaskinfoVO qtbmVO=bizRespCityQtbmService.findByAreaList(taskId, areaCode);
            System.out.println("粮食安全行政首长责任制----市级牵头部门----查看" + qtbmVO.toString());
            String dataJson= JSON.toJSONString(qtbmVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }



}