package com.unis.accountability.businessmanagement.controller;



import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.backlog.BacklogAddVO;
import com.unis.accountability.businessmanagement.common.vo.backlog.ReceiverCollectionVO;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.*;

import com.unis.accountability.businessmanagement.mq.BacklogMQService;
import com.unis.accountability.businessmanagement.service.BizRespCityTaskDistributionService;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**州市任务分配管理
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/cityTaskDistribution")
@Slf4j
@Api(value = "粮食安全省长责任制--州市任务分配管理(市考核办)", tags = "粮食安全省长责任制--州市任务分配管理(市考核办)")
public class BizRespCityTaskDistributionController {
    @Autowired
    private BizRespCityTaskDistributionService bizRespCityTaskDistributionService;
    @Autowired
    private BacklogMQService mqService;


    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody CityTaskPage cityTaskPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<CityTaskDistributionPageVO>> result = bizRespCityTaskDistributionService.findByPage(cityTaskPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     *
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)----查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            CityTaskDistributionVO cityVO=bizRespCityTaskDistributionService.findById(id);
            System.out.println("粮食安全行政首长责任制----州市任务分配管理----查看"+cityVO.toString());
            String dataJson= JSON.toJSONString(cityVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     * 更新--重点考核事项
     *
     * @param cityTaskUpdateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)---编辑", notes = "参数：itemVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody CityTaskUpdateVO cityTaskUpdateVO
    ) {
        try {
            boolean flag = bizRespCityTaskDistributionService.update(cityTaskUpdateVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }




    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)---发布", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody CityTaskPublishVO cityTaskPublishVO
    ) {
        try {
            bizRespCityTaskDistributionService.publish(cityTaskPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)---批量发布", notes = "参数：")
    @PostMapping(value = "/publishALL")
    public ResponseWrapper publishALL(
            @RequestBody CityTaskPublishVO cityTaskPublishVO
    ) {
        try {
            bizRespCityTaskDistributionService.publishALL(cityTaskPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----区自评查看（市局）----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findZpCityByPage/{page}/{size}")
    public ResponseWrapper findZpCityByPage(
            @RequestBody CityTaskPage cityTaskPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizRespCityTaskDistributionService.findZpCityByPage(cityTaskPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----区自评查看（市局）---考核分发", notes = "参数：")
    @PostMapping(value = "/publishKhff")
    public ResponseWrapper publishKhff(
            @RequestBody CityTaskPublishVO cityTaskPublishVO
    ) {
        try {
            bizRespCityTaskDistributionService.publishKhff(cityTaskPublishVO);
            //市考核--cbl
            System.out.println("*************进入创建待办************");
            for (Map.Entry<String, List<ReceiverCollectionVO>> m : cityTaskPublishVO.getUserList().entrySet()) {
                if(m.getValue().size()>0){
                BacklogAddVO record = new BacklogAddVO();
                record.buildAddVO(record);
                record.setItemId(cityTaskPublishVO.getYear()+"-"+m.getKey());
                record.setItemName(cityTaskPublishVO.getItemName());
                record.setItemUrl(cityTaskPublishVO.getUrl());
                record.setItemQueryHaveDone(cityTaskPublishVO.getItemQueryHaveDone());
                record.setItemUrlHaveDone(cityTaskPublishVO.getItemUrlHaveDone());
                record.setItemStatus(1);
                record.setItemQuery(cityTaskPublishVO.getItemQuery());
                record.setItemStatusName("已发布");
                record.setCompanyName(cityTaskPublishVO.getOrgName());
                record.setSubmitter(cityTaskPublishVO.getUserName());
                record.setSubmitterId(cityTaskPublishVO.getUserId());
                // 另起线程执行待办
                new Thread(new Runnable() {
                    @Override
                    public void run() {
                        if (m.getValue() != null && m.getValue().size() > 0) {
                            for (ReceiverCollectionVO userVO : m.getValue()) {
                                record.setReceiver(userVO.getUserName());
                                record.setReceiverId(userVO.getUserId());
                                // 需要将对象序列化成JSONObject
                                mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
                            }
                        }
                    }
                }).start();
            }}
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----区自评查看（市局）---是否考核分发", notes = "参数：")
    @PostMapping(value = "/findByIsKhff")
    public ResponseWrapper findByIsKhff(
            @RequestBody CityTaskPublishVO cityTaskPublishVO
    ) {
        try {
           String iskhff= bizRespCityTaskDistributionService.findByIsKhff(cityTaskPublishVO);
            return ResponseWrapper.success(200, "查询成功", iskhff);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }





}