package com.unis.accountability.businessmanagement.controller;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.cityFf.*;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPublishVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.TaskPageVO;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespScoreInputSmiitVO;
import com.unis.accountability.businessmanagement.service.BizRespCityTaskfFService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**州市任务分配管理
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/cityTaskfF")
@Slf4j
@Api(value = "粮食安全省长责任制--评分表分处室考核（市部门）", tags = "粮食安全省长责任制--评分表分处室考核（市部门）")
public class BizRespCityTaskfFController {

    @Autowired
    private BizRespCityTaskfFService bizRespCityTaskfFService;

    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--评分表分处室考核（市部门）---分页", notes = "默认参数 "
    )
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody CityFfPage cityFfPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<CityFfPageVO>> result;
            if(cityFfPage.getOrgId().length()>11){
                result = bizRespCityTaskfFService.findByPageQu(cityFfPage, page, size);
            }else {
                result = bizRespCityTaskfFService.findByPage(cityFfPage, page, size);
            }
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }



    /**
     *
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----评分表分处室考核（市部门）----查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            TaskFfInfoVO taskFfInfoVO=bizRespCityTaskfFService.findById(id);
            System.out.println("粮食安全行政首长责任制----市级配合部门----查看" + taskFfInfoVO.toString());
            String dataJson= JSON.toJSONString(taskFfInfoVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     * 更新--重点考核事项
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----评分表分处室考核（市部门）---编辑", notes = "参数：itemVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody FfUpdateVO ffUpdateVO
    ) {
        try {
            boolean flag = bizRespCityTaskfFService.update(ffUpdateVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }

    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----评分表分处室考核（市部门）---提交", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody FfPublishVO ffPublishVO
    ) {
        try {
            bizRespCityTaskfFService.publish(ffPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----评分表分处室考核（市部门）---批量提交", notes = "参数：")
    @PostMapping(value = "/publishALL")
    public ResponseWrapper publishALL(
            @RequestBody FfPublishVO ffPublishVO
    ) {
        try {
            bizRespCityTaskfFService.publishALL(ffPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

    /**
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----评分表分处室考核（市部门）--查询是否可以提交数据", notes = "参数：")
    @PostMapping(value = "/findByIsSubmit")
    public ResponseWrapper findByIsSubmit(
            @RequestBody FfPublishVO ffPublishVO
    ) {
        try {
            String result= bizRespCityTaskfFService.findByIsSubmit(ffPublishVO);
            return ResponseWrapper.success(200, "查询成功", result);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


}