package com.unis.accountability.businessmanagement.controller;

import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentPage;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentSaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentUpdateVO;
import com.unis.accountability.businessmanagement.service.BizRespExaminationContentService;
import com.unis.common.utils.ResponseWrapper;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**考核内容
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 10:13
 * @Description:
 */
@RestController
@RequestMapping("/examinationContent")
@Slf4j
@Api(value = "粮食安全行政首长责任制----考核内容", tags = "粮食安全省长责任制--考核内容")
public class BizRespExaminationContentController {

    @Autowired
    private BizRespExaminationContentService bizRespExaminationContentService;

    /**
     * 保存数据 考核内容
     *
     * @param saveVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----保存", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody ContentSaveVO saveVO
    ) {
        System.out.println("保存=====考核内容==="+saveVO.toString());
        try {
            boolean flag = bizRespExaminationContentService.save(saveVO);
            if (!flag) {
                return ResponseWrapper.error("对象已存在无法添加");
            }
            return ResponseWrapper.success(200, "保存成功", null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }





    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody ContentPage contentPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizRespExaminationContentService.findByPage(contentPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }



    /**
     * 更新考核内容
     *
     * @param updateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----修改", notes = "参数：updateVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody ContentUpdateVO updateVO
    ) {

        try {
            boolean flag = bizRespExaminationContentService.update(updateVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error(500, "操作失败",null);
        }

    }



    /**
     * 多选删除
     *
     * @param deleteVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----删除", notes = "参数：考核内容ids(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(@RequestBody DeleteVO deleteVO) {
        try {
            Boolean flag = bizRespExaminationContentService.deletes(deleteVO);
            if (!flag) {
                return ResponseWrapper.error(521, "考核内容已使用", null);
            }
            return ResponseWrapper.success(200, "考核内容成删除功", null);
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "考核内容删除失败",null);
        }
    }



    /**
     * 查询考核内容
     * @param year 年份
     * @param deptId 组织机构id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----根据年份year和组织机构查询好喝内容", notes = "参数：year ")
    @GetMapping(value = "/findByYearAndOrgId/{year}/{responsibilityId}/{orgId}")
    public ResponseWrapper findByYearAndOrgId(
            @PathVariable("year") String  year,
            @PathVariable("responsibilityId") String  responsibilityId,
            @PathVariable("orgId") String  orgId
    ) {
        if (null == year ) {
            return ResponseWrapper.success(320, "请求参数不能为空", null);
        }else{
            try {
                Map map=new HashMap();
                map.put("year",year);
                map.put("bizRespResponsibilityId", responsibilityId);
                map.put("orgId", orgId);
                List<Map> list=bizRespExaminationContentService.findByYearAndOrgId(map);
                return ResponseWrapper.success(200, "查询成功", list);
            } catch (Exception e) {
                e.printStackTrace();
                log.error("查找对象，发生异常", e.getMessage());
                return ResponseWrapper.error(500, "单位信息查询失败", null);
            }

        }
    }





}