package com.unis.accountability.businessmanagement.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.examinationQuota.QuotaSaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationQuota.QuotaUPdateVO;
import com.unis.accountability.businessmanagement.common.vo.examinationQuota.QutoaPage;
import com.unis.accountability.businessmanagement.service.BizRespExaminationQuotaService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**考核指标
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 16:25
 * @Description:
 */
@RestController
@RequestMapping("/examinationQuota")
@Slf4j
@Api(value = "粮食安全省长责任制--考核指标", tags = "粮食安全省长责任制--考核指标")
public class BizRespExaminationQuotaController {

    @Autowired
    private BizRespExaminationQuotaService bizRespExaminationQuotaService;



    /**
     * 考核指标
     *
     * @param quotaVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核指标----保存", notes = "参数：重点考核事项 ContentVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody QuotaSaveVO quotaVO
    ) {
        System.out.println("保存=====考核指标==="+quotaVO.toString());
        try {
            boolean flag = bizRespExaminationQuotaService.save(quotaVO);
            if (!flag) {
                return ResponseWrapper.error("对象已存在无法添加");
            }
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }









    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核指标----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody QutoaPage qutoaPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizRespExaminationQuotaService.findByPage(qutoaPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }




    /**
     * 查询 考核指标
     * @param year 年份
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核指标----根据年份year和组织机构 orgId 查询重点考核事项", notes = "参数：year、orgId ")
    @GetMapping(value = "/findByYearAndOrgId/{year}/{responsibilityId}/{orgId}")
    public ResponseWrapper findByYearAndOrgId(
            @PathVariable("year") String  year,
            @PathVariable("responsibilityId") String  responsibilityId,
            @PathVariable("orgId") String  orgId
    ) {
        if (null == year ) {
            return ResponseWrapper.success(320, "请求参数不能为空", null);
        }else{
            try {
                Map map=new HashMap();
                map.put("year",year);
                map.put("orgId", orgId);
                map.put("bizRespResponsibilityId",responsibilityId);
                List<Map> list=bizRespExaminationQuotaService.findByYearAndOrgId(map);
                return ResponseWrapper.success(200, "查询成功", list);
            } catch (Exception e) {
                e.printStackTrace();
                log.error("查找对象，发生异常", e.getMessage());
                return ResponseWrapper.error(500, "单位信息查询失败",null);
            }

        }
    }




    /**
     * 更新--考核指标
     *
     * @param quotaUPdateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核指标----编辑", notes = "参数：bizRespExaminationContentVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody QuotaUPdateVO quotaUPdateVO
    ) {

        try {
            boolean flag = bizRespExaminationQuotaService.update(quotaUPdateVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null);
        }

    }




    /**
     * 多选删除
     *
     * @param deleteVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核指标----批量删除", notes = "参数：重点考核事项ids(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(
            @RequestBody  DeleteVO deleteVO
    ) {
        try {
            Boolean flag = bizRespExaminationQuotaService.deletes(deleteVO);
            if (!flag) {
                return ResponseWrapper.error(521, "考核目标任务已使用",null);
            }
            return ResponseWrapper.success(200, "考核指标删除成功",null);
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "考核指标删除失败",null);
        }
    }




}