package com.unis.accountability.businessmanagement.controller;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.*;
import com.unis.accountability.businessmanagement.entity.BizRespDepartmentalOpinion;
import com.unis.accountability.businessmanagement.entity.BizRespExaminationTask;
import com.unis.accountability.businessmanagement.service.BizRespExaminationTaskService;
import com.unis.accountability.businessmanagement.service.impl.BizRespDepartmentalOpinionServiceImpl;
import com.unis.common.utils.ResponseWrapper;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**考核目标任务
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/examinationTask")
@Slf4j
@Api(value = "粮食安全省长责任制--考核目标任务", tags = "粮食安全省长责任制--考核目标任务")
public class BizRespExaminationTaskController {

    @Autowired
    private BizRespExaminationTaskService bizRespExaminationTaskService;

    @Autowired
    private BizRespDepartmentalOpinionServiceImpl bizRespDepartmentalOpinionService;

    /**
     * 考核目标任务
     *
     * @param taskSaveVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---保存", notes = "参数：考核目标任务 taskVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody TaskSaveVO taskSaveVO
    ) {
        System.out.println("保存=====考核指标==="+taskSaveVO.toString());
        try {
            boolean flag = bizRespExaminationTaskService.save(taskSaveVO);
            if (!flag) {
                return ResponseWrapper.error("对象已存在无法添加");
            }
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }




    /**
     * 根据 考核指标 id 查询 考核目标任务 可填分数
     * @param
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---查询可填分数", notes = "参数：year ")
    @GetMapping(value = "/findBySorce/{quotaId}/{responsibilityId}/{deptid}")
    public ResponseWrapper findBySorce(
            @PathVariable("quotaId") String  quotaId,
            @PathVariable("responsibilityId") String  responsibilityId,
            @PathVariable("deptid") String  deptid
    ) {
        try {
            Map map=new HashMap();
            map.put("quotaId",quotaId);
            map.put("responsibilityId",responsibilityId);
            //部门ID
            map.put("deptid", deptid);
            Map result=bizRespExaminationTaskService.findBySorce(map);
            return ResponseWrapper.success(200, "查询成功", result);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }







    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---分页", notes = "默认参数：source= :1 管理平台用    deptIds   " +
            "2 userId : 配合部门，牵头部门 3 userId :自评部门  4:根据行政区划查询所有数据,statusType=10,20,  year=2018"
    )
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody TaskPageVO taskVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizRespExaminationTaskService.findByPage(taskVO, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }







    /**
     * 根据id查询考核目标任务--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            BizRespExaminationTaskVO taskVO=bizRespExaminationTaskService.findById(id);
            System.out.println("根据id查询考核目标任务"+taskVO.toString());
            return ResponseWrapper.success(200, "查询成功", taskVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }

    @ApiOperation(value = "粮食安全行政首长责任制----省级任务考查询(省考核办)---驳回", notes = "参数：taskId")
    @GetMapping(value = "/taskId/{inputId}")
    public ResponseWrapper getTaskIdByInputId(
            @PathVariable("inputId") String inputId
    ) {
        try {
            String taskId = bizRespExaminationTaskService.getTaskIdByInputId(inputId);
            return ResponseWrapper.success(200, "查询成功",taskId);
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }






    /**
     * 更新--考核目标任务
     *
     * @param taskUpdateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---编辑", notes = "参数：taskVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody TaskUpdateVO taskUpdateVO
    ) {
        try {
            boolean flag = bizRespExaminationTaskService.update(taskUpdateVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败"+ e.getMessage() ,null);
        }

    }
    /**
     * 更新--考核目标任务
     *
     * @param taskUpdateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核科室分发---编辑", notes = "参数：taskVO")
    @PostMapping(value = "/updateOpinion")
    public ResponseWrapper updateOpinion(
            @RequestBody TaskUpdateVO taskUpdateVO
    ) {
        try {
           // boolean flag = bizRespExaminationTaskService.update(taskUpdateVO);
            BizRespDepartmentalOpinion opinion = new BizRespDepartmentalOpinion();
            opinion.setId(taskUpdateVO.taskVO.getIds());
            opinion.setUserCode(taskUpdateVO.taskVO.getUserCode());
            opinion.setFfzt(taskUpdateVO.taskVO.getStatus());
            opinion.setKhcs(taskUpdateVO.taskVO.getKhcs());
            opinion.setKhcsid(taskUpdateVO.taskVO.getKhcsid());
            bizRespDepartmentalOpinionService.updateByPrimaryKey(opinion);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败"+ e.getMessage() ,null);
        }

    }
    @ApiOperation(value = "粮食安全省长责任制--区考核分配---批量发布", notes = "参数：组织名")
    @PostMapping(value = "/publishAll/{orgName}")
    public ResponseWrapper publishAll(
            @PathVariable("orgName") String orgName
    ) {
        try {
            bizRespExaminationTaskService.publishAll(orgName);
            return ResponseWrapper.success("发布成功");
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败"+ e.getMessage() ,null);
        }

    }


    /**
     * 多选删除
     *
     * @param deleteVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---批量删除", notes = "参数：考核目标任务ids(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(
            @RequestBody DeleteVO deleteVO
    ) {
        try {
            Boolean flag = bizRespExaminationTaskService.deletes(deleteVO);
            if (!flag) {
                return ResponseWrapper.error(300, "参数错误，删除失败", null);
            }
            return ResponseWrapper.success(200, "用户信息删除成功", null);
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息删除失败",null);
        }
    }




    /**
     * 根据id查询考核目标任务--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细--牵头部门配合部门部门和自评部门专用", notes = "参数：id ")
    @GetMapping(value = "/findByTaskInfo/{id}")
    public ResponseWrapper findByTaskInfo(
            @PathVariable("id") String  id
    ) {
        try {
            TaskInfoVO taskVO= bizRespExaminationTaskService.findByTaskInfo(id);
            System.out.println("根据id查询考核目标任务"+taskVO.toString());
            String dataJson= JSON.toJSONString(taskVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }
   
    /**
     * 粮食安全省长责任制--考核目标任务---根据填报设置ID查询所有考核任务
     * @param bizRespResponsiBilityId
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细--牵头部门配合部门部门和自评部门专用", notes = "参数：id ")
    @GetMapping(value = "/findTaskListByResponsiBilityId/{bizRespResponsiBilityId}")
    public ResponseWrapper findTaskListByResponsiBilityId(
    		@PathVariable("bizRespResponsiBilityId") String  bizRespResponsiBilityId
    		) {
    	try {
    		List<BizRespExaminationTask> taskVO= bizRespExaminationTaskService.findTaskListByResponsiBilityId(bizRespResponsiBilityId);
//    		System.out.println("根据id查询考核目标任务"+taskVO.toString());
    		String dataJson= JSON.toJSONString(taskVO);
    		return ResponseWrapper.success(200, "查询成功", dataJson);
    	} catch (Exception e) {
    		e.printStackTrace();
    		log.error("查找对象，发生异常", e.getMessage());
    		return ResponseWrapper.error(500, "单位信息查询失败",null);
    	}
    }

}