package com.unis.accountability.businessmanagement.controller;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPage;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPageVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPublishVO;
import com.unis.accountability.businessmanagement.common.vo.provincePhbm.ProvincePhbmPage;
import com.unis.accountability.businessmanagement.common.vo.provincePhbm.ProvincePhbmPublishVO;
import com.unis.accountability.businessmanagement.common.vo.provincePhbm.PrvoincePhbmPageVO;
import com.unis.accountability.businessmanagement.service.BizRespCityPhbmService;
import com.unis.accountability.businessmanagement.service.BizRespProvincePhbmService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**州市任务分配管理
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/provincePhbm")
@Slf4j
@Api(value = "粮食安全省长责任制--省级配合部门", tags = "粮食安全省长责任制--省级配合部门")
public class BizRespProvincePhbmController {
    @Autowired
    private BizRespProvincePhbmService bizRespProvincePhbmService;

    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----省级配合部门----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody ProvincePhbmPage provincePhbmPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<PrvoincePhbmPageVO>> result = bizRespProvincePhbmService.findByPage(provincePhbmPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     * 粮食安全行政首长责任制----省级配合部门----查看
     * @param id  部门意见ID
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----省级配合部门----查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            PhbmVO phbmVO=bizRespProvincePhbmService.findById(id);
            System.out.println("粮食安全行政首长责任制----省级配合部门----查看" + phbmVO.toString());
            String dataJson= JSON.toJSONString(phbmVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     * 更新--重点考核事项
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----省级配合部门---编辑", notes = "参数：itemVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody PhbmUpdateVO phbmUpdateVO
    ) {
        try {
            boolean flag = bizRespProvincePhbmService.update(phbmUpdateVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }




    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----省级配合部门---上报", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody ProvincePhbmPublishVO phbmPublishVO
    ) {
        try {
            bizRespProvincePhbmService.publish(phbmPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----省级配合部门---批量上报", notes = "参数：")
    @PostMapping(value = "/publishALL")
    public ResponseWrapper publishALL(
            @RequestBody ProvincePhbmPublishVO phbmPublishVO
    ) {
        try {
            bizRespProvincePhbmService.publishALL(phbmPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


//
//
//    /**
//     * 发布
//     * @param
//     * @return ResponseWrapper
//     */
//    @ApiOperation(value = "粮食安全行政首长责任制----省级配合部门---根据年份部门状态查询明细", notes = "参数：")
//    @PostMapping(value = "/fidByYearAndDeptIdAndStatus")
//    public ResponseWrapper fidByYearAndDeptIdAndStatus(
//            @RequestBody CityPhbmPage cityPhbmPage
//    ) {
//        try {
//            List<CityPhbmPageVO> phbmPageVOList=bizRespCityPhbmService.fidByYearAndDeptIdAndStatus(cityPhbmPage);
//            String dataJson= JSON.toJSONString(phbmPageVOList);
//            return ResponseWrapper.success(200, "查询成功", dataJson);
//        } catch (Exception e) {
//            e.printStackTrace();
//            log.error( "更新对象，发生异常", e.getMessage() );
//            return ResponseWrapper.error( 500, "操作失败",null );
//        }
//    }






}