package com.unis.accountability.businessmanagement.controller;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.backlog.BacklogAddVO;
import com.unis.accountability.businessmanagement.common.vo.backlog.ReceiverCollectionVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPage;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPageVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPublishVO;
import com.unis.accountability.businessmanagement.common.vo.provinceTask.*;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespScoreInputSmiitVO;
import com.unis.accountability.businessmanagement.mq.BacklogMQService;
import com.unis.accountability.businessmanagement.service.BizRespCityPhbmService;
import com.unis.accountability.businessmanagement.service.BizRespProvinceTaskService;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**州市任务分配管理
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/provinceTask")
@Slf4j
@Api(value = "粮食安全省长责任制--省级任务考查询(省考核办)", tags = "粮食安全省长责任制--省级任务考查询(省考核办)")
public class BizRespProvinceTaskController {

    @Autowired
    private BizRespProvinceTaskService bizRespProvinceTaskService;
    @Autowired
    private BacklogMQService mqService;
    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核结果查看（市局）----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody ProvinceTaskPage provinceTaskPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<ProvincePageVO>> result = bizRespProvinceTaskService.findByPage(provinceTaskPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }



    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----省级任务考查询(省考核办)----州市考核明细", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findCityByPage/{page}/{size}")
    public ResponseWrapper findCityByPage(
            @RequestBody ProvinceCityTaskPage provinceTaskPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<ProvinceCityPageVO>> result = bizRespProvinceTaskService.findCityByPage(provinceTaskPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }




    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----结果汇总查看（市局)----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByHzPage/{page}/{size}")
    public ResponseWrapper findByHzPage(
            @RequestBody ProvinceTaskPage provinceTaskPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<ProvincePageVO>> result = bizRespProvinceTaskService.findByHzPage(provinceTaskPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }




    /**
     * 更新--重点考核事项
     *
     * @param taskId
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----省级任务考查询(省考核办)---驳回", notes = "参数：taskId")
    @GetMapping(value = "/saveReappraisal/{taskId}/{shiAreaCode}")
    public ResponseWrapper saveReappraisal(
            @PathVariable("taskId") String taskId,
            @PathVariable("shiAreaCode") String shiAreaCode
    ) {
        try {
            boolean flag = bizRespProvinceTaskService.saveReappraisal(taskId, shiAreaCode);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }



    /**
     * 更新--重点考核事项
     *
     * @param taskId
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----省级任务考查询(省考核办)---省级配合部门和牵头部门评价明细", notes = "参数：taskId")
    @GetMapping(value = "/findByProvinceQtbmAndPhbm/{taskId}/{shiAreaCode}")
    public ResponseWrapper findByProvinceQtbmAndPhbm(
            @PathVariable("taskId") String taskId,
            @PathVariable("shiAreaCode") String shiAreaCode
    ) {
        try {
            ProvinceTaskVO provinceTaskVO = bizRespProvinceTaskService.findByProvinceQtbmAndPhbm(taskId, shiAreaCode);
            String dataJson= JSON.toJSONString(provinceTaskVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }


    /**
     * 更新--重点考核事项
     *
     * @param provinceCityTaskPage
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----省级任务考查询(省考核办)---提交", notes = "参数：taskId")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody ProvinceCityTaskPage provinceCityTaskPage
    ) {
        try {
             bizRespProvinceTaskService.publish(provinceCityTaskPage);
            return ResponseWrapper.success(200, "查询成功", null);
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }


    /**
     * 更新--重点考核事项
     *
     * @param provinceCityTaskPage
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核结果查看（市局)---抽查分发", notes = "参数：taskId")
    @PostMapping(value = "/publishCcFf")
    public ResponseWrapper publishCcFf(
            @RequestBody List<ProvinceCityTaskPage> provinceCityTaskPage
    ) {
        try {
            bizRespProvinceTaskService.publishCcFf(provinceCityTaskPage);
            for(ProvinceCityTaskPage cityTaskPage:provinceCityTaskPage){
                System.out.println("*************进入创建待办************");
                BacklogAddVO record=new BacklogAddVO();
                record.buildAddVO(record);
                record.setItemId(cityTaskPage.getBizRespResponsibilityId()+"-"+cityTaskPage.getAreaCode());
                record.setItemName(cityTaskPage.getItemName());
                record.setItemUrl(cityTaskPage.getUrl());
                record.setItemQueryHaveDone(cityTaskPage.getItemQueryHaveDone());
                record.setItemUrlHaveDone(cityTaskPage.getItemUrlHaveDone());
                record.setItemStatus(1);
                record.setItemQuery(cityTaskPage.getItemQuery());
                record.setItemStatusName("已发布");
                record.setCompanyName(cityTaskPage.getOrgName());
                record.setSubmitter(cityTaskPage.getUserName());
                record.setSubmitterId(cityTaskPage.getUserId());
                // 另起线程执行待办
                new Thread(new Runnable() {
                    @Override
                    public void run() {
                        if(cityTaskPage.getUserList()!=null&&cityTaskPage.getUserList().size()>0){
                            for (ReceiverCollectionVO userVO : cityTaskPage.getUserList()) {
                                record.setReceiver(userVO.getUserName());
                                record.setReceiverId(userVO.getUserId());
                                // 需要将对象序列化成JSONObject
                                mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
                            }
                        }
                    }
                }).start();
                break;
            }

            return ResponseWrapper.success(200, "查询成功", null);
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }




}