package com.unis.accountability.businessmanagement.controller;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.backlog.BacklogAddVO;
import com.unis.accountability.businessmanagement.common.vo.backlog.ReceiverCollectionVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.*;
import com.unis.accountability.businessmanagement.mq.BacklogMQService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.service.BizRespResponsibilityService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/7/25 0025 16:38
 * @Description:
 */
@RestController
@Slf4j
@Api(value = "粮食安全行政首长责任制-----考核评分表管理", tags = "粮食安全行政首长责任制：考核评分表管理")
@RequestMapping("/responsibility")
public class BizRespResponsibilityController {

    @Autowired
    private BizRespResponsibilityService bizRespResponsibilityService;
    @Autowired
    private BacklogMQService mqService;


    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "考核评分表管理---分页查询", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody BizRespResponsibilityPageVO pageVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizRespResponsibilityService.findByPage(pageVO, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     * 下发评表
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---根据评分表名称和年分查询数据是否存在", notes = "参数：下发评表明细 pageVO")
    @PostMapping(value = "/findByPfbmc")
    public ResponseWrapper findByPfbmc(
            @RequestBody BizRespResponsibilityPfbmcVO pfbmcVO
    ) {
        try {
            Map map=bizRespResponsibilityService.findByPfbmc(pfbmcVO);
            String tt=map.get("result").toString();
            if("2".equals(tt)){
                return ResponseWrapper.error(504, "评分表名称已存在", null);
            }
            return ResponseWrapper.success(200, "保存成功", null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }



    /**
     * 考核评分表管理---保存
     *
     * @param bilitySaveVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---保存", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody BilitySaveVO bilitySaveVO
    ) {
        System.out.println("保存=====责任考核==="+bilitySaveVO.toString());
        try {
            BizRespResponsibilityVO bizRespResponsibilityVO= bizRespResponsibilityService.findByYear(String.valueOf(bilitySaveVO.getBilityVO().getYear()));
            if(bizRespResponsibilityVO!=null){
                return ResponseWrapper.error("当前年度数据已经添加");
            }

            boolean flag = bizRespResponsibilityService.save(bilitySaveVO);
            if (!flag) {
                return ResponseWrapper.error("对象已存在无法添加");
            }
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }

    /**
     * 考核评分表管理---编辑
     *
     * @param bilityUpdateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---编辑修改评分表名称", notes = "参数：编辑修改评分表名称 ContentVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody BilityUpdateVO bilityUpdateVO
    ) {
        System.out.println("编辑修改评分表名称=====责任考核==="+bilityUpdateVO.toString());
        try {
            boolean flag = bizRespResponsibilityService.update(bilityUpdateVO);
            if (!flag) {
                return ResponseWrapper.error("对象已存在无法添加");
            }
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }





    /**
     * 查询责任考核
     * @param year 年份
     * @param
     * @return
     */
    @ApiOperation(value = "考核评分表管理------根据年份year和组织机构和ID查询基本信息", notes = "参数：year ")
    @GetMapping(value = "/findById/{year}/{id}/{orgId}")
    public ResponseWrapper findById(
            @PathVariable("year") String  year,
            @PathVariable("id") String  id,
            @PathVariable("orgId") String  orgId
    ) {
        if (null == year) {
            return ResponseWrapper.success(320, "请求参数不能为空", null);
        }else{
            try {
                Map map=new HashMap();
                map.put("year",year);
                map.put("id",id);
                //机构ID
                map.put("orgId", orgId);
                BizRespResponsibilityVO bizRespResponsibilityVO=bizRespResponsibilityService.findByYearAndOrgId(map);
                return ResponseWrapper.success(200, "查询成功", bizRespResponsibilityVO);
            } catch (Exception e) {
                e.printStackTrace();
                log.error("查找对象，发生异常", e.getMessage());
                return ResponseWrapper.error(500, "单位信息查询失败", null);
            }

        }
    }


    /**
     * 查询责任考核
     * @param
     * @param
     * @return
     */
    @ApiOperation(value = "考核评分表管理----根据id查询明细", notes = "参数：id ")
    @GetMapping(value = "/findByIds/{id}")
    public ResponseWrapper findByIds(
            @PathVariable("id") String  id
    ) {

        try {
            BizRespResponsibilityVO bizRespResponsibilityVO=bizRespResponsibilityService.findByIds(id);
            String dataJson= JSON.toJSONString(bizRespResponsibilityVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }

    }


    /**
     * 查询责任考核
     * @param
     * @return
     */
    @ApiOperation(value = "考核评分表管理------根据ID查询基本信息", notes = "参数：year ")
    @GetMapping(value = "/findByInfo/{id}")
    public ResponseWrapper findByInfo(
            @PathVariable("id") String  id
    ) {
        try {
            BizRespResponsibilityVO bizRespResponsibilityVO=bizRespResponsibilityService.findByInfo(id);
            String dataJson= JSON.toJSONString(bizRespResponsibilityVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败", null);
        }
    }


    /**
     * 查询责任考核
     * @param year 年份
     * @param
     * @return
     */
    @ApiOperation(value = "考核评分表管理------根据年分查询基本信息", notes = "参数：year ")
    @GetMapping(value = "/findByYear/{year}")
    public ResponseWrapper findByYear(
            @PathVariable("year") String  year
    ) {
        try {
            BizRespResponsibilityVO bizRespResponsibilityVO=bizRespResponsibilityService.findByYear(year);
            String dataJson= JSON.toJSONString(bizRespResponsibilityVO);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败", null);
        }
    }




    /**
     * 单选删除
     *
     * @param deleteVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---删除责任考核", notes = "参数：考核内容id(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(@RequestBody DeleteVO deleteVO) {
        try {
            Boolean flag = bizRespResponsibilityService.deletes(deleteVO);
            if (!flag) {
                return ResponseWrapper.error(300, "参数错误，删除失败",null);
            }
            return ResponseWrapper.success(200, "用户信息删除成功",null);
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息删除失败",null);
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---发布", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody BizRespResponsibilitPublishVO publishVO
    ) {
        try {
            //保存所有区
            String flag = bizRespResponsibilityService.publish(publishVO);
            if ("2".equals(flag)) {
                return ResponseWrapper.error(504, "评分表总分与考核目标任务总分不相等!",null);
            }
            //if("".equals(publishVO.getStatus())){
            for (Map.Entry<String, List<ReceiverCollectionVO>> m : publishVO.getUserList().entrySet()) {
                if(m.getValue().size()>0){
                    BacklogAddVO record = new BacklogAddVO();
                    record.buildAddVO(record);
                    record.setItemId(publishVO.getId()+"-"+m.getKey());
                    record.setItemName(publishVO.getItemName());
                    record.setItemUrl(publishVO.getUrl());
                    record.setItemQueryHaveDone(publishVO.getItemQueryHaveDone());
                    record.setItemUrlHaveDone(publishVO.getItemUrlHaveDone());
                    record.setItemStatus(1);
                    record.setItemQuery(publishVO.getItemQuery());
                    record.setItemStatusName("已发布");
                    record.setCompanyName(publishVO.getOrgName());
                    record.setSubmitter(publishVO.getUserName());
                    record.setSubmitterId(publishVO.getUserId());
                    // 另起线程执行待办
                    new Thread(new Runnable() {
                        @Override
                        public void run() {
                            if (m.getValue() != null && m.getValue().size() > 0) {
                                for (ReceiverCollectionVO userVO : m.getValue()) {
                                    record.setReceiver(userVO.getUserName());
                                    record.setReceiverId(userVO.getUserId());
                                    // 需要将对象序列化成JSONObject
                                    mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
                                }
                            }
                        }
                    }).start();
                }
                //}
            }
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }



    /**
     * 下及州市
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---下级州市", notes = "参数：下及州市 pageVO")
    @PostMapping(value = "/findByRespResponsibilityCity")
    public ResponseWrapper findByRespResponsibilityCity(
            @RequestBody BizRespResponsibilityCityVO cityVO
    ) {
        try {
            List<String> result= bizRespResponsibilityService.findByRespResponsibilityCity(cityVO);
            String areacode= StringUtils.join(result, ",");
            return ResponseWrapper.success(200, "查询成功", areacode);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 更新评分表
     *
     * @param updateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---更新评分表", notes = "参数：bizRespExaminationContentVO")
    @PostMapping(value = "/updatePfb")
    public ResponseWrapper updatePfb(
            @RequestBody BizRespResponsibilityUpdateVO updateVO
    ) {
        try {
            String flag = bizRespResponsibilityService.updatePfb(updateVO);
            if ("2".equals(flag)) {
                return ResponseWrapper.error(504, "评分表总分与考核目标任务总分不相等!",null);
            }
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null);
        }

    }



    /**
     * 下发评表
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---下发评表明细", notes = "参数：下发评表明细 pageVO")
    @PostMapping(value = "/findByRespResponsibilityInfo")
    public ResponseWrapper findByRespResponsibilityInfo(
            @RequestBody BizRespResponsibilityPageVO pageVO
    ) {
        try {
            Map result= bizRespResponsibilityService.bizRespResponsibilityService(pageVO);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 下发评表
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---复制评分表", notes = "参数：下发评表明细 pageVO")
    @PostMapping(value = "/saveCopyPfb")
    public ResponseWrapper saveCopyPfb(
            @RequestBody BizRespCopyPfbVO copyPfbVO
    ) {
        try {
            boolean flag = bizRespResponsibilityService.saveCopyPfb(copyPfbVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }





}