package com.unis.accountability.businessmanagement.controller;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.CityTaskPublishVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BizRespExaminationTaskVO;
import com.unis.accountability.businessmanagement.common.vo.provinceTask.ProvinceTaskPage;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespScoreInputSmiitVO;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespScoreInputVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespResponsibilityPageVO;
import com.unis.accountability.businessmanagement.entity.BizRespExaminationTask;
import com.unis.accountability.businessmanagement.service.BizRespExaminationTaskService;
import com.unis.common.utils.ResponseWrapper;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespRespScoreInputPublishVO;
import com.unis.accountability.businessmanagement.service.BizRespScoreInputService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/9/19 0019 15:42
 * @Description:
 */
@RestController
@RequestMapping("/respScoreInput")
@Slf4j
@Api(value = "粮食安全首长责任制--州市考核任务管理", tags = "粮食安全首长责任制--州市考核任务管理")
public class BizRespScoreInputController {


    @Autowired
    private BizRespScoreInputService bizRespScoreInputService;
    @Autowired
    private BizRespExaminationTaskService bizRespExaminationTaskService;

    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全首长责任制--州市考核任务管理----发布", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody BizRespRespScoreInputPublishVO inputPublishVO
    ) {
        try {
            bizRespScoreInputService.publish(inputPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

    @ApiOperation(value = "粮食安全首长责任制--结果汇总查看----发布", notes = "参数：")
    @PostMapping(value = "/publishByArea")
    public ResponseWrapper publishByArea(
            @RequestBody ProvinceTaskPage provinceTaskPage
    ) {
        try {
            bizRespScoreInputService.updateByArea(provinceTaskPage);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }
    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全首长责任制--州市考核任务管理  根据年分 状态 行政区划 查询 州市考核录入数据", notes = "参数：")
    @PostMapping(value = "/findByYearAndStatusAndAreaCode")
    public ResponseWrapper findByYearAndStatusAndAreaCode(
            @RequestBody CityTaskPublishVO cityTaskPublishVO
    ) {
        try {
            List<BizRespScoreInputVO> inputList= bizRespScoreInputService.findByYearAndStatusAndAreaCode(cityTaskPublishVO);
            String dataJson= JSON.toJSONString(inputList);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--下发州市考核任务----制定州市考核任务--- 分页查询", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findTaskByPage/{page}/{size}")
    public ResponseWrapper findTaskByPage(
            @RequestBody BizRespResponsibilityPageVO pageVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizRespScoreInputService.findTaskByPage(pageVO, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     * 粮食安全首长责任制--州市考核任务管理  根据年分 状态 行政区划 查询 州市考核录入数据
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "州市、外部单位牵头部门、配合部门评分--查询是否可以提交数据", notes = "参数：")
    @PostMapping(value = "/findByIsSubmit")
    public ResponseWrapper findByIsSubmit(
            @RequestBody BizRespScoreInputSmiitVO scoreInputSmiitVO
    ) {
        try {
            String result= bizRespScoreInputService.findByIsSubmit(scoreInputSmiitVO);
            return ResponseWrapper.success(200, "查询成功", result);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }
    /**
     * 粮食安全首长责任制--区考核部门查询 根据id查询
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "区考核部门查询", notes = "参数：inputId")
    @GetMapping(value = "/{id}")
    public ResponseWrapper findByInputId(
            @PathVariable("id") String id
    ) {
        try {
            BizRespExaminationTaskVO byInputId = bizRespExaminationTaskService.findByInputId(id);
            String dataJson= JSON.toJSONString(byInputId);
            return ResponseWrapper.success(200, "查询成功", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

}