package com.unis.accountability.businessmanagement.controller;

import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.entity.BizRespScoringCity;
import com.unis.accountability.businessmanagement.service.BizRespScoringCityService;
import com.unis.common.utils.ResponseWrapper;
import com.unis.accountability.businessmanagement.common.vo.scoringCity.BizRespScoringCityPublishVO;
import com.unis.accountability.businessmanagement.common.vo.scoringCity.BizRespScoringCityVO;
import com.unis.accountability.businessmanagement.common.vo.scoringCity.ScoringCityUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.scoringCity.ScoringPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**粮食安全行政首长责任制-----评分结果录入(州市)---填报时间   BIZ_RESP_SCORING_CITY
 * @Auther:张新亮
 * @Date: 2019/9/19 0019 15:42
 * @Description:
 */
@RestController
@RequestMapping("/scoringCity")
@Slf4j
@Api(value = "粮食安全首长责任制---州市任务填报设置", tags = "粮食安全首长责任制--州市任务填报设置")
public class BizRespScoringCityController {
    @Autowired
    private BizRespScoringCityService bizRespScoringCityService;



    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody ScoringPage scoringPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizRespScoringCityService.findByPage(scoringPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }




    /**
     * 根据id查询考核目标任务--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置----查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            BizRespScoringCityVO cityVO=bizRespScoringCityService.findById(id);
            System.out.println("根据id查询考核目标任务"+cityVO.toString());
            return ResponseWrapper.success(200, "查询成功", cityVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     * 根据id查询考核目标任务--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置----根据年分和状态---考核评分权重--对象", notes = "参数：id ")
    @GetMapping(value = "/findByYearAndStatus/{year}/{status}/{areaCode}")
    public ResponseWrapper findByYearAndStatus(
            @PathVariable("year") String  year,
            @PathVariable("status") String  status,
            @PathVariable("areaCode") String  areaCode
    ) {
        try {
            BizRespScoringCityVO cityVO=new BizRespScoringCityVO();
            BizRespScoringCity city=bizRespScoringCityService.findByYearAndStatus(year,status,areaCode);
            if(city!=null){
                 cityVO=bizRespScoringCityService.findById(city.getId());
            }
            return ResponseWrapper.success(200, "查询成功", cityVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }





    /**
     * 根据id查询考核目标任务--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置----根据年分查询明细", notes = "参数：id ")
    @GetMapping(value = "/findByYearAndOrgId/{year}/{orgId}")
    public ResponseWrapper findByYearAndOrgId(
            @PathVariable("year") String  year,
            @PathVariable("orgId") String  orgId
    ) {
        try {
            BizRespScoringCityVO cityVO=bizRespScoringCityService.findByYearAndOrgId(year, orgId);
            System.out.println("根据id查询考核目标任务"+cityVO.toString());
            return ResponseWrapper.success(200, "查询成功", cityVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }






    /**
     * 更新--考核目标任务
     *
     * @param scoringCityUpdateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置---编辑", notes = "参数：taskVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody ScoringCityUpdateVO scoringCityUpdateVO
    ) {
        try {
            boolean flag = bizRespScoringCityService.update(scoringCityUpdateVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败"+ e.getMessage() ,null);
        }

    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全首长责任制--州市考核任务管理----发布", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody BizRespScoringCityPublishVO inputPublishVO
    ) {
        try {
            bizRespScoringCityService.publish(inputPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

}