package com.unis.accountability.businessmanagement.controller;

import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.scoringWeight.*;
import com.unis.accountability.businessmanagement.service.BizRespScoringWeightService;
import com.unis.common.utils.ResponseWrapper;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.entity.BizRespScoringWeight;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/7/25 0025 16:38
 * @Description:
 */
@RestController
@Slf4j
@Api(value = "粮食安全行政首长责任制-----考核评分权重", tags = "粮食安全行政首长责任制：考核评分权重")
@RequestMapping("/scoringWeight")
public class BizRespScoringWeightController {
    @Autowired
    private BizRespScoringWeightService bizRespScoringWeightService;


    /**
     * 保存数据---核评分权重
     * @param weightSaveVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "核评分权重----保存", notes = "参数：考核评分权重 scoringWeightVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody WeightSaveVO weightSaveVO
    ) {
        System.out.println("保存=====考核评分权重==="+weightSaveVO.toString());
        try {

            BizRespScoringWeight weight=bizRespScoringWeightService.findByYear(weightSaveVO.getWeightVO().getYear());
            if(weight!=null){
                return ResponseWrapper.error(504, "核评分权重年分已存在!",null);
            }

            boolean flag = bizRespScoringWeightService.save(weightSaveVO);
            if (!flag) {
                return ResponseWrapper.error("保存失败!");
            }
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("考核评分权重，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }








    /**
     * 考核评分权重--考核等级设置
     * @return
     */
    @ApiOperation(value = "考核评分权重--考核等级设置", notes = " type  save  update")
    @GetMapping(value = "/findByWeightRank/{type}/{id}")
    public ResponseWrapper findByWeightRank(
            @PathVariable("type") String  type,
            @PathVariable("id") String  id
    ) {
        try {
            List<BizRespScoringWeightRankVO> mapList=bizRespScoringWeightService.findByWeightRank(type, id);
            return ResponseWrapper.success(200, "查询成功", mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     * 考核评分权重--查询可选年分
     * @return
     */
    @ApiOperation(value = "考核评分权重--查询可选年分", notes = "type: save 新增 page 分页查询  ")
    @GetMapping(value = "/findByYear/{type}")
    public ResponseWrapper findByYear(
            @PathVariable("type") String  type
    ) {
        try {
            List<Integer> mapList=bizRespScoringWeightService.findByAll(type);
            return ResponseWrapper.success(200, "查询成功", mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }

    /**
     * 考核评分权重--查询复制评分表可选年分
     * @return
     */
    @ApiOperation(value = "考核评分权重--查询复制评分表可选年分", notes = "type: save 新增 page 分页查询  ")
    @GetMapping(value = "/findByCopyYear")
    public ResponseWrapper findByCopyYear(
    ) {
        try {
            Map mapList=bizRespScoringWeightService.findByCopyYear();
            return ResponseWrapper.success(200, "查询成功", mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }





    /**
     *  根据年分和状态---考核评分权重--对象
     * @return
     */
    @ApiOperation(value = "根据年分和状态---考核评分权重--对象", notes = "")
    @GetMapping(value = "/findByYearAndStatus/{year}/{status}")
    public ResponseWrapper findByYearAndStatus(
            @PathVariable("year") Integer  year,
            @PathVariable("status") Integer  status
    ) {
        try {
            BizRespScoringWeight weightDO=bizRespScoringWeightService.findByYearAndStatus(year, status);
            return ResponseWrapper.success(200, "查询成功", weightDO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }







    /**
     * 核评分权重----分页
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "核评分权重----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody BizRespScoringWeightPageVO pageVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizRespScoringWeightService.findByPage(pageVO, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("核评分权重分页模糊查询信息{}", e.getMessage());
            return ResponseWrapper.error(500, "核评分权重分页模糊查询信息失败",null);
        }
    }





    /**
     * 根据id查询考核内容--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "核评分权重---查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            Map map=new HashMap();
            //考核评分权重
            WeightInfoVO weightInfoVO=bizRespScoringWeightService.findById(id);
            //考核评分权重--考核等级
            List<BizRespScoringWeightRankVO> weightRankVO=bizRespScoringWeightService.findByRankId(id);
            weightInfoVO.setWeightRankList(weightRankVO);
            return ResponseWrapper.success(200, "查询成功", weightInfoVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }



    /**
     * 保存数据---核评分权重
     * @param weightUpdateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "核评分权重---修改", notes = "参数：考核评分权重 scoringWeightVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody WeightUpdateVO weightUpdateVO
    ) {
        System.out.println("保存=====考核评分权重==="+weightUpdateVO.toString());
        try {
            boolean flag = bizRespScoringWeightService.update(weightUpdateVO);
            if (!flag) {
                return ResponseWrapper.error("保存失败!");
            }
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("考核评分权重，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "核评分权重---发布", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody BizRespScoringWeightPublishVO publishVO
    ) {
        try {
            bizRespScoringWeightService.publish(publishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }



    /**
     * 删除考核评分权重
     *
     * @param deleteVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "核评分权重---删除", notes = "参数")
    @DeleteMapping(value = "/delete")
    public ResponseWrapper delete(@RequestBody DeleteVO deleteVO) {
        try {
            Boolean flag = bizRespScoringWeightService.delete(deleteVO);
            if (!flag) {
                return ResponseWrapper.error(300, "参数错误，删除失败",null);
            }
            return ResponseWrapper.success(200, "用户信息删除成功",null);
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息删除失败",null);
        }
    }



}