package com.unis.accountability.businessmanagement.controller;
import java.util.List;

import javax.servlet.http.HttpServletResponse;

import com.unis.accountability.businessmanagement.common.vo.manageRuler.MangerRulesReceviceVO;
import com.unis.accountability.businessmanagement.common.vo.manageRuler.MangerRulesVO;
import com.unis.accountability.businessmanagement.common.vo.manageRuler.PageResult;
import com.unis.accountability.businessmanagement.service.MangerRulesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 粮食与物资储备管理制度
 * 
 * @author liuweilong
 *
 */
@RestController
@RequestMapping("/MaterialManagement")
@Api(value = "粮食与物资储备管理制度", tags = "粮食与物资储备管理制度")
public class MangerRulesController {

	@Autowired
	private MangerRulesService mangerRulesService;

	// 新增
	@ApiOperation(value = "保存")
	@PostMapping("/save")
	public ResponseWrapper insert(@RequestBody MangerRulesVO vo) {
		
	    try {
	    	mangerRulesService.insertEntity(vo);
	    	
	    	return ResponseWrapper.success();
			
		} catch (Exception e) {
			
			e.printStackTrace();
			
			return ResponseWrapper.error("保存失败");
		}
		
	}

	// 编辑
	@ApiOperation(value = "编辑")
	@PostMapping("/update")
	public ResponseWrapper update(@RequestBody MangerRulesVO vo) {
		
       Integer updateCode = mangerRulesService.update(vo);
		
		if(updateCode>0) {
			
			return ResponseWrapper.success();
		}
		
		return ResponseWrapper.error("编辑失败");
	}

	// 下发文件
	@ApiOperation(value = "下发")
	@PostMapping("/issue")
	public ResponseWrapper issue(@RequestBody MangerRulesReceviceVO vo) {

		try {
			mangerRulesService.issue(vo);
			
			return ResponseWrapper.success();
			
		} catch (Exception e) {
			
			e.printStackTrace();
		}

		return ResponseWrapper.error();
	}

	// 下载
	@ApiOperation(value = "下载")
	@PostMapping("/downLoad/{realPath}")
	public ResponseWrapper downLoad(HttpServletResponse response, @PathVariable("realPath") String realPath) {

		try {
			mangerRulesService.downLoad(response, realPath);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	// 删除
	@ApiOperation(value = "删除")
	@GetMapping("/delete/{zdbm}")
	public ResponseWrapper delete(@PathVariable("zdbm") String zdbm) {

		try {
			mangerRulesService.deleteBYPrimaryKey(zdbm);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	// 查看
	@ApiOperation(value = "查看")
	@GetMapping("/getInformation/{zdbm}")
	public ResponseWrapper getInformation(@PathVariable("zdbm") String zdbm) {

		try {
			return ResponseWrapper.success(mangerRulesService.getInfomationByPrimarykey(zdbm));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	
	
	
	// 获取列表
	@ApiOperation(value = "查询列表")
	@ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "页大小", dataType = "int", paramType = "query"),
			@ApiImplicitParam(name = "wjmc", value = "文件名称", required = false, paramType = "query"),
			@ApiImplicitParam(name = "scrq", value = "上传日期", required = false, paramType = "query") })
	@PostMapping(value = "/selectList")
	public ResponseWrapper selectList(@RequestParam(value = "pageNum",defaultValue = "1" ) int pageNum,
			@RequestParam(value = "pageSize",defaultValue = "10") int pageSize,
			@RequestParam(value = "wjmc", required = false) String wjmc,
			@RequestParam(value = "scrq", required = false) String scrq,
			@RequestParam(value = "orgId", required = false) String orgId,
			@RequestBody List<String> orgCode
			) {

		try {
			PageResult<MangerRulesVO> pg = mangerRulesService.getList(pageNum, pageSize, wjmc, scrq,orgCode,orgId);
			
			if(pg==null) {
				
			return ResponseWrapper.error(HttpStatus.NO_CONTENT.value(),HttpStatus.NO_CONTENT.name(),null);
			}
			
			return ResponseWrapper.success(pg);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}

	}
	
	 
	 /**
	  * 
	      * @Title: getJsbmByzdbm
	      * @Description: 根据zdbm获取接收部门编码
	      * @param @param zdbm
	      * @param @return 参数
	      * @return ResponseWrapper 返回类型
	      * @throws
	  */
	 @ApiOperation(value = "根据主表Id获取接收部门id")
	 @GetMapping("/getJsbm/{zdbm}")
	 public ResponseWrapper getJsbmByzdbm(@PathVariable("zdbm")String zdbm) {
		 try {
			 
			 String jsbmByzdbm = mangerRulesService.getJsbmByzdbm(zdbm);
			 
			 return ResponseWrapper.success(jsbmByzdbm);
			
		} catch (Exception e) {
			
			e.printStackTrace();
			
			return ResponseWrapper.error();
		}
		 
	 }
	
}
