package com.unis.accountability.businessmanagement.controller;
import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.msgNotice.*;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BilityUpdateVO;
import com.unis.accountability.businessmanagement.service.MsgNoticeService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/11/5 0005 14:21
 * @Description:
 */
@RestController
@RequestMapping("/msgNotice")
@Slf4j
@Api(value = "信息报送--信息报送", tags = "信息报送--信息报送")
public class MsgNoticeController {

    @Autowired
    private MsgNoticeService msgNoticeService;



    /**
     * 保存数据 信息报送
     *
     * @param msgNoticeSaveVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送----保存", notes = "参数：考核内容 MsgNoticeSaveVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody MsgNoticeSaveVO msgNoticeSaveVO
    ) {
        System.out.println("保存=====信息报送==="+msgNoticeSaveVO.toString());
        try {
            boolean flag = msgNoticeService.save(msgNoticeSaveVO);
            if (!flag) {
                return ResponseWrapper.error("对象已存在无法添加");
            }
            return ResponseWrapper.success(200, "保存成功", null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }



    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "信息报送----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody MsgNoticePage msgNoticePage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = msgNoticeService.findByPage(msgNoticePage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                String dataJson= JSON.toJSONString(result);
                return ResponseWrapper.success(200, "查询成功", dataJson);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送---报送", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody MsgNoticePublishVO publishVO
    ) {
        try {
             msgNoticeService.publish(publishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }

    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送---批量采用", notes = "参数：")
    @PostMapping(value = "/publishALL")
    public ResponseWrapper publishALL(
            @RequestBody MsgNoticePublishVO publishVO
    ) {
        try {
            msgNoticeService.publishALL(publishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }


    /**
     *信息报送----查看
     * @param
     * @return
     */
    @ApiOperation(value = "信息报送----查看", notes = "参数：msgNoticeReadVO ")
    @PostMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String id
    ) {
        try {
            MsgNoticeVO msgNoticeVO=msgNoticeService.findById(id);
            System.out.println("信息报送----查看" + msgNoticeVO.toString());
            String dataJson= JSON.toJSONString(msgNoticeVO);
            return ResponseWrapper.success(200, "msgNoticeVO", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     *信息报送----查看
     * @param
     * @return
     */
    @ApiOperation(value = "信息报送----查看", notes = "参数：msgNoticeReadVO ")
    @GetMapping(value = "/findByInfo/{id}")
    public ResponseWrapper findByInfo(
            @PathVariable("id") String  id
    ) {
        try {
            MsgNoticeVO msgNoticeVO=msgNoticeService.findByInfo(id);
            System.out.println("信息报送----查看" + msgNoticeVO.toString());
            String dataJson= JSON.toJSONString(msgNoticeVO);
            return ResponseWrapper.success(200, "msgNoticeUserVO", dataJson);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     * 信息报送----修改
     *
     * @param msgNoticeUpdateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送----修改", notes = "参数：信息报送 msgNoticeUpdateVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody MsgNoticeUpdateVO msgNoticeUpdateVO
    ) {
        System.out.println("信息报送----修改==="+msgNoticeUpdateVO.toString());
        try {
            boolean flag = msgNoticeService.update(msgNoticeUpdateVO);
            if (!flag) {
                return ResponseWrapper.error("信息报送保存失败");
            }
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }

    /**
     * 多选删除
     *
     * @param msgNoticeReadVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送----删除", notes = "参数：考核内容ids(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(@RequestBody DeleteVO deleteVO) {
        try {
            Boolean flag = msgNoticeService.deletes(deleteVO);
            if (!flag) {
                return ResponseWrapper.error(521, "信息简报删除失败", null);
            }
            return ResponseWrapper.success(200, "信息简报删除功", null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "信息报送删除失败",null);
        }
    }


}