package com.unis.accountability.businessmanagement.controller;

import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentPage;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentSaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BigTaskQueryVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BigTaskVO;
import com.unis.accountability.businessmanagement.common.vo.opinion.BizRespDepartmentalOpinionVO;
import com.unis.accountability.businessmanagement.service.BizRespExaminationContentService;
import com.unis.accountability.businessmanagement.service.ProvinceLeadDeptService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Auther:邹杰利
 * @Date: 2019/9/20
 * @Description:省级牵头部门
 */
@RestController
@Slf4j
@Api(value = "盟市长责任制--省级牵头部门", tags = "盟市长责任制--省级牵头部门")
public class ProvinceLeadDeptController {

    @Autowired
    private ProvinceLeadDeptService provinceLeadDeptService;

    /**
     * @author 邹杰利
     * @param bigTaskQueryVO
     * @param pageNum
     * @param pageSize
     * @return
     */
    @ApiOperation(value = "盟市长责任制--省级牵头部门/配合部门--条件分页查询", notes = "参数：")
    @PostMapping(value = "/provinceLeadDept/{pageNum}/{pageSize}")
    public ResponseWrapper getProvinceLeadDept(@RequestBody BigTaskQueryVO bigTaskQueryVO,
                                               @PathVariable("pageNum") Integer pageNum,
                                               @PathVariable("pageSize") Integer pageSize){
        try {
            Map resultMap = provinceLeadDeptService.getProvinceLeadDept(bigTaskQueryVO,pageNum,pageSize);
            return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", resultMap);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }

    @ApiOperation(value = "盟市长责任制--省级牵头部门--根据任务id查询省级配合部门意见", notes = "参数：id")
    @GetMapping(value = "/provinceCoordinateOpinion/{id}/{areaCode}/{coordinateDeptId}")
    public ResponseWrapper getProvinceCoordinateOpinion(@PathVariable("id") String id,
                                                        @PathVariable("areaCode") String areaCode,
                                                        @PathVariable("coordinateDeptId") String coordinateDeptId){
        try {
            Map<String, Object> resultMap = new HashMap<>();
            resultMap.put("id",id);
            resultMap.put("areaCode",areaCode);
            resultMap.put("coordinateDeptId",coordinateDeptId);
            List<BizRespDepartmentalOpinionVO> opinionVO = provinceLeadDeptService.getProvinceCoordinateOpinion(resultMap);
            return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", opinionVO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }


    @ApiOperation(value = "盟市长责任制--省级牵头部门--根据任务id查询省级牵头部门意见", notes = "参数：id")
    @GetMapping(value = "/provinceLeadOpinion/{id}/{areaCode}")
    public ResponseWrapper getProvinceLeadOpinion(@PathVariable("id") String id,
                                                  @PathVariable("areaCode") String areaCode){
        try {
            Map<String, Object> resultMap = new HashMap<>();
            resultMap.put("id",id);
            resultMap.put("areaCode",areaCode);
            BizRespDepartmentalOpinionVO opinionVO = provinceLeadDeptService.getProvinceLeadOpinion(resultMap);
            return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", opinionVO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }

    @ApiOperation(value = "盟市长责任制--省级牵头部门--根据任务id查询省级牵头部门复评意见", notes = "参数：id")
    @GetMapping(value = "/provinceLeadAgainOpinion/{id}/{areaCode}")
    public ResponseWrapper getProvinceLeadAgainOpinion(@PathVariable("id") String id,
                                                       @PathVariable("areaCode") String areaCode){
        try {
            Map<String, Object> resultMap = new HashMap<>();
            resultMap.put("id",id);
            resultMap.put("areaCode",areaCode);
            BizRespDepartmentalOpinionVO opinionVO = provinceLeadDeptService.getProvinceLeadAgainOpinion(resultMap);
            return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", opinionVO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }

    @ApiOperation(value = "盟市长责任制--省级牵头部门--更新省级牵头/配合部门意见", notes = "参数：BizRespDepartmentalOpinionVO")
    @PutMapping(value = "/bizRespDepartmentalOpinion")
    public ResponseWrapper updateBizRespDepartmentalOpinion(@RequestBody BizRespDepartmentalOpinionVO bizRespDepartmentalOpinionVO){
        try {
            if (bizRespDepartmentalOpinionVO.getId() == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "更新失败，有必传参数为空", null);
            }
            provinceLeadDeptService.updateBizRespDepartmentalOpinion(bizRespDepartmentalOpinionVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), "更新成功", null);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "更新失败", null);
        }
    }


    @ApiOperation(value = "盟市长责任制--省级牵头部门--新增省级牵头部门复评分", notes = "参数：BizRespDepartmentalOpinionVO")
    @PostMapping(value = "/provinceLeadOpinion")
    public ResponseWrapper insertProvinceLeadOpinion(@RequestBody BizRespDepartmentalOpinionVO bizRespDepartmentalOpinionVO){
        try {
            provinceLeadDeptService.insertProvinceLeadOpinion(bizRespDepartmentalOpinionVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), "添加成功", null);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "添加失败", null);
        }
    }


    @ApiOperation(value = "盟市长责任制--省级牵头/配合部门--批量上报", notes = "参数：taskId")
    @PutMapping(value = "/provinceLeadOpinion/{year}/{type}/{updateBy}")
    public ResponseWrapper updateTaskStatus(@PathVariable(value = "year") Integer year,
                                            @PathVariable(value = "type") String type,
                                            @PathVariable(value = "updateBy") String updateBy){
        try{
            Map<Object, Object> selectMap = new HashMap<>();
            selectMap.put("year",year);
            selectMap.put("type",type);
            selectMap.put("updateBy",updateBy);
            provinceLeadDeptService.updateTaskStatus(selectMap);
            return ResponseWrapper.success(HttpStatus.OK.value(), "上报成功", null);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "上报失败", null);
        }
    }

//    @ApiOperation(value = "盟市长责任制--省级配合部门--上报", notes = "参数：taskId")
//    @PutMapping(value = "/provinceCoordinateOpinionStatus/{oids}")
//    public ResponseWrapper updateProvinceCoordinateOpinionStatus(@PathVariable(value = "oids") String oids){
//        try {
//            provinceLeadDeptService.updateProvinceCoordinateOpinionStatus(oids);
//            return ResponseWrapper.success(HttpStatus.OK.value(), "上报成功", null);
//        } catch (Exception e) {
//            log.error(e.getMessage());
//            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "上报失败", null);
//        }
//    }
}