package com.unis.accountability.businessmanagement.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BigTaskQueryVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BigTaskVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.ProvinceLeadVO;
import com.unis.accountability.businessmanagement.common.vo.opinion.BizRespDepartmentalOpinionVO;
import com.unis.accountability.businessmanagement.entity.BizRespDepartmentalOpinion;
import com.unis.accountability.businessmanagement.mapper.BizRespDepartmentalOpinionMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationTaskMapper;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UUIDUtils;
import lombok.Data;
import lombok.ToString;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.*;

/**
 * @Author zoujieli
 * @Description
 * @Date 2019/9/20 18:29
 * Version 1.0
 */
@Data
@Component
@ToString
public class ProvinceLeadDeptDomain {

    @Autowired
    private BizRespExaminationTaskMapper taskMapper;
    @Autowired
    private BizRespDepartmentalOpinionMapper opinionMapper;

    /**
     * 盟市长责任制--省级牵头部门--条件分页查询
     * @author 邹杰利
     * @param bigTaskQueryVO
     * @param pageNum
     * @param pageSize
     * @return
     */
    public Map getProvinceLeadDept(BigTaskQueryVO bigTaskQueryVO, Integer pageNum, Integer pageSize) {

        int cancal = 0;

        Map resultMap = new HashMap<>();
        List<ProvinceLeadVO> provinceLeadVOList = null;
        PageInfo<ProvinceLeadVO> pageInfo = null;

        if ("20".equals(bigTaskQueryVO.getType())){
            //查询省级牵头部门意见
            PageHelper.startPage(pageNum,pageSize);
            provinceLeadVOList = opinionMapper.getProvinceLeadVO(bigTaskQueryVO);
            pageInfo = new PageInfo<>(provinceLeadVOList);

            if (provinceLeadVOList != null && provinceLeadVOList.size() > 0) {
                for (int i = 0; i < provinceLeadVOList.size(); i++) {
                    for (int j = i + 1; j < provinceLeadVOList.size(); j++) {
                        ProvinceLeadVO voi = provinceLeadVOList.get(i);
                        ProvinceLeadVO voj = provinceLeadVOList.get(j);
                        if (voi.getAreaCode().equals(voj.getAreaCode()) && voi.getTaskName().equals(voj.getTaskName())) {
                            if ("20".equals(voi.getType())) {
                                provinceLeadVOList.remove(i);
                                cancal++;
                            } else if ("20".equals(voj.getType())) {
                                provinceLeadVOList.remove(j);
                                cancal++;//记录移除的数量
                            }
                        }
                    }
                }
            }
        }else {
            //查询省级配合部门意见
            PageHelper.startPage(pageNum,pageSize);
            provinceLeadVOList = opinionMapper.getProvinceCoordinateVO(bigTaskQueryVO);
            pageInfo = new PageInfo<>(provinceLeadVOList);
        }

        resultMap.put("total",pageInfo.getTotal()-cancal);
        resultMap.put("provinceLeadVOList",provinceLeadVOList);

        return resultMap;
    }

    /**
     * 盟市长责任制--省级牵头部门--根据任务id查询详情
     * @author 邹杰利
     * @param id
     * @return
     */
    public BigTaskVO getProvinceLeadDeptDetail(String id) {
        BigTaskVO bigTaskVO = taskMapper.getProvinceLeadDeptDetail(id);

        //todo 查询州市的评分并装进bigTaskVO中

        return bigTaskVO;
    }

    /**
     * 盟市长责任制--省级牵头部门--更新省级牵头/配合部门评分
     * @author 邹杰利
     * @param bizRespDepartmentalOpinionVO
     */
    public void updateBizRespDepartmentalOpinion(BizRespDepartmentalOpinionVO bizRespDepartmentalOpinionVO) {

        //更新省级牵头部门评分
        BizRespDepartmentalOpinion bizRespDepartmentalOpinion = new BizRespDepartmentalOpinion();
        LsBeanUtils.copyAllProperties(bizRespDepartmentalOpinionVO, bizRespDepartmentalOpinion);
        opinionMapper.updateLeadOpinion(bizRespDepartmentalOpinion);

        if ("20".equals(bizRespDepartmentalOpinionVO.getType())) {
            //更新任务状态为已上报10
            Map<String, Object> selectMap = new HashMap<>();
            String tid = bizRespDepartmentalOpinionVO.getBizResexaminationTaskId();
            if (StringUtils.isNotEmpty(tid)) {
                selectMap.put("updateBy", bizRespDepartmentalOpinionVO.getUpdateBy());
                selectMap.put("updateTime", bizRespDepartmentalOpinionVO.getUpdateTime());
                selectMap.put("tid", tid);
                taskMapper.updateTaskStatus(selectMap);
            }
        }
    }

    /**
     * 盟市长责任制--省级牵头部门--根据任务id查询省级配合部门意见
     * @author 邹杰利
     * @param selectMap
     * @return
     */
    public List<BizRespDepartmentalOpinionVO> getProvinceCoordinateOpinion(Map selectMap) {
        List<BizRespDepartmentalOpinion> bizRespDepartmentalOpinionList = opinionMapper.getProvinceCoordinateOpinion(selectMap);
        List<BizRespDepartmentalOpinionVO> opinionVOList = new ArrayList<>();
        if (bizRespDepartmentalOpinionList != null && !bizRespDepartmentalOpinionList.isEmpty()){
            for (BizRespDepartmentalOpinion opinion: bizRespDepartmentalOpinionList){
                BizRespDepartmentalOpinionVO bizRespDepartmentalOpinionVO = new BizRespDepartmentalOpinionVO();
                LsBeanUtils.copyAllProperties(opinion,bizRespDepartmentalOpinionVO);
                opinionVOList.add(bizRespDepartmentalOpinionVO);
            }
        }
        return opinionVOList;
    }


    /**
     * 盟市长责任制--省级牵头部门--根据任务id查询省级牵头部门意见
     * @author 邹杰利
     * @param result
     * @return
     */
    public BizRespDepartmentalOpinionVO getProvinceLeadOpinion(Map result) {
        BizRespDepartmentalOpinion bizRespDepartmentalOpinion = opinionMapper.getProvinceLeadOpinion(result);
        BizRespDepartmentalOpinionVO opinionVO = new BizRespDepartmentalOpinionVO();

        if (bizRespDepartmentalOpinion != null){
            LsBeanUtils.copyAllProperties(bizRespDepartmentalOpinion,opinionVO);
        }

        return opinionVO;
    }

    /**
     * 盟市长责任制--省级牵头部门--新增省级牵头部门复评分
     * @author 邹杰利
     * @param bizRespDepartmentalOpinionVO
     */
    public void insertProvinceLeadOpinion(BizRespDepartmentalOpinionVO bizRespDepartmentalOpinionVO) {

        BizRespDepartmentalOpinion bizRespDepartmentalOpinion = new BizRespDepartmentalOpinion();
        LsBeanUtils.copyAllProperties(bizRespDepartmentalOpinionVO,bizRespDepartmentalOpinion);

        bizRespDepartmentalOpinion.setId(UUIDUtils.uuid());
        opinionMapper.insertSelective(bizRespDepartmentalOpinion);
    }

    /**
     * 省级牵头/配合部门--批量上报
     * @author 邹杰利
     * @param selectMap
     */
    public void updateTaskStatus(Map selectMap) {
        String oid = null;
        String tid = null;
        selectMap.put("updateTime",new Date());
        List<ProvinceLeadVO> provinceLeadVOList = null;

        if ("20".equals(selectMap.get("type"))) {
            //获得省级牵头部门待上报的意见

            provinceLeadVOList = opinionMapper.getProvinceLeadVOByStatus(selectMap);
            //遍历list集合，更新任务表和意见表
            if (provinceLeadVOList != null && !provinceLeadVOList.isEmpty()) {
                for (ProvinceLeadVO provinceLeadVO : provinceLeadVOList) {
                    oid = provinceLeadVO.getOid();
                    tid = provinceLeadVO.getId();
                    selectMap.put("oid",oid);
                    selectMap.put("tid",tid);
                    opinionMapper.updateOpinionStatus(selectMap);
                    taskMapper.updateTaskStatus(selectMap);
                }
            }
        }else if ("10".equals(selectMap.get("type"))){
            //获得省级配合部门待上报的意见
            provinceLeadVOList = opinionMapper.getProvinceLeadVOByStatus(selectMap);
            //遍历list集合，更新意见表
            for (ProvinceLeadVO provinceLeadVO : provinceLeadVOList){
                oid = provinceLeadVO.getOid();
                selectMap.put("oid",oid);
                opinionMapper.updateOpinionStatus(selectMap);
            }
        }
    }

        //更新任务状态
//        String[] taskIdsArr = null;
//
//        if (StringUtils.isNotEmpty(taskIds)) {
//            if (taskIds.contains(",")) {
//                taskIdsArr = taskIds.split(",");
//            } else {
//                taskIdsArr = new String[]{taskIds};
//            }
//        }
//        for (String taskId: taskIdsArr) {
//            taskMapper.updateTaskStatus(taskId);
//        }
//
//        //更新意见表状态
//        String[] oidsArr = null;
//
//        if (StringUtils.isNotEmpty(oids)){
//            if (taskIds.contains(",")){
//                oidsArr = oids.split(",");
//            }else {
//                oidsArr = new String[]{oids};
//            }
//        }
//        for (String oid: oidsArr){
//            opinionMapper.updateOpinionStatus(oid);
//        }
//    }

    /**
     * 省级配合部门--上报
     * @author 邹杰利
     * @param oids
     */
//    public void updateProvinceCoordinateOpinionStatus(String oids) {
//        //更新意见表状态
//        String[] oidsArr = null;
//
//        if (StringUtils.isNotEmpty(oids)){
//            if (oids.contains(",")){
//                oidsArr = oids.split(",");
//            }else {
//                oidsArr = new String[]{oids};
//            }
//        }
//        for (String oid: oidsArr){
//            opinionMapper.updateOpinionStatus(oid);
//        }
//    }

    /**
     * 根据任务id查询省级牵头部门复评意见
     * @author 邹杰利
     * @param resultMap
     * @return
     */
    public BizRespDepartmentalOpinionVO getProvinceLeadAgainOpinion(Map<String, Object> resultMap) {
        BizRespDepartmentalOpinion bizRespDepartmentalOpinion = opinionMapper.getProvinceLeadAgainOpinion(resultMap);
        BizRespDepartmentalOpinionVO opinionVO = new BizRespDepartmentalOpinionVO();

        if (bizRespDepartmentalOpinion != null){
            LsBeanUtils.copyAllProperties(bizRespDepartmentalOpinion,opinionVO);
        }

        return opinionVO;
    }
}
