package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPage;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPageVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.*;
import com.unis.accountability.businessmanagement.entity.BizRespDepartmentalOpinion;
import com.unis.accountability.businessmanagement.entity.BizRespScoreInput;
import com.unis.accountability.businessmanagement.entity.BizRespScoringCity;
import com.unis.accountability.businessmanagement.entity.BizRespScoringWeight;
import com.unis.accountability.businessmanagement.mapper.BizRespCityZpbmServiceMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespDepartmentalOpinionMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespScoreInputMapper;
import com.unis.accountability.businessmanagement.service.BizRespCityPhbmService;
import com.unis.accountability.businessmanagement.service.BizRespDepartmentalOpinionService;
import com.unis.accountability.businessmanagement.service.BizRespScoringCityService;
import com.unis.accountability.businessmanagement.service.BizRespScoringWeightService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

/**
 * @Auther:张新亮
 * @Date: 2019/9/21 0021 14:57
 * @Description:
 */
@Service
@Transactional
public class BizRespCityPhbmServiceImpl implements BizRespCityPhbmService {
    @Autowired
    private BizRespCityZpbmServiceMapper bizRespCityZpbmServiceMapper;
    @Autowired
    private BizRespScoreInputMapper bizRespScoreInputMapper;
    @Autowired
    private BizRespDepartmentalOpinionService bizRespDepartmentalOpinionService;
    @Autowired
    private BizRespDepartmentalOpinionMapper bizRespDepartmentalOpinionMapper;
    @Autowired
    private BizRespScoringWeightService bizRespScoringWeightService;
    /**
     * 粮食安全行政首长责任制----市级配合部门----分页
     * @param cityPhbmPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<CityPhbmPageVO>> findByPage(
            CityPhbmPage cityPhbmPage,
            Integer page,
            Integer size
    ) {
        Page<List<CityPhbmPageVO>> listPage = PageHelper.startPage(page, size);
        System.out.println("接口参数=="+cityPhbmPage.toString());
        List<CityPhbmPageVO> mapLists=bizRespCityZpbmServiceMapper.findByPhbmPage(cityPhbmPage);
        String ifpf="no";
        for(CityPhbmPageVO cityPhbmPageVO:mapLists){
            BizRespScoringWeight bizRespScoringWeight=bizRespScoringWeightService.findByYearAndStatus(Integer.valueOf(cityPhbmPageVO.getYear()), 1);
            if(bizRespScoringWeight!=null){
                ifpf= bizRespScoringWeightService.weightCompareTo(bizRespScoringWeight, "qjPtbm");
            }
            cityPhbmPageVO.setIfPf(ifpf);
        }

        return listPage.toPageInfo();
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门----查看
     * @param id
     * @return
     */
    @Override
    public PhbmVO findById(String id,String  deptId) {
        BizRespScoreInput bizRespScoreInput=bizRespScoreInputMapper.selectByPrimaryKey(id);
        bizRespScoreInput.setPhbm(deptId);
        PhbmVO phbmVO=bizRespDepartmentalOpinionService.findByPhbmInfo(bizRespScoreInput);
        phbmVO.setOrgId(bizRespScoreInput.getOrgId());
        return phbmVO;
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门---编辑
     * @param phbmUpdateVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean update(PhbmUpdateVO phbmUpdateVO) {
        System.out.println("接口参数=="+phbmUpdateVO.toString());
        return bizRespDepartmentalOpinionService.updatePhbm(phbmUpdateVO);
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门---提交
     * @param cityZpbmPublishVO
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public void publish(CityZpbmPublishVO cityZpbmPublishVO) {
        System.out.println("接口参数=="+cityZpbmPublishVO.toString());
        BizRespScoreInput bizRespScoreInput=bizRespScoreInputMapper.selectByPrimaryKey(cityZpbmPublishVO.getId());
        String id=bizRespScoreInput.getId();
        String areaCode=bizRespScoreInput.getAreaCode();
        String deptId=cityZpbmPublishVO.getDeptId();
        if(bizRespScoreInput.getResultStatus()==1){
            throw new RuntimeException("考核结果已发布，不允许自评");
        }
        String type="40";
        BizRespDepartmentalOpinion opinion=bizRespDepartmentalOpinionMapper.findByCityInfo(id, areaCode, deptId, type);
        opinion.setStatus("30");
        opinion.setUpdateBy(cityZpbmPublishVO.getUpdateBy());
        opinion.setUpdateTime(new Date());
        bizRespDepartmentalOpinionMapper.updateByPrimaryKeySelective(opinion);
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门---批量提交
     * @param cityZpbmPublishVO
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public void publishALL(CityZpbmPublishVO cityZpbmPublishVO) {
        System.out.println("接口参数=="+cityZpbmPublishVO.toString());
        //查询州市自评部门已填报的数据
        List<publishAllVO> publishAllVOList=bizRespCityZpbmServiceMapper.findByPhbmYearAndDeptId(cityZpbmPublishVO);
        for(publishAllVO publishAllVO:publishAllVOList){
            BizRespDepartmentalOpinion opinion=bizRespDepartmentalOpinionMapper.selectByPrimaryKey(publishAllVO.getOpinionId());
            opinion.setStatus("30");
            opinion.setUpdateBy(cityZpbmPublishVO.getUpdateBy());
            opinion.setUpdateTime(new Date());
            bizRespDepartmentalOpinionMapper.updateByPrimaryKeySelective(opinion);
        }
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门---根据年份部门状态查询明细
     * @param cityPhbmPage
     * @return
     */
    @Override
    public List<CityPhbmPageVO> fidByYearAndDeptIdAndStatus(CityPhbmPage cityPhbmPage) {
        System.out.println("接口参数=="+cityPhbmPage.toString());
        return bizRespCityZpbmServiceMapper.findByPhbmPage(cityPhbmPage);
    }
}