package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.*;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPage;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPageVO;
import com.unis.accountability.businessmanagement.common.vo.provincePhbm.ProvincePhbmPublishVO;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespScoreInputSmiitVO;
import com.unis.accountability.businessmanagement.entity.BizRespDepartmentalOpinion;
import com.unis.accountability.businessmanagement.entity.BizRespExaminationTask;
import com.unis.accountability.businessmanagement.entity.BizRespScoreInput;
import com.unis.accountability.businessmanagement.mapper.BizRespCityTaskDistributionMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespCityZpbmServiceMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationTaskMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespScoreInputMapper;
import com.unis.accountability.businessmanagement.service.*;
import com.unis.common.utils.DateUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/9/20 0020 13:58
 * @Description:
 */
@Service
@Transactional
public class BizRespCityTaskDistributionServcieImpl implements BizRespCityTaskDistributionService {

    @Autowired
    private BizRespCityTaskDistributionMapper bizRespCityTaskDistributionMapper;
    @Autowired
    private BizRespScoreInputMapper bizRespScoreInputMapper;
    @Autowired
    private BizRespDepartmentalOpinionService bizRespDepartmentalOpinionService;
    @Autowired
    private BizRespProvinceTaskService bizRespProvinceTaskService;
    @Autowired
    private BizRespExaminationTaskMapper bizRespExaminationTaskMapper;


    /**
     * 粮食安全行政首长责任制----州市任务分配管理----分页
     * @param cityTaskPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<CityTaskDistributionPageVO>> findByPage(
            CityTaskPage cityTaskPage,
            Integer page,
            Integer size
    ) {
        System.out.println("接口参数=="+cityTaskPage.toString());
        Page<List<CityTaskDistributionPageVO>> listPage = PageHelper.startPage(page, size);
        List<CityTaskDistributionPageVO> mapLists=bizRespCityTaskDistributionMapper.findByPage(cityTaskPage);
        return listPage.toPageInfo();
    }

    /**
     * 粮食安全行政首长责任制----州市任务分配管理----查看
     * @param id
     * @return
     */
    @Override
    public CityTaskDistributionVO findById(String id) {
       return bizRespCityTaskDistributionMapper.findById(id);
    }


    /**
     * 粮食安全行政首长责任制----州市任务分配管理---编辑
     * @param cityTaskUpdateVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean update(CityTaskUpdateVO cityTaskUpdateVO) {
        System.out.println("接口参数=="+cityTaskUpdateVO.toString());
        BizRespScoreInput bizRespScoreInput= bizRespScoreInputMapper.selectByPrimaryKey(cityTaskUpdateVO.getCityTaskDistributionVO().getIds());
        bizRespScoreInput.setZpbm(cityTaskUpdateVO.getCityTaskDistributionVO().getZpbm());
        bizRespScoreInput.setQtbm(cityTaskUpdateVO.getCityTaskDistributionVO().getQtbm());
        bizRespScoreInput.setPhbm(cityTaskUpdateVO.getCityTaskDistributionVO().getPhbm());
        bizRespScoreInput.setStatus("1");
        bizRespScoreInput.setUpdateBy(cityTaskUpdateVO.getUpdateBy());
        bizRespScoreInput.setUpdateTime(new Date());
        bizRespScoreInput.setDeptId(cityTaskUpdateVO.getDeptId());
        bizRespScoreInput.setOrgId(cityTaskUpdateVO.getOrgId());
        bizRespScoreInputMapper.updateByPrimaryKeySelective(bizRespScoreInput);
        return true;
    }


    /***
     * 粮食安全行政首长责任制----州市任务分配管理---发布
     * @param cityTaskPublishVO
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public void publish(CityTaskPublishVO cityTaskPublishVO) {
        System.out.println("接口参数=="+cityTaskPublishVO.toString());
        BizRespScoreInput bizRespScoreInput= bizRespScoreInputMapper.selectByPrimaryKey(cityTaskPublishVO.getId());
        bizRespScoreInput.setStatus("2");
        bizRespScoreInput.setUpdateBy(cityTaskPublishVO.getUpdateBy());
        bizRespScoreInput.setUpdateTime(new Date());
        bizRespScoreInputMapper.updateByPrimaryKeySelective(bizRespScoreInput);
        bizRespDepartmentalOpinionService.saveCity(bizRespScoreInput, cityTaskPublishVO, cityTaskPublishVO.getAreaCode());

    }

    /**
     * 粮食安全行政首长责任制----州市任务分配管理---批量发布
     * @param cityTaskPublishVO
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public void publishALL(CityTaskPublishVO cityTaskPublishVO) {
        System.out.println("接口参数=="+cityTaskPublishVO.toString());
        List<BizRespScoreInput> inputList=bizRespScoreInputMapper.findByYearAndStatusAndAreaCode(cityTaskPublishVO);
        for(BizRespScoreInput bizRespScoreInput:inputList){
            bizRespScoreInput.setStatus("2");
            bizRespScoreInput.setUpdateBy(cityTaskPublishVO.getUpdateBy());
            bizRespScoreInput.setUpdateTime(new Date());
            bizRespScoreInputMapper.updateByPrimaryKeySelective(bizRespScoreInput);
            bizRespDepartmentalOpinionService.saveCity(bizRespScoreInput,cityTaskPublishVO,cityTaskPublishVO.getAreaCode());
        }
    }


    /**
     * 粮食安全行政首长责任制----区自评查看（市局）----分页
     * @param cityTaskPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<Map>> findZpCityByPage(
            CityTaskPage cityTaskPage,
            Integer page,
            Integer size
    ) {
        System.out.println("接口参数=="+cityTaskPage.toString());
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        List<Map> mapList=bizRespCityTaskDistributionMapper.findZpCityByPage(cityTaskPage);
        for(Map map:mapList){
            String bilityId=map.get("bilityid").toString();
            String areaCode=map.get("areacode").toString();
            String year=map.get("year").toString();
           
            //查询区牵头部门总分数
            bizRespProvinceTaskService.findByOpionScore(map, bilityId, areaCode, year, "50", "50");
           
            //查询总数
            BizRespScoreInputSmiitVO scoreInputSmiitVO=new BizRespScoreInputSmiitVO();
            scoreInputSmiitVO.setYear(year);
            scoreInputSmiitVO.setAreaCode(areaCode);
            List<BizRespScoreInput> totalList=bizRespScoreInputMapper.findByIsSubmit(scoreInputSmiitVO);
            map.put("status","2");
            map.put("statusValue","进行中");
            map.put("wcjd","0");
            
            //已提交数据
            scoreInputSmiitVO=new BizRespScoreInputSmiitVO();
            scoreInputSmiitVO.setYear(year);
            scoreInputSmiitVO.setAreaCode(areaCode);
            //scoreInputSmiitVO.setStatus("3");
            scoreInputSmiitVO.setOpStatus("50");
            List<BizRespScoreInput> ytj= bizRespScoreInputMapper.findByIsSubmit(scoreInputSmiitVO);
            if(ytj!=null && ytj.size()>0){
                String wcjd=bizRespProvinceTaskService.getProportion(totalList.size(), ytj.size());
                if("100".equals(wcjd)){
                    map.put("status","3");
                    map.put("statusValue","已完成");
                }
                map.put("wcjd",wcjd);
            }

            List<BizRespExaminationTask> taskList=bizRespExaminationTaskMapper.findByBilityId(bilityId);
            Integer isff= taskList.get(0).getStatus();
            if(10==isff.intValue()){
                map.put("ifkhff","已分发");
            }else{
                map.put("ifkhff","未分发");
            }

            ProvincePhbmPublishVO inputSmiitVO=new ProvincePhbmPublishVO();
            inputSmiitVO.setYear(year);
            inputSmiitVO.setAreaCode(areaCode);
            inputSmiitVO.setType("50");
            inputSmiitVO.setStatus("50");
//            inputSmiitVO.setStatus("40");
            List<BizRespDepartmentalOpinion>  opinionList = bizRespDepartmentalOpinionService.findByFfList(inputSmiitVO);
            if(opinionList!=null && opinionList.size()>0){
                BizRespDepartmentalOpinion opinion=opinionList.get(0);
                String update= DateUtil.DateToStr(opinion.getUpdateTime(), DateUtil.df);
                map.put("updateTime",update);
            }
        }
        return listPage.toPageInfo();
    }

    /**
     * 粮食安全行政首长责任制----区自评查看（市局）---考核分发
     * @param cityTaskPublishVO
     */
    @Override
    public void publishKhff(CityTaskPublishVO cityTaskPublishVO) {
        bizRespScoreInputMapper.publishKhff(cityTaskPublishVO);
    }

    /**
     * 粮食安全行政首长责任制----区自评查看（市局）---是否考核分发
     * @param cityTaskPublishVO
     * @return  yes 可以分发 no 不可以分雪
     */
    @Override
    public String findByIsKhff(CityTaskPublishVO cityTaskPublishVO) {
        cityTaskPublishVO.setStatus("0");
        List<BizRespExaminationTask> taskList=bizRespProvinceTaskService.findByIsKhff(cityTaskPublishVO);
        if(taskList!=null && taskList.size()>0){
            return "yes";
        }else{
            return "no";
        }

    }


}