package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.SaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentPage;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentSaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.AreeExcelVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.BizRespExaminationContentExcelVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.BizRespExcelSaveVO;
import com.unis.accountability.businessmanagement.entity.BizRespExaminationContent;
import com.unis.accountability.businessmanagement.entity.BizRespExaminationTask;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationContentMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationItemMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationTaskMapper;
import com.unis.accountability.businessmanagement.service.BizRespExaminationContentService;
import com.unis.common.utils.LsBeanUtils;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**粮食安全行政首长责任制----考核内容
 * @Auther:张新亮
 * @Date: 2019/9/18 0018 14:52
 * @Description:
 */
@Service
@Transactional
public class BizRespExaminationContentServiceImpl implements BizRespExaminationContentService {
    @Autowired
    private BizRespExaminationContentMapper bizRespExaminationContentMapper;
    @Autowired
    private BizRespExaminationItemMapper bizRespExaminationItemMapper;
    @Autowired
    private BizRespExaminationTaskMapper bizRespExaminationTaskMapper;


    /**
     * 粮食安全行政首长责任制----考核内容----保存
     * @param saveVO
     * @return
     */

    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean save(ContentSaveVO saveVO) {
        BizRespExaminationContent bizRespExaminationContentDO = LsBeanUtils.copyProperties(saveVO.getContentVO(), BizRespExaminationContent.class);
        //创建时间
        bizRespExaminationContentDO.setCreateTime(new Date());
        bizRespExaminationContentDO.setUpdateTime(new Date());
        //创建人
        bizRespExaminationContentDO.setCreateBy(saveVO.getCreateBy());
        //行政区划
        bizRespExaminationContentDO.setAreaCode(saveVO.getAreaCode());
        //机构ID
        bizRespExaminationContentDO.setOrgId(saveVO.getOrgId());
        //部门ID
        bizRespExaminationContentDO.setDeptId(saveVO.getDeptId());
        int result=bizRespExaminationContentMapper.insertSelective(bizRespExaminationContentDO);
        if(result>0){
            return true;
        }
        return false;
    }


    /**
     * 粮食安全行政首长责任制----考核内容----分页
     * @param contentPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<Map>> findByPage(ContentPage contentPage, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        List<Map> mapList=bizRespExaminationContentMapper.findByPage(contentPage);
        for(Map map:mapList){
            String id=map.get("id").toString();
            String isEidt= this.getIfRelease(id);
            String isdelete=this.getIfDelete(id);
            map.put("isEidt",isEidt);
            map.put("isDelete",isdelete);
        }
        return listPage.toPageInfo();
    }

    /**
     * 是否可以删除
     * @param id
     * @return
     */
    private String getIfDelete(String id) {
        List<Map> mapList=bizRespExaminationItemMapper.findByBizRespContentId(id);
        // y 可以删除  n 不呆删除
        if(mapList.size()>0){
            return "N";
        }else{
            return "Y";
        }
    }


    /**
     * 是否可以编辑
     * @param id
     * @return
     */
    private String getIfRelease(String id) {
        List<Map> mapList=this.findIfRelease(id);
        // y 可以删除  n 不呆删除
        if(mapList.size()>0){
            return "N";
        }else{
            return "Y";
        }

    }

    /**
     * 粮食安全行政首长责任制----考核内容----是否可以删除
     * @param id
     * @return
     */
    @Override
    public List<Map> findIfRelease(String id) {
        return  bizRespExaminationContentMapper.findIfRelease(id);
    }


    /**
     * 粮食安全行政首长责任制----考核内容----修改
     * @param updateVO
     * @return
     */

    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean update(ContentUpdateVO updateVO) {
        BizRespExaminationContent bizRespExaminationContentDO = LsBeanUtils.copyProperties(updateVO.getContentVO(), BizRespExaminationContent.class);
        bizRespExaminationContentDO.setId(updateVO.getContentVO().getIds());
        bizRespExaminationContentDO.setUpdateTime(new Date());
        bizRespExaminationContentDO.setUpdateBy(updateVO.getUpdateBy());
        int result= bizRespExaminationContentMapper.updateByPrimaryKeySelective(bizRespExaminationContentDO);
        if(result>0){
            return true;
        }
        return false;
    }

    /**
     * 粮食安全行政首长责任制----考核内容----删除
     * @param deleteVO
     * @return
     */
    /**
     * 批量删除考核内容
     * @param
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public Boolean deletes(DeleteVO deleteVO) {
        for(int i=0;i<deleteVO.getIds().length;i++){
            String id=deleteVO.getIds()[i];
            //查询考核内容是否被使用  只要有一个查询已存在则为删除失败
            List<Map> itemDO=bizRespExaminationItemMapper.findByBizRespContentId(id);
            if(itemDO.size()>0){
                return false;
            }
        }

        for(int i=0;i<deleteVO.getIds().length;i++){
            String id=deleteVO.getIds()[i];
            BizRespExaminationContent bizRespExaminationContentDO=bizRespExaminationContentMapper.selectByPrimaryKey(id);
            if(bizRespExaminationContentDO!=null){
                bizRespExaminationContentDO.setDeleteTime(new Date());
                bizRespExaminationContentDO.setDeleteBy(deleteVO.getDeleteBy());
                bizRespExaminationContentMapper.updateByPrimaryKeySelective(bizRespExaminationContentDO);
            }
        }
        return true;
    }


    /**
     * 粮食安全行政首长责任制----考核内容----根据年份year和组织机构查询好喝内容
     * @param map
     * @return
     */
    @Override
    public List<Map> findByYearAndOrgId(Map map) {
        return bizRespExaminationContentMapper.findByYearAndOrgId(map);
    }

    /**
     * 粮食安全行政首长责任制----考核评分表管理----考核内容
     * @param contentExcelVO
     * @param responsibilityId
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public BizRespExaminationContent getContentData(
            BizRespExaminationContentExcelVO contentExcelVO,
            String responsibilityId,
            SaveVO saveVO
    ) {
        BizRespExaminationContent bizRespExaminationContentDO =new BizRespExaminationContent();
        //创建时间
        bizRespExaminationContentDO.setCreateTime(new Date());
        bizRespExaminationContentDO.setUpdateTime(new Date());
        //创建人
        bizRespExaminationContentDO.setCreateBy(saveVO.getCreateBy());
        //行政区划
        bizRespExaminationContentDO.setAreaCode(saveVO.getAreaCode());
        //部门ID
        bizRespExaminationContentDO.setDeptId(saveVO.getDeptId());
        //部门ID
        bizRespExaminationContentDO.setOrgId(saveVO.getOrgId());
        //考核内容
        bizRespExaminationContentDO.setName(contentExcelVO.getName());
        //考核内容分值
        //填报设置ID
        bizRespExaminationContentDO.setBizRespResponsibilityId(responsibilityId);
        bizRespExaminationContentMapper.insertSelective(bizRespExaminationContentDO);
        return bizRespExaminationContentDO;
    }


    /**
     * 粮食安全行政首长责任制----根据 bizRespResponsibilityId 查询考核内容
     * @param bizRespResponsibilityId
     * @return
     */
    @Override
    public List<BizRespExaminationContentExcelVO> findByRespResponsibilityId(String bizRespResponsibilityId) {
        List<BizRespExaminationContentExcelVO> excelVOList=new ArrayList();
        List<BizRespExaminationContent> contentList=bizRespExaminationContentMapper.findByRespResponsibilityId(bizRespResponsibilityId);
        for(BizRespExaminationContent content:contentList){
            BizRespExaminationContentExcelVO excelVO=new BizRespExaminationContentExcelVO();
            excelVO.setName(content.getName());
            excelVO.setId(content.getId());
            //根据考核内容ID查询子项个数
            List<Map> contentNumber=bizRespExaminationContentMapper.findByContentNumber(content.getId());
            excelVO.setNumber(contentNumber.size());
            excelVOList.add(excelVO);
        }
        return excelVOList;
    }


    /**
     * AreeExcelVO areeExcelVO
     * @param areeExcelVO
     * @return
     */
    @Override
    public List<BizRespExaminationContentExcelVO> findByContentExcel(AreeExcelVO areeExcelVO) {
        List<BizRespExaminationContentExcelVO> excelVOList=new ArrayList();
        List<BizRespExaminationContent> contentList=bizRespExaminationContentMapper.findByContentExcel(areeExcelVO);
        for(BizRespExaminationContent content:contentList){
            BizRespExaminationContentExcelVO excelVO=new BizRespExaminationContentExcelVO();
            excelVO.setName(content.getName());
            excelVO.setId(content.getId());
            //根据考核内容ID查询子项个数
            areeExcelVO.setContentId(content.getId());
            List<Map> contentNumber=bizRespExaminationContentMapper.findByContentExcelNumber(areeExcelVO);
            excelVO.setNumber(contentNumber.size());
            excelVOList.add(excelVO);
        }
        return excelVOList;
    }

}