package com.unis.accountability.businessmanagement.service.impl;

import com.unis.accountability.businessmanagement.common.vo.SaveVO;
import com.unis.accountability.businessmanagement.common.vo.cityQtbm.QtbmVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPage;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.ZpbmVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.*;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BizRespExaminationTaskVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.TaskVO;
import com.unis.accountability.businessmanagement.common.vo.provinceTask.ProvinceCityPageVO;
import com.unis.accountability.businessmanagement.common.vo.provinceTask.ProvinceCityTaskPage;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespResponsibilityVO;
import com.unis.accountability.businessmanagement.entity.*;
import com.unis.accountability.businessmanagement.mapper.BizRespCityZpbmServiceMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespScoreInputMapper;
import com.unis.accountability.businessmanagement.service.*;
import com.unis.common.utils.LsBeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @Auther:张新亮
 * @Date: 2019/9/25 0025 14:47
 * @Description:
 */
@Service
@Transactional
public class BizRespExaminationExcelServiceImpl implements BizRespExaminationExcelService {

    @Autowired
    private BizRespCityZpbmServiceMapper bizRespCityZpbmServiceMapper;
    @Autowired
    private BizRespScoreInputMapper bizRespScoreInputMapper;
    @Autowired
    private BizRespDepartmentalOpinionService bizRespDepartmentalOpinionService;
    @Autowired
    private BizRespResponsibilityService bizRespResponsibilityService;
    @Autowired
    private BizRespExaminationContentService bizRespExaminationContentService;
    @Autowired
    private BizRespExaminationItemService bizRespExaminationItemService;
    @Autowired
    private BizRespExaminationQuotaService bizRespExaminationQuotaService;
    @Autowired
    private BizRespExaminationTaskService bizRespExaminationTaskService;

    /**
     * 粮食安全行政首长责任制--省级任务考查询(省考核办)---州市评分表导出
     * @param year
     * @param shiAreaCode
     * @param bizRespResponsibilityId
     * @return
     */
    @Override
    public List<ProvinceCityPageVO> exportCityExcel(
            String year,
            String shiAreaCode,
            String bizRespResponsibilityId
    ) {
        ProvinceCityTaskPage cityTaskPage=new ProvinceCityTaskPage();
        cityTaskPage.setYear(year);
        cityTaskPage.setAreaCode(shiAreaCode);
        cityTaskPage.setBizRespResponsibilityId(bizRespResponsibilityId);
        List<ProvinceCityPageVO> mapLists=bizRespCityZpbmServiceMapper.findCityByPage(cityTaskPage);
        for(ProvinceCityPageVO pageVO:mapLists){
            BizRespScoreInput bizRespScoreInput=bizRespScoreInputMapper.selectByPrimaryKey(pageVO.getInputId());
            if(!"0".equals(bizRespScoreInput.getStatus())){
                //市自评部门
                ZpbmVO zpbmVO=bizRespDepartmentalOpinionService.findByZpbmInfo(bizRespScoreInput);
                pageVO.setCityZpbmFz(zpbmVO.getScore());
                //市牵头部门
                String[] deptId=bizRespScoreInput.getQtbm().split(",");
                bizRespScoreInput.setQtbm(deptId[0]);
                QtbmVO qtbmVO=bizRespDepartmentalOpinionService.findByQtbmInfo(bizRespScoreInput);
                pageVO.setCityQtbmFz(qtbmVO.getScore());
                //省牵头部门
                QtbmVO provinceQtbm=bizRespDepartmentalOpinionService.findByProvinceQtbm(pageVO.getTaskId(), "20",pageVO.getShiAreaCode());
                pageVO.setProvinceQtbmFz(provinceQtbm.getScore());
            }
        }
        return mapLists;
    }


    /**
     * 粮食安全行政首长责任制----考核评分表管理----导入评分表
     * @param excelSaveVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean saveExcleData(BizRespExcelSaveVO excelSaveVO) {
        BizRespResponsibility bizRespResponsibility=bizRespResponsibilityService.saveCheckExcelData(excelSaveVO);
        String responsibilityId=bizRespResponsibility.getId();
        SaveVO saveVO=excelSaveVO;
        for(BizRespExaminationContentExcelVO contentExcelVO:excelSaveVO.getExcelVOList()){
            //保存考核内容数据
            BizRespExaminationContent contentDO=bizRespExaminationContentService.getContentData(contentExcelVO, responsibilityId,saveVO);
            for(BizRespExaminationItemExcelVO itemExcelVO:contentExcelVO.getItemExcelVOList()){
                //保存重点考核事项
                BizRespExaminationItem itemDO=bizRespExaminationItemService.getItemData(contentDO.getId(), itemExcelVO, responsibilityId,saveVO);
                for(BizRespExaminationQuotaExcelVO quotaExcelVO:itemExcelVO.getQuotaExcelVOList()){
                    //保存考核指标
                    BizRespExaminationQuota quotaDO=bizRespExaminationQuotaService.getQutoaData(itemDO.getId(), quotaExcelVO, responsibilityId,saveVO);
                    for(BizRespExaminationTaskExcelVO taskExcelVO:quotaExcelVO.getTaskExcelVOList()){
                        //保存考核目标任务
                        bizRespExaminationTaskService.getTaskData(quotaDO.getId(), taskExcelVO, responsibilityId,saveVO);
                    }
                }
            }
        }
        return true;
    }
    /**
     * 粮食安全行政首长责任制----考核评分表管理----导入评分表
     * @param excelSaveVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean saveExcleData1(BizRespExcelSaveNewVO excelSaveVO) {
        BizRespResponsibility bizRespResponsibility=bizRespResponsibilityService.saveCheckExcelData(excelSaveVO);
        String responsibilityId=bizRespResponsibility.getId();
        SaveVO saveVO = excelSaveVO;
        for (BizRespExaminationTaskExcelVO taskExcelVO : excelSaveVO.getExcelVOList()) {
            //保存考核目标任务
            bizRespExaminationTaskService.getTaskData(null, taskExcelVO, responsibilityId, saveVO);
        }
        return true;
    }
    /**
     * 粮食安全行政首长责任制----考核评分表管理----导出评分表
     * @param bizRespResponsibilityId
     * @return
     */
    @Override
    public List<BizRespExaminationTaskExcelVO> exportKhpfbExcel1(String bizRespResponsibilityId) {
        List<BizRespExaminationTask> bizRespExaminationTasks = bizRespExaminationTaskService.findBybilityId(bizRespResponsibilityId);
        List<BizRespExaminationTaskExcelVO> vos = new ArrayList<BizRespExaminationTaskExcelVO>();
        for (BizRespExaminationTask vo : bizRespExaminationTasks){
            BizRespExaminationTaskExcelVO bizRespExaminationTaskExcelVO = LsBeanUtils.copyProperties(vo, BizRespExaminationTaskExcelVO.class);
            vos.add(bizRespExaminationTaskExcelVO);
        }
        return vos;
    }
    /**
     * 粮食安全行政首长责任制----考核评分表管理----导出评分表
     * @param bizRespResponsibilityId
     * @return
     */
    @Override
    public List<BizRespExaminationContentExcelVO> exportKhpfbExcel(String bizRespResponsibilityId) {
        List<BizRespExaminationContentExcelVO> contentList=bizRespExaminationContentService.findByRespResponsibilityId(bizRespResponsibilityId);
        for(BizRespExaminationContentExcelVO contentExcelVO:contentList){
            //粮食安全行政首长责任制----考核评分表管理----重点考核事项
            List<BizRespExaminationItemExcelVO> itemExcelVOList=bizRespExaminationItemService.findByItemList(contentExcelVO.getId());
            for(BizRespExaminationItemExcelVO itemExcelVO:itemExcelVOList){
                List<BizRespExaminationQuotaExcelVO> quotaExcelVOList=bizRespExaminationQuotaService.findByQuotaList(itemExcelVO.getId());
                for(BizRespExaminationQuotaExcelVO quotaExcelVO:quotaExcelVOList){
                    List<BizRespExaminationTaskExcelVO> taskExcelVOList=bizRespExaminationTaskService.findByTaskList(quotaExcelVO.getId());
                    quotaExcelVO.setTaskExcelVOList(taskExcelVOList);
                }
                itemExcelVO.setQuotaExcelVOList(quotaExcelVOList);
            }
            contentExcelVO.setItemExcelVOList(itemExcelVOList);
        }
        return contentList;
    }


    /**
     * 粮食安全行政首长责任制--区自评查看（区粮办）---导出
     * @param areeExcelVO
     * @return
     */
    @Override
    public List<BizRespExaminationContentExcelVO> exportAreaExcel(AreeExcelVO areeExcelVO) {
        BizRespResponsibilityVO bizRespResponsibilityVO= bizRespResponsibilityService.findByYear(areeExcelVO.getYear());
        areeExcelVO.setBizRespResponsibilityId(bizRespResponsibilityVO.getIds());
        List<BizRespExaminationContentExcelVO> contentList=bizRespExaminationContentService.findByContentExcel(areeExcelVO);
        for(BizRespExaminationContentExcelVO contentExcelVO:contentList){
            //粮食安全行政首长责任制----考核评分表管理----重点考核事项
            areeExcelVO.setContentId(contentExcelVO.getId());
            List<BizRespExaminationItemExcelVO> itemExcelVOList=bizRespExaminationItemService.findByItemExcel(areeExcelVO);
            for(BizRespExaminationItemExcelVO itemExcelVO:itemExcelVOList){
                areeExcelVO.setItemId(itemExcelVO.getId());
                List<BizRespExaminationQuotaExcelVO> quotaExcelVOList=bizRespExaminationQuotaService.findByQuotaExcel(areeExcelVO);
                for(BizRespExaminationQuotaExcelVO quotaExcelVO:quotaExcelVOList){
                    areeExcelVO.setQutoId(quotaExcelVO.getId());
                    List<BizRespExaminationTaskExcelVO> taskExcelVOList=bizRespExaminationTaskService.findByTaskExcel(areeExcelVO);
                    quotaExcelVO.setTaskExcelVOList(taskExcelVOList);
                }
                itemExcelVO.setQuotaExcelVOList(quotaExcelVOList);
            }
            contentExcelVO.setItemExcelVOList(itemExcelVOList);
        }
        return contentList;
    }

    /**
     * 粮食安全行政首长责任制--区自评查看（区粮办）---导出
     * @param areeExcelVO
     * @return
     */
    @Override
    public List<BizRespExaminationTaskExcelVO> exportAreaExcel1(AreeExcelVO areeExcelVO) {
        BizRespResponsibilityVO bizRespResponsibilityVO= bizRespResponsibilityService.findByYear(areeExcelVO.getYear());
        areeExcelVO.setBizRespResponsibilityId(bizRespResponsibilityVO.getIds());
        List<BizRespExaminationTaskExcelVO> taskExcelVOList=bizRespExaminationTaskService.findByTaskExcel(areeExcelVO);
        return taskExcelVOList;
    }
}