package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.SaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.AreeExcelVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.BizRespExaminationContentExcelVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.BizRespExaminationItemExcelVO;
import com.unis.common.utils.LsBeanUtils;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.examinationItem.ItemPage;
import com.unis.accountability.businessmanagement.common.vo.examinationItem.ItemSaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationItem.ItemUpdateVO;
import com.unis.accountability.businessmanagement.entity.BizRespExaminationItem;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationItemMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationQuotaMapper;
import com.unis.accountability.businessmanagement.service.BizRespExaminationItemService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/9/18 0018 15:39
 * @Description:
 */
@Service
@Transactional
public class BizRespExaminationItemServiceImpl implements BizRespExaminationItemService {
    @Autowired
    private BizRespExaminationItemMapper bizRespExaminationItemMapper;
    @Autowired
    private BizRespExaminationQuotaMapper bizRespExaminationQuotaMapper;


    /**
     * 粮食安全行政首长责任制----重点考核事项---保存
     * @param itemVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean save(ItemSaveVO itemSaveVO) {
        BizRespExaminationItem bizRespExaminationItemDO = LsBeanUtils.copyProperties(itemSaveVO.getItemVO(), BizRespExaminationItem.class);
        //创建时间
        bizRespExaminationItemDO.setCreateTime(new Date());
        bizRespExaminationItemDO.setUpdateTime(new Date());
        //创建人
        bizRespExaminationItemDO.setCreateBy(itemSaveVO.getCreateBy());
        //行政区划
        bizRespExaminationItemDO.setAreaCode(itemSaveVO.getAreaCode());
        //机构ID
        bizRespExaminationItemDO.setOrgId(itemSaveVO.getOrgId());
        //部门ID
        bizRespExaminationItemDO.setDeptId(itemSaveVO.getDeptId());
        int result=bizRespExaminationItemMapper.insertSelective(bizRespExaminationItemDO);
        if(result>0){
            return true;
        }
        return false;
    }



    /**
     *粮食安全行政首长责任制----重点考核事项---编辑
     * @param itemUpdateVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean update(ItemUpdateVO itemUpdateVO) {
        BizRespExaminationItem itemDO = LsBeanUtils.copyProperties(itemUpdateVO.getItemVO(), BizRespExaminationItem.class);
        itemDO.setId(itemUpdateVO.getItemVO().getIds());
        itemDO.setUpdateTime(new Date());
        //创建人
        itemDO.setUpdateBy(itemUpdateVO.getUpdateBy());
        int result= bizRespExaminationItemMapper.updateByPrimaryKeySelective(itemDO);
        if(result>0){
            return true;
        }
        return false;
    }

    /**
     * 粮食安全行政首长责任制----重点考核事项---批量删除
     * @param deleteVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public Boolean deletes(DeleteVO deleteVO) {
        //查询 考核指标 是否被使用  只要有一个查询已存在则为删除失败
        for(int i=0;i<deleteVO.getIds().length;i++){
            String id=deleteVO.getIds()[i];
            List<Map> itemDO=bizRespExaminationQuotaMapper.findByBizRespQuotaId(id);
            if(itemDO.size()>0){
                return false;
            }
        }


        for(int i=0;i<deleteVO.getIds().length;i++){
            String id=deleteVO.getIds()[i];
            BizRespExaminationItem itemDO=bizRespExaminationItemMapper.selectByPrimaryKey(id);
            if(itemDO!=null){
                itemDO.setDeleteTime(new Date());
                itemDO.setDeleteBy(deleteVO.getDeleteBy());
                bizRespExaminationItemMapper.updateByPrimaryKeySelective(itemDO);
            }
        }
        return true;
    }

    /**
     * 粮食安全行政首长责任制----重点考核事项---分页
     * @param itemVO
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<Map>> findByPage(ItemPage itemPage, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        List<Map> mapList=bizRespExaminationItemMapper.findByPage(itemPage);
        for(Map map:mapList){
            String id=map.get("id").toString();
            String isEidt= this.getIfRelease(id);
            String isdelete=this.getIfDelete(id);
            map.put("isEidt",isEidt);
            map.put("isDelete",isdelete);
        }
        return listPage.toPageInfo();
    }

    private String getIfDelete(String id) {
        List<Map> mapList=bizRespExaminationQuotaMapper.findByBizRespQuotaId(id);
        // y 可以删除  n 不删除
        if(mapList.size()>0){
            return "N";
        }else{
            return "Y";
        }
    }


    private String getIfRelease(String id) {
        List<Map> mapList=this.findIfRelease(id);
        // y 可以删除  n 不呆删除
        if(mapList.size()>0){
            return "N";
        }else{
            return "Y";
        }
    }

    /**
     * 粮食安全行政首长责任制----重点考核事项---是否右以编辑
     * @param id
     * @return
     */
    @Override
    public List<Map> findIfRelease(String id) {
        return bizRespExaminationItemMapper.findIfRelease(id);
    }

    /**
     * 粮食安全行政首长责任制----重点考核事项---根据年份year和组织机构 orgId 查询重点考核事项
     * @param map
     * @return
     */
    @Override
    public List<Map> findByYearAndOrgId(Map map) {
        return bizRespExaminationItemMapper.findByYearAndOrgId(map);
    }

    /**
     * 粮食安全行政首长责任制----考核评分表管理----重点考核事项
     * @param contentId
     * @param itemExcelVO
     * @param responsibilityId
     * @param saveVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public BizRespExaminationItem getItemData(
            String contentId,
            BizRespExaminationItemExcelVO itemExcelVO,
            String responsibilityId,
            SaveVO saveVO
    ) {
        BizRespExaminationItem bizRespExaminationItemDO =new BizRespExaminationItem();
        //创建时间
        bizRespExaminationItemDO.setCreateTime(new Date());
        bizRespExaminationItemDO.setUpdateTime(new Date());
        //创建人
        bizRespExaminationItemDO.setCreateBy(saveVO.getCreateBy());
        //行政区划
        bizRespExaminationItemDO.setAreaCode(saveVO.getAreaCode());
        //部门ID
        bizRespExaminationItemDO.setDeptId(saveVO.getDeptId());
        bizRespExaminationItemDO.setOrgId(saveVO.getOrgId());
        //重点考核事项 内容
        bizRespExaminationItemDO.setName(itemExcelVO.getName());
        bizRespExaminationItemDO.setBizRespResponsibilityId(responsibilityId);
        bizRespExaminationItemDO.setBizRespContentId(contentId);
        bizRespExaminationItemMapper.insertSelective(bizRespExaminationItemDO);
        return bizRespExaminationItemDO;
    }




    /**
     * 粮食安全行政首长责任制----考核评分表管理----重点考核事项
     * @param excelVO
     */
    @Override
    public List<BizRespExaminationItemExcelVO> findByItemList(String countId) {
        List<BizRespExaminationItemExcelVO> itemExcelVOList=new ArrayList();
        List<BizRespExaminationItem> itemList=  bizRespExaminationItemMapper.findByItemList(countId);
        for(BizRespExaminationItem item:itemList){
            BizRespExaminationItemExcelVO itemExcelVO=new BizRespExaminationItemExcelVO();
            itemExcelVO.setName(item.getName());
            itemExcelVO.setId(item.getId());
            List<Map> number=bizRespExaminationItemMapper.findByItemNumber(item.getId());
            itemExcelVO.setNumber(number.size());
            itemExcelVOList.add(itemExcelVO);
        }
        return itemExcelVOList;
    }

    @Override
    public List<BizRespExaminationItemExcelVO> findByItemExcel(AreeExcelVO areeExcelVO) {
        List<BizRespExaminationItemExcelVO> itemExcelVOList=new ArrayList();
        List<BizRespExaminationItem> itemList=  bizRespExaminationItemMapper.findByItemExcel(areeExcelVO);
        for(BizRespExaminationItem item:itemList){
            BizRespExaminationItemExcelVO itemExcelVO=new BizRespExaminationItemExcelVO();
            itemExcelVO.setName(item.getName());
            itemExcelVO.setId(item.getId());
            areeExcelVO.setItemId(item.getId());
            List<Map> number=bizRespExaminationItemMapper.findByItemExcelNumber(areeExcelVO);
            itemExcelVO.setNumber(number.size());
            itemExcelVOList.add(itemExcelVO);
        }
        return itemExcelVOList;
    }

}