package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.SaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.AreeExcelVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.BizRespExaminationQuotaExcelVO;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationQuotaMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationTaskMapper;
import com.unis.accountability.businessmanagement.service.BizRespExaminationQuotaService;
import com.unis.common.utils.LsBeanUtils;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.examinationQuota.QuotaSaveVO;
import com.unis.accountability.businessmanagement.common.vo.examinationQuota.QuotaUPdateVO;
import com.unis.accountability.businessmanagement.common.vo.examinationQuota.QutoaPage;
import com.unis.accountability.businessmanagement.entity.BizRespExaminationQuota;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/9/18 0018 16:34
 * @Description:
 */
@Service
@Transactional
public class BizRespExaminationQuotaServiceImpl implements BizRespExaminationQuotaService {
    @Autowired
    private BizRespExaminationQuotaMapper bizRespExaminationQuotaMapper;
    @Autowired
    private BizRespExaminationTaskMapper bizRespExaminationTaskMapper;


    /**
     * 粮食安全省长责任制--考核指标----保存
     * @param quotaSaveVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean save(QuotaSaveVO quotaSaveVO) {
        BizRespExaminationQuota quotaDO = LsBeanUtils.copyProperties(quotaSaveVO.getQuotaVO(), BizRespExaminationQuota.class);
        //创建时间
        quotaDO.setCreateTime(new Date());
        quotaDO.setUpdateTime(new Date());
        //创建人
        quotaDO.setCreateBy(quotaSaveVO.getCreateBy());
        //行政区划
        quotaDO.setAreaCode(quotaSaveVO.getAreaCode());
        //部门ID
        quotaDO.setDeptId(quotaSaveVO.getDeptId());
        //机构ID
        quotaDO.setOrgId(quotaSaveVO.getOrgId());
        int result=bizRespExaminationQuotaMapper.insertSelective(quotaDO);
        if(result>0){
            return true;
        }
        return false;
    }



    /**
     * 粮食安全省长责任制--考核指标----分页
     * @param qutoaPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<Map>> findByPage(QutoaPage qutoaPage, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        List<Map> mapList= bizRespExaminationQuotaMapper.findByPage(qutoaPage);
        for(Map map:mapList){
            String id=map.get("id").toString();
            String isEidt= this.getIfRelease(id);
            String isdelete=this.getIfDelete(id);
            map.put("isEidt",isEidt);
            map.put("isDelete",isdelete);

        }
        return listPage.toPageInfo();
    }

    private String getIfRelease(String id) {
        List<Map> mapList=this.findIfRelease(id);
        // y 可以删除  n 不呆删除
        if(mapList.size()>0){
            return "N";
        }else{
            return "Y";
        }

    }


    /**
     * 粮食安全省长责任制--考核指标----是否可以修改
     * @param id
     * @return
     */
    @Override
    public List<Map> findIfRelease(String id) {
        return bizRespExaminationQuotaMapper.findIfRelease(id);
    }

    private String getIfDelete(String id) {
        List<Map> mapList=bizRespExaminationTaskMapper.findByBizTaskId(id);
        // y 可以删除  n 不呆删除
        if(mapList.size()>0){
            return "N";
        }else{
            return "Y";
        }
    }




    /**
     * 粮食安全省长责任制--考核指标----根据年份year和组织机构 orgId 查询重点考核事项
     * @param map
     * @return
     */
    @Override
    public List<Map> findByYearAndOrgId(Map map) {
        return bizRespExaminationQuotaMapper.findByYearAndOrgId(map);

    }

    /**
     * 粮食安全省长责任制--考核指标----编辑
     * @param quotaUPdateVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean update(QuotaUPdateVO quotaUPdateVO) {
        BizRespExaminationQuota quotaDO = LsBeanUtils.copyProperties(quotaUPdateVO.getQuotaVO(),BizRespExaminationQuota.class);
        quotaDO.setId(quotaUPdateVO.getQuotaVO().getIds());
        quotaDO.setUpdateTime(new Date());
        quotaDO.setUpdateBy(quotaUPdateVO.getUpdateBy());
        int result= bizRespExaminationQuotaMapper.updateByPrimaryKeySelective(quotaDO);
        if(result>0){
            return true;
        }
        return false;
    }

    /**
     * 粮食安全省长责任制--考核指标----批量删除
     * @param deleteVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public Boolean deletes(DeleteVO deleteVO) {
        //查询 考核目标任务 是否被使用  只要有一个查询已存在则为删除失败
        for(int i=0;i<deleteVO.getIds().length;i++){
            String id=deleteVO.getIds()[i];
            List<Map> itemDO=bizRespExaminationTaskMapper.findByBizTaskId(id);
            if(itemDO.size()>0){
                return false;
            }
        }


        for(int i=0;i<deleteVO.getIds().length;i++){
            String id=deleteVO.getIds()[i];
            BizRespExaminationQuota quotaDO=bizRespExaminationQuotaMapper.selectByPrimaryKey(id);
            if(quotaDO!=null){
                quotaDO.setDeleteTime(new Date());
                quotaDO.setDeleteBy(deleteVO.getDeleteBy());
                bizRespExaminationQuotaMapper.updateByPrimaryKeySelective(quotaDO);
            }
        }
        return true;
    }

    /**
     * 粮食安全行政首长责任制----考核评分表管理----考核指标
     * @param itemId
     * @param quotaExcelVO
     * @param responsibilityId
     * @param saveVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public BizRespExaminationQuota getQutoaData(
            String itemId,
            BizRespExaminationQuotaExcelVO quotaExcelVO,
            String responsibilityId,
            SaveVO saveVO
    ) {
        BizRespExaminationQuota quotaDO=new BizRespExaminationQuota();
        //创建时间
        quotaDO.setCreateTime(new Date());
        quotaDO.setUpdateTime(new Date());
        //创建人
        quotaDO.setCreateBy(saveVO.getCreateBy());
        //行政区划
        quotaDO.setAreaCode(saveVO.getAreaCode());
        //部门ID
        quotaDO.setDeptId(saveVO.getDeptId());
        quotaDO.setOrgId(saveVO.getOrgId());
        //考核指标 内容
        quotaDO.setName(quotaExcelVO.getName());
        //填报设置ID
        quotaDO.setBizRespResponsibilityId(responsibilityId);
        //重点考核事项 ID
        quotaDO.setBizRespExaminationItemId(itemId);
        bizRespExaminationQuotaMapper.insertSelective(quotaDO);

        return quotaDO;
    }

    /**
     * 粮食安全省长责任制--考核指标----集俣
     * @param id
     * @return
     */
    @Override
    public List<BizRespExaminationQuotaExcelVO> findByQuotaList(String itemId) {
        List<BizRespExaminationQuotaExcelVO> quotaExcelVOList=new ArrayList();
        List<BizRespExaminationQuota> quotaList=bizRespExaminationQuotaMapper.findByQuotaList(itemId);
        for(BizRespExaminationQuota quota:quotaList){
            BizRespExaminationQuotaExcelVO quotaExcelVO=new BizRespExaminationQuotaExcelVO();
            quotaExcelVO.setName(quota.getName());
            quotaExcelVO.setId(quota.getId());
            List<Map> number=bizRespExaminationQuotaMapper.findByQuotaNumber(quota.getId());
            quotaExcelVO.setNumber(number.size());
            quotaExcelVOList.add(quotaExcelVO);
        }
        return quotaExcelVOList;
    }

    @Override
    public List<BizRespExaminationQuotaExcelVO> findByQuotaExcel(AreeExcelVO areeExcelVO) {
        List<BizRespExaminationQuotaExcelVO> quotaExcelVOList=new ArrayList();
        List<BizRespExaminationQuota> quotaList=bizRespExaminationQuotaMapper.findByQuotaExcel(areeExcelVO);
        for(BizRespExaminationQuota quota:quotaList){
            BizRespExaminationQuotaExcelVO quotaExcelVO=new BizRespExaminationQuotaExcelVO();
            quotaExcelVO.setName(quota.getName());
            quotaExcelVO.setId(quota.getId());
            areeExcelVO.setQutoId(quota.getId());
            List<Map> number=bizRespExaminationQuotaMapper.findByQuotaExcelNumber(areeExcelVO);
            quotaExcelVO.setNumber(number.size());
            quotaExcelVOList.add(quotaExcelVO);
        }
        return quotaExcelVOList;
    }

}