package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.SaveVO;
import com.unis.accountability.businessmanagement.common.vo.cityQtbm.QtbmOpionVO;
import com.unis.accountability.businessmanagement.common.vo.cityQtbm.QtbmVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.AreeExcelVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.BizRespExaminationTaskExcelVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.*;
import com.unis.accountability.businessmanagement.entity.*;
import com.unis.accountability.businessmanagement.mapper.*;
import com.unis.accountability.businessmanagement.service.BizRespDepartmentalOpinionService;
import com.unis.accountability.businessmanagement.service.BizRespExaminationTaskService;
import com.unis.accountability.businessmanagement.service.BizRespScoringWeightService;
import com.unis.common.utils.DoubleUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PathVariable;

import java.util.*;

/**
 * @Auther:张新亮
 * @Date: 2019/9/18 0018 17:09
 * @Description:
 */
@Service
@Transactional
public class BizRespExaminationTaskServiceImpl implements BizRespExaminationTaskService {

    @Autowired
    private BizRespExaminationTaskMapper bizRespExaminationTaskMapper;
    @Autowired
    private BizRespResponsibilityMapper bizRespResponsibilityMapper;
    @Autowired
    private BizRespScoringWeightService bizRespScoringWeightService;
    @Autowired
    private BizRespExaminationQuotaMapper bizRespExaminationQuotaMapper;
    @Autowired
    private BizRespExaminationItemMapper bizRespExaminationItemMapper;
    @Autowired
    private BizRespExaminationContentMapper bizRespExaminationContentMapper;
    @Autowired
    private BizRespScoreInputMapper bizRespScoreInputMapper;
    @Autowired
    private BizRespDepartmentalOpinionService bizRespDepartmentalOpinionService;
    @Autowired
    private BizRespCityTaskfFMapper bizRespCityTaskfFMapper;
    @Autowired
    private BizRespDepartmentalOpinionMapper bizRespDepartmentalOpinionMapper;

    /**
     * 粮食安全省长责任制--考核目标任务---查询可填分数
     * @param map
     * @return
     */
    @Override
    public Map findBySorce(Map map) {
        String responsibilityId=map.get("responsibilityId").toString();
        BizRespResponsibility responsibilityDO=bizRespResponsibilityMapper.selectByPrimaryKey(responsibilityId);
        Map map1=new HashMap();
        Map result=bizRespExaminationTaskMapper.findBySorce(map);
        BizRespScoringWeight weightDO= bizRespScoringWeightService.findByYearAndStatus(responsibilityDO.getYear(), 1);
        if(result!=null){
            //总分
            String total= DoubleUtil.getString(weightDO.getTotalScore());
            //已填分数
            String score=result.get("SCORE")==null?"0":result.get("SCORE").toString();

            Double tot= DoubleUtil.sub(weightDO.getTotalScore(), Double.valueOf(score));
            map1.put("total",total);
            map1.put("score",DoubleUtil.getString(tot));
        }else{
            map1.put("total",DoubleUtil.getString(weightDO.getTotalScore()));
            map1.put("score",DoubleUtil.getString(weightDO.getTotalScore()));
        }
        return map1;
    }




    /**
     *  粮食安全省长责任制--考核目标任务---保存
     * @param taskSaveVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean save(TaskSaveVO taskSaveVO) {
        BizRespExaminationTask taskDO = LsBeanUtils.copyProperties(taskSaveVO.getTaskVO(), BizRespExaminationTask.class);

        //创建人
        taskDO.setCreateBy(taskSaveVO.getCreateBy());
        //创建时间
        taskDO.setCreateTime(new Date());
        //修改时间
        taskDO.setUpdateTime(new Date());
        //行政区划
        taskDO.setAreaCode(taskSaveVO.getAreaCode());
        //部门ID
        taskDO.setDeptId(taskSaveVO.getDeptId());
        //机构ID
        taskDO.setOrgId(taskSaveVO.getOrgId());
        taskDO.setStatus(0);
        bizRespExaminationTaskMapper.insertSelective(taskDO);
        return true;
    }



    /**a
     * 根据id查询考核目标任务
     * @param id
     * @return
     */
    @Override
    public BizRespExaminationTaskVO findById(String id) {
        BizRespExaminationTask taskDO=bizRespExaminationTaskMapper.selectByPrimaryKey(id);
        BizRespExaminationTaskVO taskVO = LsBeanUtils.copyProperties(taskDO, BizRespExaminationTaskVO.class);
        if(taskDO!=null){
            taskVO.setIds(taskDO.getId());
        }
        return taskVO;
    }

    /**
     * 粮食安全省长责任制--考核目标任务---编辑
     * @param taskUpdateVO
     * @param
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean update(TaskUpdateVO taskUpdateVO) {
        BizRespExaminationTask taskDO = LsBeanUtils.copyProperties(taskUpdateVO.getTaskVO(), BizRespExaminationTask.class);
        taskDO.setId(taskUpdateVO.getTaskVO().getIds());
        taskDO.setUpdateTime(new Date());
        taskDO.setUpdateBy(taskUpdateVO.getUpdateBy());
        bizRespExaminationTaskMapper.updateByPrimaryKeySelective(taskDO);
        return true;
    }


    /**
     * 粮食安全省长责任制--考核目标任务---批量删除
     * @param deleteVO
     * @return
     */

    @Override
    public Boolean deletes(DeleteVO deleteVO) {
        for(int i=0;i<deleteVO.getIds().length;i++){
            String id=deleteVO.getIds()[i];
            BizRespExaminationTask taskDO=bizRespExaminationTaskMapper.selectByPrimaryKey(id);
            if(taskDO!=null){
                taskDO.setDeleteTime(new Date());
                taskDO.setDeleteBy(deleteVO.getDeleteBy());
                bizRespExaminationTaskMapper.updateByPrimaryKeySelective(taskDO);
            }
        }
        return true;
    }

    /**
     * 粮食安全省长责任制--考核目标任务---分页
     * @param taskVO
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<Map>> findByPage(TaskPageVO taskVO, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        List<Map> mapLists=bizRespExaminationTaskMapper.findByPage(taskVO);
        return listPage.toPageInfo();
    }

    /**
     * 粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细--牵头部门配合部门部门和自评部门专用
     * @param id
     * @return
     */
    @Override
    public TaskInfoVO findByTaskInfo(String id) {
        TaskInfoVO taskInfoVO=new TaskInfoVO();
        BizRespExaminationTask task= bizRespExaminationTaskMapper.selectByPrimaryKey(id);
        taskInfoVO.setId(id);
        taskInfoVO.setTaskName(task.getTaskName());
        taskInfoVO.setPfbz(task.getScoreStandard());
        /**
         * 评分依据
         */
        taskInfoVO.setPfyj(task.getPfyj());
        /**
         * 农业分值
         */
        taskInfoVO.setNyfz(task.getNyfz());
        /**
         * 非农业分值
         */
        taskInfoVO.setFnyfz(task.getFnyfz());
        /**
         * 考核方式
         */
 //       taskInfoVO.setKhfs(task.getKhfs());
 //       BizRespExaminationQuota quota=bizRespExaminationQuotaMapper.selectByPrimaryKey(task.getBizRespExaminationQuotaId());
//        taskInfoVO.setKhzb(quota.getName());
 //       BizRespExaminationItem item=bizRespExaminationItemMapper.selectByPrimaryKey(quota.getBizRespExaminationItemId());
 //       taskInfoVO.setKhsx(item.getName());
  //      BizRespExaminationContent content=bizRespExaminationContentMapper.selectByPrimaryKey(item.getBizRespContentId());
  //      taskInfoVO.setKhnr(content.getName());
        BizRespResponsibility bizRespResponsibility=bizRespResponsibilityMapper.selectByPrimaryKey(task.getBizRespResponsibilityId());
        taskInfoVO.setYear(String.valueOf(bizRespResponsibility.getYear()));
        return taskInfoVO;
    }

    /**
     * 区评分表科室考核
     * @param id
     * @return
     */
    @Override
    public BizRespExaminationTaskVO findByInputId(String id){
        BizRespDepartmentalOpinion bizRespDepartmentalOpinion = bizRespDepartmentalOpinionMapper.selectByPrimaryKey(id);
        BizRespExaminationTaskVO bizRespExaminationTaskVO = new BizRespExaminationTaskVO();
        BizRespScoreInput input = bizRespScoreInputMapper.findById(bizRespDepartmentalOpinion.getBizRespScoreInputId());
        BizRespExaminationTask task = bizRespExaminationTaskMapper.selectByPrimaryKey(bizRespDepartmentalOpinion.getBizResexaminationTaskId());
        bizRespExaminationTaskVO.setLeadDepartment(input.getQtbm());
        bizRespExaminationTaskVO.setCoordinationDepartment(input.getPhbm());
        bizRespExaminationTaskVO.setScoreStandard(task.getScoreStandard());
        bizRespExaminationTaskVO.setUserCode(bizRespDepartmentalOpinion.getUserCode());
        bizRespExaminationTaskVO.setKhcs(bizRespDepartmentalOpinion.getKhcs());
        bizRespExaminationTaskVO.setKhcsid(bizRespDepartmentalOpinion.getKhcsid());
        bizRespExaminationTaskVO.setDeptId(input.getDeptId());
        bizRespExaminationTaskVO.setAreaCode(input.getAreaCode());
        bizRespExaminationTaskVO.setPfyj(task.getPfyj());
        bizRespExaminationTaskVO.setNyfz(task.getNyfz());
        bizRespExaminationTaskVO.setFnyfz(task.getFnyfz());
        BizRespResponsibility bizRespResponsibility=bizRespResponsibilityMapper.selectByPrimaryKey(task.getBizRespResponsibilityId());
        bizRespExaminationTaskVO.setYear(String.valueOf(bizRespResponsibility.getYear()));
        return bizRespExaminationTaskVO;
    }

    @Override
    public void publishAll(String orgName) {
        bizRespExaminationTaskMapper.publishAll(orgName);
    }

    @Override
    public String getTaskIdByInputId(String id){
        BizRespScoreInput input = bizRespScoreInputMapper.findById(id);
        BizRespExaminationTask task = bizRespExaminationTaskMapper.selectByPrimaryKey(input.getBizResexaminationTaskId());
        return task.getId();
    }
    /**
     * 粮食安全行政首长责任制----考核评分表管理----考核目标任务
     * @param quotaId
     * @param taskExcelVO
     * @param responsibilityId
     * @param saveVO
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public void getTaskData(
            String quotaId,
            BizRespExaminationTaskExcelVO taskExcelVO,
            String responsibilityId,
            SaveVO saveVO
    ) {
        TaskSaveVO taskSaveVO=new TaskSaveVO();
        TaskVO taskVO = LsBeanUtils.copyProperties(taskExcelVO, TaskVO.class);
        taskSaveVO.setTaskVO(taskVO);
        taskVO.setBizRespExaminationQuotaId(quotaId);
        taskVO.setBizRespResponsibilityId(responsibilityId);
        taskSaveVO.setOrgId(saveVO.getOrgId());
        taskSaveVO.setDeptId(saveVO.getDeptId());
        taskSaveVO.setAreaCode(saveVO.getAreaCode());
        taskSaveVO.setCreateBy(saveVO.getCreateBy());
        this.save(taskSaveVO);
    }

    /**
     * 粮食安全行政首长责任制----考核评分表管理----考核目标任务集合
     * @param quotaId
     * @return
     */
    @Override
    public List<BizRespExaminationTaskExcelVO> findByTaskList(String quotaId) {
        List<BizRespExaminationTaskExcelVO> taskExcelVOList=new ArrayList();
        List<BizRespExaminationTask> taskList=bizRespExaminationTaskMapper.findByTaskList(quotaId);
        for(BizRespExaminationTask task:taskList){
            BizRespExaminationTaskExcelVO taskExcelVO=new BizRespExaminationTaskExcelVO();
            taskExcelVO.setLeadDepartment(task.getLeadDepartment());
            taskExcelVO.setCoordinationDepartment(task.getCoordinationDepartment());
            taskExcelVO.setScoreStandard(task.getScoreStandard());
            taskExcelVO.setNyfz(task.getNyfz());
            taskExcelVO.setFnyfz(task.getFnyfz());
            taskExcelVO.setPfyj(task.getPfyj());
            taskExcelVO.setKhfs(task.getKhfs());
            taskExcelVOList.add(taskExcelVO);
        }
        return taskExcelVOList;
    }


    /**
     * 粮食安全行政首长责任制----考核评分表管理----根据填报时间查询考核任务
     * @param id
     * @return
     */
    @Override
    public List<BizRespExaminationTask> findBybilityId(String id) {
      return   bizRespExaminationTaskMapper.findByBilityId(id);
    }

    @Override
    public List<BizRespExaminationTaskVO> findVOBybilityId(String id) {
      return   bizRespExaminationTaskMapper.findVOByBilityId(id);
    }


    /**
     * 粮食安全行政首长责任制--区自评查看（区粮办）---导出
     * @param areeExcelVO
     * @return
     */
    @Override
    public List<BizRespExaminationTaskExcelVO> findByTaskExcel(AreeExcelVO areeExcelVO) {
        List<BizRespExaminationTaskExcelVO> taskExcelVOList=new ArrayList();
        List<BizRespExaminationTask> taskList=bizRespExaminationTaskMapper.findByTaskExcel(areeExcelVO);
        for(BizRespExaminationTask task:taskList){
            BizRespExaminationTaskExcelVO taskExcelVO=new BizRespExaminationTaskExcelVO();
            taskExcelVO.setLeadDepartment(task.getLeadDepartment());
            taskExcelVO.setCoordinationDepartment(task.getCoordinationDepartment());
            taskExcelVO.setScoreStandard(task.getScoreStandard());
            taskExcelVO.setNyfz(task.getNyfz());
            taskExcelVO.setFnyfz(task.getFnyfz());
            taskExcelVO.setPfyj(task.getPfyj());
            taskExcelVO.setKhfs(task.getKhfs());
            taskExcelVO.setCityAreaCode(task.getAreaCode());

            BizRespScoreInput input=bizRespScoreInputMapper.findByTaskIdAndAreaCode(task.getId(), areeExcelVO.getAreaCode());
           if(input!=null){
               taskExcelVO.setPhbm(input.getPhbm());
               taskExcelVO.setQtbm(input.getQtbm());
               taskExcelVO.setAreaCode(input.getAreaCode());
               //区级自评得分
               QtbmOpionVO qtbmVO=bizRespDepartmentalOpinionService.findByAreaQtbmInfo(input, "50");
               if(qtbmVO!=null){
                   taskExcelVO.setScore(qtbmVO.getScore());
               }
               //市级考核得分
               input.setQtbm(task.getLeadDepartment());
               input.setId(task.getId());
               QtbmOpionVO cityQtbmVO=bizRespDepartmentalOpinionService.findByAreaQtbmInfo(input, "20");
               if(cityQtbmVO!=null){
                   taskExcelVO.setKhdfScore(cityQtbmVO.getScore());
               }
               //市级抽查得分
               input.setQtbm(task.getLeadDepartment());
               input.setId(task.getId());
               QtbmOpionVO ccQtbmVO=bizRespDepartmentalOpinionService.findByAreaQtbmInfo(input, "60");
               if(ccQtbmVO!=null){
                   taskExcelVO.setCcScore(ccQtbmVO.getScore());
               }
           }
            taskExcelVOList.add(taskExcelVO);
        }
        return taskExcelVOList;
    }

    /**
     * 粮食安全省长责任制--考核目标任务---根据填报设置ID查询所有考核任务
     * @param bizRespResponsiBilityId
     * @return
     */
    @Override
    public List<BizRespExaminationTask> findTaskListByResponsiBilityId(String bizRespResponsiBilityId){
    	return bizRespExaminationTaskMapper.findByResponsTaskList(bizRespResponsiBilityId);
    }
}