package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmVO;
import com.unis.accountability.businessmanagement.common.vo.provincePhbm.ProvincePhbmPage;
import com.unis.accountability.businessmanagement.common.vo.provincePhbm.ProvincePhbmPublishVO;
import com.unis.accountability.businessmanagement.common.vo.provincePhbm.PrvoincePhbmPageVO;
import com.unis.accountability.businessmanagement.entity.BizRespDepartmentalOpinion;
import com.unis.accountability.businessmanagement.entity.BizRespExaminationTask;
import com.unis.accountability.businessmanagement.entity.BizRespScoringWeight;
import com.unis.accountability.businessmanagement.mapper.BizRespDepartmentalOpinionMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespExaminationTaskMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespProvinceMapper;
import com.unis.accountability.businessmanagement.service.BizRespDepartmentalOpinionService;
import com.unis.accountability.businessmanagement.service.BizRespProvincePhbmService;
import com.unis.accountability.businessmanagement.service.BizRespScoringWeightService;
import com.unis.common.utils.LsBeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Auther:张新亮
 * @Date: 2019/10/8 0008 14:50
 * @Description:
 */
@Service
@Transactional
public class BizRespProvincePhbmServiceImpl implements BizRespProvincePhbmService {

    @Autowired
    private BizRespProvinceMapper bizRespProvinceMapper;
    @Autowired
    private BizRespScoringWeightService bizRespScoringWeightService;
    @Autowired
    private BizRespDepartmentalOpinionMapper bizRespDepartmentalOpinionMapper;
    @Autowired
    private BizRespDepartmentalOpinionService bizRespDepartmentalOpinionService;
    @Autowired
    private BizRespExaminationTaskMapper bizRespExaminationTaskMapper;

    /**
     * 粮食安全行政首长责任制----省级配合部门----分页
     *
     * @param provincePhbmPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<PrvoincePhbmPageVO>> findByPage(
            ProvincePhbmPage provincePhbmPage,
            Integer page,
            Integer size
    ) {
        Page<List<PrvoincePhbmPageVO>> listPage = PageHelper.startPage(page, size);
        System.out.println("接口参数==" + provincePhbmPage.toString());
        // type  10 省配合部门  70 省级平时配合部门
        List<PrvoincePhbmPageVO> mapLists = bizRespProvinceMapper.findByPhbmPage(provincePhbmPage);
        String ifpf = "no";
        for (PrvoincePhbmPageVO prvoincePhbmPageVO : mapLists) {
            BizRespScoringWeight bizRespScoringWeight = bizRespScoringWeightService.findByYearAndStatus(Integer.valueOf(prvoincePhbmPageVO.getYear()), 1);
            if (bizRespScoringWeight != null) {
                ifpf = bizRespScoringWeightService.weightCompareTo(bizRespScoringWeight, "cityPhbm");
            }
            prvoincePhbmPageVO.setIfPf(ifpf);
        }
        // 检查是否进行抽查下发
        if (provincePhbmPage.getType().equalsIgnoreCase("10")) {
            provincePhbmPage.setType("70");
            List<PrvoincePhbmPageVO> choucha = bizRespProvinceMapper.findByPhbmPage(provincePhbmPage);
            HashMap<String, String> map = new HashMap<>();
            for (PrvoincePhbmPageVO prvoincePhbmPageVO : choucha) {
                if (!map.containsKey(prvoincePhbmPageVO.getAreaCode())) {
                    map.put(prvoincePhbmPageVO.getAreaCode(), "areaCode");
                }
            }
            for (String areaCode : map.keySet()) {
                mapLists.stream().filter(bean -> {
                    if (areaCode.equalsIgnoreCase(bean.getAreaCode())) {
                        bean.setIfPf("no");
                    }
                    return true;
                }).collect(Collectors.toList());
            }
        }
        return listPage.toPageInfo();

    }


    /**
     * 粮食安全行政首长责任制----省级配合部门----查看
     *
     * @param id 部门意见ID
     * @return
     */
    @Override
    public PhbmVO findById(String id) {
        BizRespDepartmentalOpinion opinion = bizRespDepartmentalOpinionMapper.selectByPrimaryKey(id);
        BizRespExaminationTask task = bizRespExaminationTaskMapper.selectByPrimaryKey(opinion.getBizResexaminationTaskId());
        PhbmVO phbmVO = LsBeanUtils.copyProperties(opinion, PhbmVO.class);
        phbmVO.setPhbm(opinion.getDeptId());
        phbmVO.setBizResexaminationTaskId(opinion.getBizResexaminationTaskId());
        phbmVO.setCityAreacode(task.getAreaCode());
        return phbmVO;
    }


    /**
     * 粮食安全行政首长责任制----省级配合部门---编辑
     *
     * @param phbmUpdateVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED, rollbackFor = Exception.class)
    public boolean update(PhbmUpdateVO phbmUpdateVO) {
        System.out.println("接口参数==" + phbmUpdateVO.toString());
        return bizRespDepartmentalOpinionService.updatePhbm(phbmUpdateVO);
    }


    /**
     * 粮食安全行政首长责任制----省级配合部门---上报
     *
     * @param phbmPublishVO
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED, rollbackFor = Exception.class)
    public void publish(ProvincePhbmPublishVO phbmPublishVO) {
        System.out.println("省级配合部门---上报==" + phbmPublishVO.toString());
        BizRespDepartmentalOpinion opinion = bizRespDepartmentalOpinionMapper.selectByPrimaryKey(phbmPublishVO.getId());
        opinion.setStatus("30");
        opinion.setUpdateBy(phbmPublishVO.getUpdateBy());
        opinion.setUpdateTime(new Date());
        bizRespDepartmentalOpinionMapper.updateByPrimaryKeySelective(opinion);
    }


    /**
     * 粮食安全行政首长责任制----省级配合部门---批量上报
     *
     * @param phbmPublishVO
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED, rollbackFor = Exception.class)
    public void publishALL(ProvincePhbmPublishVO phbmPublishVO) {
        List<BizRespDepartmentalOpinion> phbmList = bizRespDepartmentalOpinionMapper.findByOpionInfo(phbmPublishVO);
        for (BizRespDepartmentalOpinion opinion : phbmList) {
            opinion.setStatus("30");
            opinion.setUpdateBy(phbmPublishVO.getUpdateBy());
            opinion.setUpdateTime(new Date());
            bizRespDepartmentalOpinionMapper.updateByPrimaryKeySelective(opinion);
        }
    }

}