package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.BizRespExcelSaveNewVO;
import com.unis.accountability.businessmanagement.common.vo.examinationExcel.BizRespExcelSaveVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.*;
import com.unis.accountability.businessmanagement.entity.*;
import com.unis.accountability.businessmanagement.mapper.*;
import com.unis.accountability.businessmanagement.service.BizRespExaminationTaskService;
import com.unis.accountability.businessmanagement.service.BizRespResponsibilityService;
import com.unis.common.utils.LsBeanUtils;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespRespScoreInputPublishVO;
import com.unis.accountability.businessmanagement.service.BizRespScoreInputService;
import com.unis.common.utils.UUIDUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * @Auther:张新亮
 * @Date: 2019/9/18 0018 11:09
 * @Description:
 */
@Service
@Transactional
public class BizRespResponsibilityServiceImpl implements BizRespResponsibilityService {

    @Autowired
    private BizRespResponsibilityMapper bizRespResponsibilityMapper;
    @Autowired
    private BizRespExaminationTaskService bizRespExaminationTaskService;
    @Autowired
    private BizRespExaminationTaskMapper bizRespExaminationTaskMapper;
    @Autowired
    private BizRespScoreInputService bizRespScoreInputService;
    @Autowired
    private BizRespExaminationContentMapper bizRespExaminationContentMapper;
    @Autowired
    private BizRespExaminationItemMapper bizRespExaminationItemMapper;
    @Autowired
    private BizRespExaminationQuotaMapper bizRespExaminationQuotaMapper;

    /**
     * 考核评分表管理---分页查询
     * @param pageVO
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<Map>> findByPage(BizRespResponsibilityPageVO pageVO, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        List<Map> mapList=bizRespResponsibilityMapper.findByPage(pageVO);
        for(Map map:mapList){
            String areaList=map.get("shi_area_code")==null?"":map.get("shi_area_code").toString();
            if(StringUtils.isEmpty(areaList)){
                map.put("NUMBER",0);
            }else{
                String[] are=areaList.split(",");
                map.put("NUMBER",are.length);
            }
            String id=map.get("id").toString();
            List<BizRespExaminationTask> taskList= bizRespExaminationTaskService.findBybilityId(id);
            if(taskList!=null && taskList.size()>0){
                map.put("ISFB","YES");
            }else{
                map.put("ISFB","NO");
            }
        }
        return listPage.toPageInfo();
    }




    /**
     * 根据评分表名称查询数据是否存在
     * @return
     */
    @Override
    public Map findByPfbmc(BizRespResponsibilityPfbmcVO pfbmcVO) {
        Map result=new HashMap();
        if(StringUtils.isEmpty(pfbmcVO.getId())){
            BizRespResponsibility responsibilityDO=bizRespResponsibilityMapper.findByPfbmc(pfbmcVO.getPfbmc(), pfbmcVO.getYear());
            if(responsibilityDO!=null){
                result.put("result","2");
                result.put("mes","评分表名称已存在");
            }else{
                result.put("result","1");
                result.put("mes","");
            }
        }else{
            BizRespResponsibility responsibilityDO=bizRespResponsibilityMapper.selectByPrimaryKey(pfbmcVO.getId());
            if(!pfbmcVO.getPfbmc().equals(responsibilityDO.getPfbmc())){
                BizRespResponsibility responsibility=bizRespResponsibilityMapper.findByPfbmc(pfbmcVO.getPfbmc(), pfbmcVO.getYear());
                if(responsibility!=null){
                    result.put("result","2");
                    result.put("mes","评分表名称已存在");
                }else{
                    result.put("result","1");
                    result.put("mes","");
                }
            }else{
                result.put("result","1");
                result.put("mes","");
            }
        }

        return result;
    }

    /**
     * 评分表管理---保存
     * @param bilitySaveVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean save(BilitySaveVO bilitySaveVO) {
        BizRespResponsibility bizRespResponsibilityDO = LsBeanUtils.copyProperties(bilitySaveVO.getBilityVO(), BizRespResponsibility.class);
        //创建人
        bizRespResponsibilityDO.setCreateBy(bilitySaveVO.getCreateBy());
        //创建时间
        bizRespResponsibilityDO.setCreateTime(new Date());
        bizRespResponsibilityDO.setUpdateTime(new Date());
        //行政区划
        bizRespResponsibilityDO.setAreaCode(bilitySaveVO.getAreaCode());
        //部门ID
        bizRespResponsibilityDO.setDeptId(bilitySaveVO.getDeptId());
        //组织机构id
        bizRespResponsibilityDO.setOrgId(bilitySaveVO.getOrgId());
        // 0-草稿；1-发布
        bizRespResponsibilityDO.setStatus(0);
        bizRespResponsibilityMapper.insertSelective(bizRespResponsibilityDO);
        return true;
    }


    /**
     *考核评分表管理------根据年份year和组织机构和ID查询基本信息
     * @param map
     * @return
     */
    @Override
    public BizRespResponsibilityVO findByYearAndOrgId(Map map) {
        BizRespResponsibility bizRespResponsibilityDO=bizRespResponsibilityMapper.findByYearAndOrgId(map);
        BizRespResponsibilityVO bizRespResponsibilityVO = LsBeanUtils.copyProperties(bizRespResponsibilityDO, BizRespResponsibilityVO.class);
        if(bizRespResponsibilityDO!=null){
            bizRespResponsibilityVO.setIds(bizRespResponsibilityDO.getId());
        }
        return bizRespResponsibilityVO;
    }



    /**
     * 考核评分表管理---删除责任考核
     * @param deleteVO
     * @return
     */
    @Override
    public Boolean deletes(DeleteVO deleteVO) {
        BizRespResponsibility bizRespResponsibilityDO=bizRespResponsibilityMapper.selectByPrimaryKey(deleteVO.getId());
        if(bizRespResponsibilityDO!=null){
            //删除人
            bizRespResponsibilityDO.setDeleteBy(deleteVO.getDeleteBy());
            //删除时间
            bizRespResponsibilityDO.setDeleteTime(new Date());

            bizRespResponsibilityMapper.updateByPrimaryKeySelective(bizRespResponsibilityDO);
        }
        return true;
    }

    /**
     * 考核评分表管理---发布
     * @param publishVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public String publish(BizRespResponsibilitPublishVO publishVO) {
        //发布所有区任务
        BizRespRespScoreInputPublishVO inputPublishVO=new BizRespRespScoreInputPublishVO();
        inputPublishVO.setId(publishVO.getId());
        inputPublishVO.setUpdateBy(publishVO.getUpdateBy());
        inputPublishVO.setAreaCodeList(publishVO.getAreaCodeList());
        bizRespScoreInputService.publish(inputPublishVO);
        return "1";
    }


    /**
     * 考核评分表管理---下级州市
     * @param cityVO
     * @return
     */
    @Override
    public List<String> findByRespResponsibilityCity(BizRespResponsibilityCityVO cityVO) {
        //查询已分配的州市
        List<String> zhoushiList= bizRespResponsibilityMapper.findByZhuoShi(cityVO);
        return zhoushiList;
    }

    /**
     * 考核评分表管理------根据ID查询基本信息
     * @param id
     * @return
     */
    @Override
    public BizRespResponsibilityVO findByInfo(String id) {
        BizRespResponsibility bizRespResponsibility= bizRespResponsibilityMapper.selectByPrimaryKey(id);
        BizRespResponsibilityVO bizRespResponsibilityVO = LsBeanUtils.copyProperties(bizRespResponsibility, BizRespResponsibilityVO.class);
        bizRespResponsibilityVO.setIds(bizRespResponsibility.getId());
        if(StringUtils.isNotEmpty(bizRespResponsibility.getShiAreaCode())){
            //修改时合部所有州市
            List<String> cityList=Arrays.asList(bizRespResponsibility.getShiAreaCode().split(","));
            bizRespResponsibilityVO.setShiAreaCode(cityList);
        }
        return bizRespResponsibilityVO;
    }


    /**
     * 考核评分表管理---更新评分表
     * @param updateVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public String updatePfb(BizRespResponsibilityUpdateVO updateVO) {
        BizRespResponsibility bizRespResponsibilityDO=bizRespResponsibilityMapper.selectByPrimaryKey(updateVO.getId());
        bizRespResponsibilityDO.setUpdateTime(new Date());
        bizRespResponsibilityDO.setUpdateBy(updateVO.getUpdateBy());
        String areacode= StringUtils.join(updateVO.getAreaCodeList(), ",");
        bizRespResponsibilityDO.setShiAreaCode(areacode);
        bizRespResponsibilityMapper.updateByPrimaryKeySelective(bizRespResponsibilityDO);
        //如果 status 为1  调用发布接口
        if(updateVO.getStatus()==1){
            BizRespRespScoreInputPublishVO publishVO=new BizRespRespScoreInputPublishVO();
            publishVO.setId(bizRespResponsibilityDO.getId());
            publishVO.setUpdateBy(updateVO.getUpdateBy());
            return  bizRespScoreInputService.publish(publishVO);
        }
        return "1";
    }

    /**
     * 考核评分表管理----根据id查询明细
     * @param id
     * @return
     */
    @Override
    public BizRespResponsibilityVO findByIds(String id) {
        BizRespResponsibility bizRespResponsibilityDO=bizRespResponsibilityMapper.selectByPrimaryKey(id);
        BizRespResponsibilityVO bizRespResponsibilityVO = LsBeanUtils.copyProperties(bizRespResponsibilityDO, BizRespResponsibilityVO.class);
        if(StringUtils.isNotEmpty(bizRespResponsibilityDO.getShiAreaCode())){
            bizRespResponsibilityVO.setShiAreaCode(Arrays.asList(bizRespResponsibilityDO.getShiAreaCode().split(",")));
        }
        return bizRespResponsibilityVO;
    }

    /**
     * 考核评分表管理---下发评表明细
     * @param pageVO
     * @return
     */
    @Override
    public Map bizRespResponsibilityService(BizRespResponsibilityPageVO pageVO) {
        Map result=new HashMap();

        List<Map> pfbList=new ArrayList();
        if("copy".equals(pageVO.getType())){
            pfbList=bizRespResponsibilityMapper.findByRespResponsibilityInfo(pageVO);
        }
        if("xf".equals(pageVO.getType())){
            pfbList=bizRespResponsibilityMapper.findByRespResponsibilityInfoXf(pageVO);
        }


        result.put("pfbList", pfbList);
        return result;
    }


    /**
     * 考核评分表管理---复制评分表
     * @param copyPfbVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean saveCopyPfb(BizRespCopyPfbVO copyPfbVO) {
        BizRespResponsibility bizRespResponsibility=bizRespResponsibilityMapper.findByYearAndPfbName(copyPfbVO.getOldYear(),copyPfbVO.getOldPfbmc());
        if(bizRespResponsibility!=null) {
            BizRespResponsibility newBility = LsBeanUtils.copyProperties(bizRespResponsibility, BizRespResponsibility.class);
            newBility.setPfbmc(copyPfbVO.getNewPfbmc());
            newBility.setYear(Integer.valueOf(copyPfbVO.getNewYear()));
            newBility.setId(UUIDUtils.uuid());
            // 0-草稿；1-发布
            newBility.setStatus(0);
            newBility.setFbTime(null);
            newBility.setShiAreaCode(null);
            //创建时间
            newBility.setCreateTime(new Date());
            newBility.setUpdateTime(new Date());
            bizRespResponsibilityMapper.insertSelective(newBility);


            List<BizRespExaminationTask> taskList = bizRespExaminationTaskMapper.findByBilityId(bizRespResponsibility.getId());
            for (BizRespExaminationTask task : taskList) {
                task.setId(UUIDUtils.uuid());
                task.setBizRespResponsibilityId(newBility.getId());
                //task.setBizRespExaminationQuotaId(newQuotaId);
                task.setStatus(0);
                //创建时间
                task.setCreateTime(new Date());
                task.setUpdateTime(new Date());
                bizRespExaminationTaskMapper.insertSelective(task);
            }
        }
        return true;
    }


    /**
     * 考核评分表管理---编辑修改评分表名称
     * @param bilityUpdateVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean update(BilityUpdateVO bilityUpdateVO) {
        BizRespResponsibility bizRespResponsibility=bizRespResponsibilityMapper.selectByPrimaryKey(bilityUpdateVO.getBilityVO().getIds());
        bizRespResponsibility.setPfbmc(bilityUpdateVO.getBilityVO().getPfbmc());
        bizRespResponsibility.setUpdateBy(bilityUpdateVO.getUpdateBy());
        bizRespResponsibility.setUpdateTime(new Date());
        bizRespResponsibilityMapper.updateByPrimaryKeySelective(bizRespResponsibility);
        return true;
    }

    @Override
    public BizRespResponsibility saveCheckExcelData(BizRespExcelSaveVO excelSaveVO) {
        return null;
    }

    /**
     * 考核评分表管理---保存填报信息
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public BizRespResponsibility saveCheckExcelData(BizRespExcelSaveNewVO excelSaveVO) {
        BizRespResponsibility bizRespResponsibilityDO=new BizRespResponsibility();
        bizRespResponsibilityDO.setYear(Integer.valueOf(excelSaveVO.getYear()));
        bizRespResponsibilityDO.setPfbmc(excelSaveVO.getPfbmc());
        //创建人
        bizRespResponsibilityDO.setCreateBy(excelSaveVO.getCreateBy());
        //创建时间
        bizRespResponsibilityDO.setCreateTime(new Date());
        bizRespResponsibilityDO.setUpdateTime(new Date());
        //行政区划
        bizRespResponsibilityDO.setAreaCode(excelSaveVO.getAreaCode());
        //部门ID
        bizRespResponsibilityDO.setDeptId(excelSaveVO.getDeptId());
        bizRespResponsibilityDO.setOrgId(excelSaveVO.getOrgId());
        // 0-草稿；1-发布
        bizRespResponsibilityDO.setStatus(0);
        bizRespResponsibilityMapper.insert(bizRespResponsibilityDO);
        return bizRespResponsibilityDO;
    }


    /**
     * 考核评分表管理------根据年分查询基本信息
     * @param year
     * @return
     */
    @Override
    public BizRespResponsibilityVO findByYear(String year) {
        BizRespResponsibility bizRespResponsibility= bizRespResponsibilityMapper.findByYearAndPfbName(year, null);
        BizRespResponsibilityVO bizRespResponsibilityVO = LsBeanUtils.copyProperties(bizRespResponsibility, BizRespResponsibilityVO.class);
        if(bizRespResponsibility!=null){
            bizRespResponsibilityVO.setIds(bizRespResponsibility.getId());
            if(StringUtils.isNotEmpty(bizRespResponsibility.getShiAreaCode())){
                //修改时合部所有州市
                List<String> cityList=Arrays.asList(bizRespResponsibility.getShiAreaCode().split(","));
                bizRespResponsibilityVO.setShiAreaCode(cityList);
            }
        }
        return bizRespResponsibilityVO;
    }


}