package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.service.BizRespScoringCityService;
import com.unis.common.utils.DateUtil;
import com.unis.accountability.businessmanagement.common.vo.scoringCity.BizRespScoringCityPublishVO;
import com.unis.accountability.businessmanagement.common.vo.scoringCity.BizRespScoringCityVO;
import com.unis.accountability.businessmanagement.common.vo.scoringCity.ScoringCityUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.scoringCity.ScoringPage;
import com.unis.accountability.businessmanagement.entity.BizRespScoringCity;
import com.unis.accountability.businessmanagement.mapper.BizRespScoringCityMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @Auther:张新亮
 * @Date: 2019/9/19 0019 18:44
 * @Description:
 */
@Service
@Transactional
public class BizRespScoringCityImpl implements BizRespScoringCityService {
    @Autowired
    private BizRespScoringCityMapper bizRespScoringCityMapper;

    /**
     * 粮食安全首长责任制--州市任务填报设置----分页
     * @param scoringPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<Map>> findByPage(ScoringPage scoringPage, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        List<Map> mapLists=bizRespScoringCityMapper.findByPage(scoringPage);
        return listPage.toPageInfo();
    }



    /**
     * 粮食安全首长责任制--州市任务填报设置----查看
     * @param id
     * @return
     */
    @Override
    public BizRespScoringCityVO findById(String id) {
        BizRespScoringCity bizRespScoringCity=bizRespScoringCityMapper.selectByPrimaryKey(id);
        BizRespScoringCityVO cityVO=new BizRespScoringCityVO();
        //年份
        cityVO.setYear(bizRespScoringCity.getYear());
        List<String> sjPhbmTime=new ArrayList();

        //州市配合部门开始时间
        if(bizRespScoringCity.getSjPhbmStartTime()!=null){
            String date= DateUtil.getDateFormat(bizRespScoringCity.getSjPhbmStartTime(), DateUtil.YYYYMMDD);
            sjPhbmTime.add(date);
        }
        //州市配合部门结束时间
        if(bizRespScoringCity.getSjPhbmEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjPhbmEndTime(), DateUtil.YYYYMMDD);
            sjPhbmTime.add(date);
        }
        cityVO.setSjPhbmTime(sjPhbmTime);
        List<String> sjQtbmTime=new ArrayList();
        //市牵头部门开始时间
        if(bizRespScoringCity.getSjQtbmStartTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjQtbmStartTime(), DateUtil.YYYYMMDD);
            sjQtbmTime.add(date);
        }
        //市牵头部门结束时间
        if(bizRespScoringCity.getSjQtbmEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjQtbmEndTime(), DateUtil.YYYYMMDD);
            sjQtbmTime.add(date);
        }
        cityVO.setSjQtbmTime(sjQtbmTime);


        List<String> sjZpbmTime=new ArrayList();
        //市自评部门开始时间
        if(bizRespScoringCity.getSjZpbmStartTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjZpbmStartTime(), DateUtil.YYYYMMDD);
            sjZpbmTime.add(date);
        }
        //市自评部门结束时间
        if(bizRespScoringCity.getSjQtbmEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjZpbmEndTime(), DateUtil.YYYYMMDD);
            sjZpbmTime.add(date);
        }
        cityVO.setSjZpbmTime(sjZpbmTime);
        cityVO.setIds(bizRespScoringCity.getId());
        return cityVO;
    }


    /**
     * 粮食安全首长责任制--州市任务填报设置----根据年分查询明细
     * @param year
     * @param orgId
     * @return
     */
    @Override
    public BizRespScoringCityVO findByYearAndOrgId(String year, String orgId) {
        BizRespScoringCity bizRespScoringCity=bizRespScoringCityMapper.findByYearAndOrgId(year,orgId);
        BizRespScoringCityVO cityVO=new BizRespScoringCityVO();
        if(bizRespScoringCity==null){
            return cityVO;

        }
        //年份
        cityVO.setYear(bizRespScoringCity.getYear());
        List<String> sjPhbmTime=new ArrayList();

        //州市配合部门开始时间
        if(bizRespScoringCity.getSjPhbmStartTime()!=null){
            String date= DateUtil.getDateFormat(bizRespScoringCity.getSjPhbmStartTime(), DateUtil.YYYYMMDD);
            sjPhbmTime.add(date);
        }
        //州市配合部门结束时间
        if(bizRespScoringCity.getSjPhbmEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjPhbmEndTime(), DateUtil.YYYYMMDD);
            sjPhbmTime.add(date);
        }
        cityVO.setSjPhbmTime(sjPhbmTime);
        List<String> sjQtbmTime=new ArrayList();
        //市牵头部门开始时间
        if(bizRespScoringCity.getSjQtbmStartTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjQtbmStartTime(), DateUtil.YYYYMMDD);
            sjQtbmTime.add(date);
        }
        //市牵头部门结束时间
        if(bizRespScoringCity.getSjQtbmEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjQtbmEndTime(), DateUtil.YYYYMMDD);
            sjQtbmTime.add(date);
        }
        cityVO.setSjQtbmTime(sjQtbmTime);


        List<String> sjZpbmTime=new ArrayList();
        //市自评部门开始时间
        if(bizRespScoringCity.getSjZpbmStartTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjZpbmStartTime(), DateUtil.YYYYMMDD);
            sjZpbmTime.add(date);
        }
        //市自评部门结束时间
        if(bizRespScoringCity.getSjQtbmEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringCity.getSjZpbmEndTime(), DateUtil.YYYYMMDD);
            sjZpbmTime.add(date);
        }
        cityVO.setSjZpbmTime(sjZpbmTime);
        cityVO.setIds(bizRespScoringCity.getId());
        return cityVO;

    }






    /**
     * 粮食安全首长责任制--州市任务填报设置---编辑
     * @param scoringCityUpdateVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean update(ScoringCityUpdateVO scoringCityUpdateVO) {
        BizRespScoringCity bizRespScoringCity=bizRespScoringCityMapper.selectByPrimaryKey(scoringCityUpdateVO.getCityVO().getIds());
          //市配合部门开始时间
        if(scoringCityUpdateVO.getCityVO().getSjPhbmStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(scoringCityUpdateVO.getCityVO().getSjPhbmStartTime(), DateUtil.YYYYMMDD);
            bizRespScoringCity.setSjPhbmStartTime(date);
        }
        //市配合部门结束时间
        if(scoringCityUpdateVO.getCityVO().getSjPhbmEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(scoringCityUpdateVO.getCityVO().getSjPhbmEndTime(), DateUtil.YYYYMMDD);
            bizRespScoringCity.setSjPhbmEndTime(date);
        }
        //市牵头部门开始时间
        if(scoringCityUpdateVO.getCityVO().getSjQtbmStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(scoringCityUpdateVO.getCityVO().getSjQtbmStartTime(), DateUtil.YYYYMMDD);
            bizRespScoringCity.setSjQtbmStartTime(date);
        }
        //市牵头部门结束时间
        if(scoringCityUpdateVO.getCityVO().getSjQtbmEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(scoringCityUpdateVO.getCityVO().getSjQtbmEndTime(), DateUtil.YYYYMMDD);
            bizRespScoringCity.setSjQtbmEndTime(date);
        }


        //市自评部门开始时间
        if(scoringCityUpdateVO.getCityVO().getSjZpbmStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(scoringCityUpdateVO.getCityVO().getSjZpbmStartTime(), DateUtil.YYYYMMDD);
            bizRespScoringCity.setSjZpbmStartTime(date);
        }
        //市牵头部门结束时间
        if(scoringCityUpdateVO.getCityVO().getSjZpbmEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(scoringCityUpdateVO.getCityVO().getSjZpbmEndTime(), DateUtil.YYYYMMDD);
            bizRespScoringCity.setSjZpbmEndTime(date);
        }

        bizRespScoringCity.setUpdateBy(scoringCityUpdateVO.getUpdateBy());
        bizRespScoringCity.setOrgId(scoringCityUpdateVO.getOrgId());
        bizRespScoringCity.setDeptId(scoringCityUpdateVO.getDeptId());
        bizRespScoringCityMapper.updateByPrimaryKeySelective(bizRespScoringCity);
        return true;
    }

    /**
     * 粮食安全首长责任制--州市考核任务管理----发布
     * @param inputPublishVO
     */
    @Override
    public void publish(BizRespScoringCityPublishVO inputPublishVO) {
        BizRespScoringCity bizRespScoringCity=bizRespScoringCityMapper.selectByPrimaryKey(inputPublishVO.getId());
        bizRespScoringCity.setStatus(1);
        bizRespScoringCity.setUpdateBy(inputPublishVO.getUpdateBy());
        bizRespScoringCity.setFbTime(new Date());
        bizRespScoringCityMapper.updateByPrimaryKeySelective(bizRespScoringCity);
    }

    /**
     * 时间比较
     * @param scoringCity
     * @param type
     * @return
     */
    @Override
    public String weightCompareTo(BizRespScoringCity scoringCity, String type) {
        String result="";
        //市自评部门
        if("cityZpbm".equals(type)){
            //州市考核开始时间
            Date zsStartTime=scoringCity.getSjZpbmStartTime();
            //州市考核结束时间
            Date zsEndTime=scoringCity.getSjZpbmEndTime();
            if(zsStartTime==null || zsEndTime==null){
                result="no";
            }else{
                //当前时
                Date nowTime=new Date();
                boolean resu= belongCalendar(nowTime,zsStartTime,zsEndTime);
                if(resu){
                    result="yes";
                }else{
                    result="no";
                }
            }

        }

        //市配合部门
        if("cityPhbm".equals(type)){
            //州市考核开始时间
            Date zsStartTime=scoringCity.getSjPhbmStartTime();
            //州市考核结束时间
            Date zsEndTime=scoringCity.getSjPhbmEndTime();
            if(zsStartTime==null || zsEndTime==null){
                result="no";
            }else{
                //当前时
                Date nowTime=new Date();
                boolean resu= belongCalendar(nowTime,zsStartTime,zsEndTime);
                if(resu){
                    result="yes";
                }else{
                    result="no";
                }
            }
        }


        //市牵头部门
        if("cityQtbm".equals(type)){
            //州市考核开始时间
            Date zsStartTime=scoringCity.getSjQtbmStartTime();
            //州市考核结束时间
            Date zsEndTime=scoringCity.getSjQtbmEndTime();
            if(zsStartTime==null || zsEndTime==null){
                result="no";
            }else{
                //当前时
                Date nowTime=new Date();
                boolean resu= belongCalendar(nowTime,zsStartTime,zsEndTime);
                if(resu){
                    result="yes";
                }else{
                    result="no";
                }
            }
        }
        return result;
    }


    /**
     * 粮食安全首长责任制--州市考核任务管理----根据年份和状态查贸易 州市任务填报设置 信怎
     * @param year
     * @param status
     * @return
     */
    @Override
    public BizRespScoringCity findByYearAndStatus(String year, String status,String areaCode) {
        return bizRespScoringCityMapper.findByYearAndStatus(year,status,areaCode);

    }



    public  boolean belongCalendar(Date nowTime, Date beginTime, Date endTime) {
        SimpleDateFormat st = new SimpleDateFormat("yyyy-MM-dd 00:00:00");
        SimpleDateFormat ed = new SimpleDateFormat("yyyy-MM-dd 23:59:59");
        Long now=nowTime.getTime();
        System.out.println("now:==" + now);

        Long begin = DateUtil.toDate(st.format(beginTime), "yyyy-MM-dd HH:mm:ss").getTime();
        System.out.println("begin:==" + begin);
        Long end= DateUtil.toDate(ed.format(endTime), "yyyy-MM-dd HH:mm:ss").getTime();
        System.out.println("end:==" + end);
        if(now>= begin && now<=end){
            return true;
        }else{
            return false;
        }
    }
}