package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.scoringWeight.*;
import com.unis.accountability.businessmanagement.entity.BizRespResponsibility;
import com.unis.accountability.businessmanagement.mapper.BizRespResponsibilityMapper;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.entity.BizRespScoringWeight;
import com.unis.accountability.businessmanagement.entity.BizRespScoringWeightRank;
import com.unis.accountability.businessmanagement.mapper.BizRespScoringWeightMapper;
import com.unis.accountability.businessmanagement.mapper.BizRespScoringWeightRankMapper;
import com.unis.accountability.businessmanagement.service.BizRespScoringWeightService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestBody;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.*;

/**粮食安全行政首长责任制-----考核评分权重
 * @Auther:张新亮
 * @Date: 2019/9/17 0017 15:20
 * @Description:
 */
@Service
@Transactional
public class BizRespScoringWeightServiceImpl implements BizRespScoringWeightService {
    @Autowired
    private BizRespScoringWeightMapper bizRespScoringWeightMapper;
    @Autowired
    private BizRespScoringWeightRankMapper bizRespScoringWeightRankMapper;
    @Autowired
    private BizRespResponsibilityMapper bizRespResponsibilityMapper;

    /**
     * 考核评分权重--考核等级设置
     * @param type
     * @param id
     * @return
     */
    @Override
    public List<BizRespScoringWeightRankVO> findByWeightRank(String type, String id) {
        List<BizRespScoringWeightRankVO> list=new ArrayList();
        BizRespScoringWeightRankVO rankVO=null;
        if("save".equals(type)){
            rankVO=new BizRespScoringWeightRankVO();
            rankVO.setRankName("优秀");
            rankVO.setFzStart("90");
            rankVO.setFzEnd("100");
            list.add(rankVO);
            rankVO=new BizRespScoringWeightRankVO();
            rankVO.setRankName("良好");
            rankVO.setFzStart("75");
            rankVO.setFzEnd("89");
            list.add(rankVO);
            rankVO=new BizRespScoringWeightRankVO();
            rankVO.setRankName("合格");
            rankVO.setFzStart("60");
            rankVO.setFzEnd("74");
            list.add(rankVO);
            rankVO=new BizRespScoringWeightRankVO();
            rankVO.setRankName("不合格");
            rankVO.setFzStart("0");
            rankVO.setFzEnd("59");
            list.add(rankVO);
        }
        return list;
    }


    /**
     * 考核评分权重--考核等级设置
     * @param type save 新增 page 分页查询
     * @return
     */
    @Override
    public List<Integer> findByAll(String type) {
        List<BizRespScoringWeight> weightDOList=bizRespScoringWeightMapper.findByAll();
        List<Integer> result=new ArrayList();
        if("save".equals(type)){
            Integer year= DateUtil.getYearString();
            for(int i=0;i<10;i++){
                Integer ye=year-i;
                Boolean res=getSingleDogs(ye, weightDOList);
                if(!res){
                    result.add(ye);
                }
            }
        }

        if("page".equals(type)){
            for(BizRespScoringWeight weightDO:weightDOList){
                if(weightDO.getStatus().intValue()==1){
                    result.add(weightDO.getYear());
                }
            }
        }

        return result;
    }

    /**
     * 考核评分权重--查询复制评分表可选年分
     * @param year1
     * @return
     */
    @Override
    public Map findByCopyYear() {
        Map result=new HashMap();
        //考核年度
        List<Integer> khndList=new ArrayList();
        List<BizRespResponsibility> bilityList=bizRespResponsibilityMapper.findByAll();
        for(BizRespResponsibility bizRespResponsibility:bilityList){
            khndList.add(bizRespResponsibility.getYear());
        }
        //新考核年度
        List<Integer> newKhnfList=new ArrayList();
        List<BizRespScoringWeight> weightDOList=bizRespScoringWeightMapper.findByAll();
        for(BizRespScoringWeight weight:weightDOList){
            Map map=new HashMap();
            map.put("year",weight.getYear());
            BizRespResponsibility bizRespResponsibility= bizRespResponsibilityMapper.findByYearAndOrgId(map);
            if(bizRespResponsibility==null){
                newKhnfList.add(weight.getYear());
            }
        }
        result.put("khndList",khndList);
        result.put("newKhnfList",newKhnfList);
        return result;
    }


    /**
     * 去重复数据
     * @param
     * @return
     */
    public  Boolean getSingleDogs(Integer year, List<BizRespScoringWeight> weightDOList) {
        for(BizRespScoringWeight weightDO:weightDOList){
            if(weightDO.getYear().equals(year)){
                Map map=new HashMap();
                map.put("year",year);
                BizRespResponsibility bizRespResponsibility= bizRespResponsibilityMapper.findByYearAndOrgId(map);
                if(bizRespResponsibility==null){
                    return false;
                }else{
                    return true;
                }
            }
        }
        return false;
    }


    /**
     * 根据年分和状态---考核评分权重--对象
     * @param year
     * @param status
     * @return
     */
    @Override
    public BizRespScoringWeight findByYearAndStatus(Integer year, Integer status) {
        List<BizRespScoringWeight> weightDOList=bizRespScoringWeightMapper.findByAll();
        for(BizRespScoringWeight weightDO:weightDOList){
            if(weightDO.getYear().equals(year) && weightDO.getStatus().equals(status)){
                return weightDO;
            }
        }
        return null;
    }

    /**
     * 考核评分权重-----保存
     * @param weightSaveVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean save(WeightSaveVO weightSaveVO) {
        BizRespScoringWeight weightDO = LsBeanUtils.copyProperties(weightSaveVO.getWeightVO(), BizRespScoringWeight.class);
        weightDO.setId(UUIDUtils.uuid());

        //省级年终配合部门开始时间
        if(weightSaveVO.getWeightVO().getSjPhbmStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjPhbmStartTime(), DateUtil.YYYYMMDD);
            weightDO.setSjPhbmStartTime(date);
        }
        //省级年终配合部门结束时间
        if(weightSaveVO.getWeightVO().getSjPhbmEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjPhbmEndTime(), DateUtil.YYYYMMDD);
            weightDO.setSjPhbmEndTime(date);
        }
        //省级年终牵头部门开始时间
        if(weightSaveVO.getWeightVO().getSjQtbmStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjQtbmStartTime(), DateUtil.YYYYMMDD);
            weightDO.setSjQtbmStartTime(date);
        }
        //省级年终牵头部门结束时间
        if(weightSaveVO.getWeightVO().getSjQtbmEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjQtbmEndTime(), DateUtil.YYYYMMDD);
            weightDO.setSjQtbmEndTime(date);
        }



        //省级平时配合部门开始时间
        if(weightSaveVO.getWeightVO().getSjPhbmPsStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjPhbmPsStartTime(), DateUtil.YYYYMMDD);
            weightDO.setSjPhbmPsStartTime(date);
        }
        //省级平时配合部门结束时间
        if(weightSaveVO.getWeightVO().getSjPhbmPsEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjPhbmPsEndTime(), DateUtil.YYYYMMDD);
            weightDO.setSjPhbmPsEndTime(date);
        }
        //省级平时牵头部门开始时间
        if(weightSaveVO.getWeightVO().getSjQtbmPsStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjQtbmPsStartTime(), DateUtil.YYYYMMDD);
            weightDO.setSjQtbmPsStartTime(date);
        }
        //省级平时牵头部门结束时间
        if(weightSaveVO.getWeightVO().getSjQtbmPsEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjQtbmPsEndTime(), DateUtil.YYYYMMDD);
            weightDO.setSjQtbmPsEndTime(date);
        }


        //创建时间
        weightDO.setCreateTime(new Date());
        weightDO.setUpdateTime(new Date());
        //创建人
        weightDO.setCreateBy(weightSaveVO.getCreateBy());
        //行政区划
        weightDO.setAreaCode(weightSaveVO.getAreaCode());
        //组织机构id
        weightDO.setOrgId(weightSaveVO.getOrgId());
        //部门ID
        weightDO.setDeptId(weightSaveVO.getDeptId());
        //0-草稿；1-发布
        weightDO.setStatus(0);


        for(BizRespScoringWeightRankVO rankVO:weightSaveVO.getWeightVO().getWeightRankList()){
            BizRespScoringWeightRank rankDO=new BizRespScoringWeightRank();
            rankDO.setRankName(rankVO.getRankName());
            rankDO.setFzStart(rankVO.getFzStart());
            rankDO.setFzEnd(rankVO.getFzEnd());
            rankDO.setBizRespScoringWeightId(weightDO.getId());
            //创建时间
            rankDO.setCreateTime(new Date());
            rankDO.setUpdateTime(new Date());
            //创建人
            rankDO.setCreateBy(weightSaveVO.getCreateBy());
            //行政区划
            rankDO.setAreaCode(weightSaveVO.getAreaCode());
            //部门ID
            rankDO.setDeptId(weightSaveVO.getDeptId());
            //组织机构id
            rankDO.setOrgId(weightSaveVO.getOrgId());
            bizRespScoringWeightRankMapper.insertSelective(rankDO);
        }
        bizRespScoringWeightMapper.insertSelective(weightDO);
        return true;
    }


    /**
     * 核评分权重------分页查询
     * @param pageVO
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<Map>> findByPage(BizRespScoringWeightPageVO pageVO, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        List<Map> mapList=bizRespScoringWeightMapper.findByPage(pageVO);
        return listPage.toPageInfo();
    }

    /**
     * 根据ID查询 考核评分权重 明细
     * @param id
     * @return
     */
    @Override
    public WeightInfoVO findById(String id) {
        BizRespScoringWeight bizRespScoringWeightDO=bizRespScoringWeightMapper.selectByPrimaryKey(id);
        WeightInfoVO scoringWeightVO =new WeightInfoVO();
        scoringWeightVO.setIds(bizRespScoringWeightDO.getId());
        //年份
        scoringWeightVO.setYear(bizRespScoringWeightDO.getYear());


        List<String> sjPhbmTime=new ArrayList();
        //省级年终配合部门开始时间
        if(bizRespScoringWeightDO.getSjPhbmStartTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringWeightDO.getSjPhbmStartTime(), DateUtil.YYYYMMDD);
            sjPhbmTime.add(date);
        }
        //省级年终配合部门结束时间
        if(bizRespScoringWeightDO.getSjPhbmEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringWeightDO.getSjPhbmEndTime(), DateUtil.YYYYMMDD);
            sjPhbmTime.add(date);
        }
        scoringWeightVO.setSjPhbmTime(sjPhbmTime);

        List<String> sjQtbmTime=new ArrayList();
        //省级年终牵头部门开始时间
        if(bizRespScoringWeightDO.getSjQtbmStartTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringWeightDO.getSjQtbmStartTime(), DateUtil.YYYYMMDD);
            sjQtbmTime.add(date);
        }
        //省级年终牵头部门结束时间
        if(bizRespScoringWeightDO.getSjQtbmEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringWeightDO.getSjQtbmEndTime(), DateUtil.YYYYMMDD);
            sjQtbmTime.add(date);
        }
        scoringWeightVO.setSjQtbmTime(sjQtbmTime);


        List<String> sjPsPhbmTime=new ArrayList();
        //省级平时配合部门开始时间
        if(bizRespScoringWeightDO.getSjPhbmPsStartTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringWeightDO.getSjPhbmPsStartTime(), DateUtil.YYYYMMDD);
            sjPsPhbmTime.add(date);
        }
        //省级平时配合部门结束时间
        if(bizRespScoringWeightDO.getSjPhbmPsEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringWeightDO.getSjPhbmPsEndTime(), DateUtil.YYYYMMDD);
            sjPsPhbmTime.add(date);
        }
        scoringWeightVO.setSjPhbmPsTime(sjPsPhbmTime);

        List<String> sjPsQtbmTime=new ArrayList();
        //省级平时牵头部门开始时间
        if(bizRespScoringWeightDO.getSjQtbmPsStartTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringWeightDO.getSjQtbmPsStartTime(), DateUtil.YYYYMMDD);
            sjPsQtbmTime.add(date);
        }
        //省级平时牵头部门结束时间
        if(bizRespScoringWeightDO.getSjQtbmPsEndTime()!=null){
            String date=DateUtil.getDateFormat(bizRespScoringWeightDO.getSjQtbmPsEndTime(), DateUtil.YYYYMMDD);
            sjPsQtbmTime.add(date);
        }
        scoringWeightVO.setSjQtbmPsTime(sjPsQtbmTime);
        //省级牵头分权重
        scoringWeightVO.setSjQtbmWeight(bizRespScoringWeightDO.getSjQtbmWeight());
        //省级牵头复评分权重
        scoringWeightVO.setSjQtbmFpWeight(bizRespScoringWeightDO.getSjQtbmFpWeight());
        //州市单位自评分权重
        scoringWeightVO.setZsZpbmWeight(bizRespScoringWeightDO.getZsZpbmWeight());
        //总分
        if(bizRespScoringWeightDO.getTotalScore()!=null){
            scoringWeightVO.setTotalScore(convertDoubleToString(bizRespScoringWeightDO.getTotalScore()));
        }
        return scoringWeightVO;
    }



    private  String convertDoubleToString(double val) {
        BigDecimal bd = new BigDecimal(String.valueOf(val));
        return bd.stripTrailingZeros().toPlainString();
    }


    /**
     * 考核评分权重--考核等级
     * @param id
     * @return
     */
    @Override
    public List<BizRespScoringWeightRankVO> findByRankId(String id) {
        List<BizRespScoringWeightRankVO> mapList=bizRespScoringWeightRankMapper.findByScoringWeightId(id);
        return mapList;
    }

    /**
     * 核评分权重---修改
     * @param weightSaveVO
     * @return
     */
    @Override
    public boolean update(WeightUpdateVO weightSaveVO) {
        BizRespScoringWeight weightDO=bizRespScoringWeightMapper.selectByPrimaryKey(weightSaveVO.getWeightVO().getIds());

        //省级年终配合部门开始时间
        if(weightSaveVO.getWeightVO().getSjPhbmStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjPhbmStartTime(), DateUtil.YYYYMMDD);
            weightDO.setSjPhbmStartTime(date);
        }
        //省级年终配合部门结束时间
        if(weightSaveVO.getWeightVO().getSjPhbmEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjPhbmEndTime(), DateUtil.YYYYMMDD);
            weightDO.setSjPhbmEndTime(date);
        }
        //省级年终牵头部门开始时间
        if(weightSaveVO.getWeightVO().getSjQtbmStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjQtbmStartTime(), DateUtil.YYYYMMDD);
            weightDO.setSjQtbmStartTime(date);
        }
        //省级年终牵头部门结束时间
        if(weightSaveVO.getWeightVO().getSjQtbmEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjQtbmEndTime(), DateUtil.YYYYMMDD);
            weightDO.setSjQtbmEndTime(date);
        }



        //省级平时配合部门开始时间
        if(weightSaveVO.getWeightVO().getSjPhbmPsStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjPhbmPsStartTime(), DateUtil.YYYYMMDD);
            weightDO.setSjPhbmPsStartTime(date);
        }
        //省级平时配合部门结束时间
        if(weightSaveVO.getWeightVO().getSjPhbmPsEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjPhbmPsEndTime(), DateUtil.YYYYMMDD);
            weightDO.setSjPhbmPsEndTime(date);
        }
        //省级平时牵头部门开始时间
        if(weightSaveVO.getWeightVO().getSjQtbmPsStartTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjQtbmPsStartTime(), DateUtil.YYYYMMDD);
            weightDO.setSjQtbmPsStartTime(date);
        }
        //省级平时牵头部门结束时间
        if(weightSaveVO.getWeightVO().getSjQtbmPsEndTime()!=null){
            Date date=DateUtil.turnStrDateToJavaUtilDate(weightSaveVO.getWeightVO().getSjQtbmPsEndTime(), DateUtil.YYYYMMDD);
            weightDO.setSjQtbmPsEndTime(date);
        }



        //省级牵头分权重
        weightDO.setSjQtbmWeight(weightSaveVO.getWeightVO().getSjQtbmWeight());
        //省级牵头复评分权重
        weightDO.setSjQtbmFpWeight(weightSaveVO.getWeightVO().getSjQtbmFpWeight());
        //州市单位自评分权重
        weightDO.setZsZpbmWeight(weightSaveVO.getWeightVO().getZsZpbmWeight());
        //修改时间
        weightDO.setUpdateTime(new Date());
        //修改人
        weightDO.setUpdateBy(weightSaveVO.getUpdateBy());

        for(BizRespScoringWeightRankVO rankVO:weightSaveVO.getWeightVO().getWeightRankList()){
            BizRespScoringWeightRank rankDO=bizRespScoringWeightRankMapper.selectByPrimaryKey(rankVO.getId());
            rankDO.setRankName(rankVO.getRankName());
            rankDO.setFzStart(rankVO.getFzStart());
            rankDO.setFzEnd(rankVO.getFzEnd());
            rankDO.setBizRespScoringWeightId(weightDO.getId());
            //修改时间
            rankDO.setUpdateTime(new Date());
            //修改人
            rankDO.setUpdateBy(weightSaveVO.getUpdateBy());
            bizRespScoringWeightRankMapper.updateByPrimaryKeySelective(rankDO);
        }
        bizRespScoringWeightMapper.updateByPrimaryKeySelective(weightDO);
        return true;
    }

    /**
     * 发布
     * @param publishVO
     */
    @Override
    public void publish(BizRespScoringWeightPublishVO publishVO) {
        BizRespScoringWeight weightDO= bizRespScoringWeightMapper.selectByPrimaryKey(publishVO.getId());
        weightDO.setStatus(1);
        //创建时间
        weightDO.setUpdateTime(new Date());
        //创建人
        weightDO.setUpdateBy(publishVO.getUpdateBy());
        weightDO.setFbTime(new Date());
        bizRespScoringWeightMapper.updateByPrimaryKeySelective(weightDO);
    }

    /**
     * 删除
     * @param deleteVO
     * @return
     */
    @Override
    public Boolean delete(@RequestBody DeleteVO deleteVO) {
        BizRespScoringWeight weightDO= bizRespScoringWeightMapper.selectByPrimaryKey(deleteVO.getId());
        weightDO.setDeleteTime(new Date());
        weightDO.setDeleteBy(deleteVO.getDeleteBy());
        bizRespScoringWeightMapper.updateByPrimaryKeySelective(weightDO);
        return true;
    }

    /**
     * 时间比较
     * @param weightDO
     * @param
     * @return
     */
    @Override
    public String weightCompareTo(BizRespScoringWeight weightDO, String type) {

        String result="";
        //市级合部门
        if("cityPhbm".equals(type)){
            //省级配合部门开始时间
            Date zsStartTime=weightDO.getSjPhbmStartTime();
            //省级配合部门结束时间
            Date zsEndTime=weightDO.getSjPhbmEndTime();
            //当前时
            Date nowTime=new Date();
            boolean resu= belongCalendar(nowTime,zsStartTime,zsEndTime);
            if(resu){
                result="yes";
            }else{
                result="no";
            }
        }


        //市级牵头部门
        if("cityQtbm".equals(type)){
            //省级牵头部门开始时间
            Date zsStartTime=weightDO.getSjQtbmStartTime();
            //省级牵头部门结束时间
            Date zsEndTime=weightDO.getSjQtbmEndTime();
            //当前时
            Date nowTime=new Date();
            boolean resu= belongCalendar(nowTime,zsStartTime,zsEndTime);
            if(resu){
                result="yes";
            }else{
                result="no";
            }
        }

        //区级牵头部门
        if("qjQtbm".equals(type)){
            //区级牵头部门开始时间
            Date zsStartTime=weightDO.getSjQtbmPsStartTime();
            //区级牵头部门结束时间
            Date zsEndTime=weightDO.getSjQtbmPsEndTime();
            //当前时
            Date nowTime=new Date();
            boolean resu= belongCalendar(nowTime,zsStartTime,zsEndTime);
            if(resu){
                result="yes";
            }else{
                result="no";
            }
        }

        //区级配合部门
        if("qjPtbm".equals(type)){
            //区级配合部门开始时间
            Date zsStartTime=weightDO.getSjPhbmPsStartTime();
            //区级配合部门结束时间
            Date zsEndTime=weightDO.getSjPhbmPsEndTime();
            //当前时
            Date nowTime=new Date();
            boolean resu= belongCalendar(nowTime,zsStartTime,zsEndTime);
            if(resu){
                result="yes";
            }else{
                result="no";
            }
        }

        return result;
    }

    /**
     * 根据年分查询
     * @param year
     * @return
     */
    @Override
    public BizRespScoringWeight findByYear(Integer year) {
        return bizRespScoringWeightMapper.findByYear(year);
    }


    public  boolean belongCalendar(Date nowTime, Date beginTime, Date endTime) {
        SimpleDateFormat st = new SimpleDateFormat("yyyy-MM-dd 00:00:00");
        SimpleDateFormat ed = new SimpleDateFormat("yyyy-MM-dd 23:59:59");
        Long now=nowTime.getTime();
        System.out.println("now:=="+now);

        Long begin = DateUtil.toDate(st.format(beginTime), "yyyy-MM-dd HH:mm:ss").getTime();
        System.out.println("begin:==" + begin);
        Long end= DateUtil.toDate(ed.format(endTime), "yyyy-MM-dd HH:mm:ss").getTime();
        System.out.println("end:=="+end);
        if(now>= begin && now<=end){
            return true;
        }else{
            return false;
        }
    }


}