package com.unis.accountability.businessmanagement.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.msgNotice.*;
import com.unis.accountability.businessmanagement.entity.BizRespExaminationTask;
import com.unis.accountability.businessmanagement.entity.MsgNotice;
import com.unis.accountability.businessmanagement.entity.MsgNoticeUser;
import com.unis.accountability.businessmanagement.mapper.MsgNoticeMapper;
import com.unis.accountability.businessmanagement.mapper.MsgNoticeUserMapper;
import com.unis.accountability.businessmanagement.service.MsgNoticeService;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/11/5 0005 14:36
 * @Description:
 */
@Service
@Transactional
public class MsgNoticeServiceImpl implements MsgNoticeService {
    @Autowired
    private MsgNoticeMapper msgNoticeMapper;
    @Autowired
    private MsgNoticeUserMapper msgNoticeUserMapper;

    /**
     * 信息报送----保存
     * @param msgNoticeSaveVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean save(MsgNoticeSaveVO msgNoticeSaveVO) {
        MsgNotice msgNotice = LsBeanUtils.copyProperties(msgNoticeSaveVO.getMsgNoticeVO(), MsgNotice.class);
        //创建时间
        msgNotice.setCreateTime(new Date());
        msgNotice.setUpdateTime(new Date());
        msgNotice.setPublishTime(new Date());
        msgNotice.setPublishBy(msgNoticeSaveVO.getCreateBy());
        //创建人
        msgNotice.setCreateBy(msgNoticeSaveVO.getCreateBy());
        //行政区划
        msgNotice.setAreaCode(msgNoticeSaveVO.getAreaCode());
        //机构ID
        msgNotice.setOrgId(msgNoticeSaveVO.getOrgId());
        //部门ID
        msgNotice.setDeptId(msgNoticeSaveVO.getDeptId());
        //上传文件
        if(msgNoticeSaveVO.getMsgNoticeVO().getFileId()!=null && msgNoticeSaveVO.getMsgNoticeVO().getFileId().size()>0){
            String fileList= StringUtils.join(msgNoticeSaveVO.getMsgNoticeVO().getFileId(), ",");
            msgNotice.setFileId(fileList);
        }
        int result=msgNoticeMapper.insertSelective(msgNotice);
        if(result>0){
            return true;
        }
        return false;
    }


    /**
     * 信息报送----分页
     * @param msgNoticePage
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<List<Map>> findByPage(
            MsgNoticePage msgNoticePage,
            Integer page,
            Integer size
    ) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        System.out.println("接口参数=="+msgNoticePage.toString());
        List<Map> mapLists=msgNoticeMapper.findByAll(msgNoticePage);
        return listPage.toPageInfo();
    }



    /**
     * 转换已读未读数据
     * @param map
     * @param userId
     */
    private void getInfo(Map map,String userId) {
        String type=map.get("TYPE").toString();
        String id=map.get("ID").toString();
        if("2".equals(type)){
            MsgNoticeUser msgNoticeUser= msgNoticeUserMapper.findByUserIdAndMsgId(userId, id);
            if(msgNoticeUser==null){
                map.put("STATUS","30");
                map.put("STATUS_VALUE","未读");
            }else{
                map.put("STATUS","40");
                map.put("STATUS_VALUE","已读");
            }
        }
    }


    /**
     * 信息报送---报送
     * @param publishVO
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public void publish(MsgNoticePublishVO publishVO) {
        MsgNotice msgNotice= msgNoticeMapper.selectByPrimaryKey(publishVO.getId());
        msgNotice.setUpdateTime(new Date());
        msgNotice.setUpdateBy(publishVO.getUpdateBy());
        msgNotice.setStatus(publishVO.getStatus());
        msgNoticeMapper.updateByPrimaryKey(msgNotice);
    }

    /**
     * 信息报送---批量采用
     * @param publishVO
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public void publishALL(MsgNoticePublishVO publishVO) {
        for(String id:publishVO.getIdsList()){
            MsgNotice msgNotice= msgNoticeMapper.selectByPrimaryKey(id);
            msgNotice.setUpdateTime(new Date());
            msgNotice.setUpdateBy(publishVO.getUpdateBy());
            msgNotice.setStatus(publishVO.getStatus());
            msgNoticeMapper.updateByPrimaryKey(msgNotice);
        }
    }



    /**
     * 信息报送---查询明细
     * @param
     * @return
     */
    @Override
    public MsgNoticeVO findById(String id) {
        MsgNotice msgNotice=  msgNoticeMapper.selectByPrimaryKey(id);
        MsgNoticeVO msgNoticeVO=LsBeanUtils.copyProperties(msgNotice, MsgNoticeVO.class);
        String publishTime=DateUtil.getDateFormat(msgNotice.getPublishTime(), DateUtil.df);
        msgNoticeVO.setPublishTime(publishTime);
        if(StringUtils.isNotEmpty(msgNotice.getFileId())){
            List<String> fileList= Arrays.asList(msgNotice.getFileId().split(","));
            msgNoticeVO.setFileId(fileList);
        }
        return msgNoticeVO;
    }


    /**
     * 信息报送----查看
     * @param id
     * @return
     */
    @Override
    public MsgNoticeVO findByInfo(String id) {
        MsgNotice msgNotice=  msgNoticeMapper.selectByPrimaryKey(id);
        MsgNoticeVO msgNoticeVO=LsBeanUtils.copyProperties(msgNotice, MsgNoticeVO.class);
        if(StringUtils.isNotEmpty(msgNotice.getFileId())){
            List<String> fileList= Arrays.asList(msgNotice.getFileId().split(","));
            msgNoticeVO.setFileId(fileList);
        }
        return msgNoticeVO;
    }




    /**
     * 保存读取数据
     * @param msgNoticeReadVO
     */
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    private void saveMsgNoticeUser(MsgNoticeReadVO msgNoticeReadVO) {
        MsgNoticeUser msgNoticeUser=new MsgNoticeUser();
        //创建时间
        msgNoticeUser.setCreateTime(new Date());
        msgNoticeUser.setUpdateTime(new Date());
        //创建人
        msgNoticeUser.setCreateBy(msgNoticeReadVO.getCreateBy());
        //行政区划
        msgNoticeUser.setAreaCode(msgNoticeReadVO.getAreaCode());
        //机构ID
        msgNoticeUser.setOrgId(msgNoticeReadVO.getOrgId());
        //部门ID
        msgNoticeUser.setDeptId(msgNoticeReadVO.getDeptId());
        msgNoticeUser.setStatus("40");
        msgNoticeUser.setUserId(msgNoticeReadVO.getUserId());
        msgNoticeUser.setMsgId(msgNoticeReadVO.getId());
        msgNoticeUserMapper.insertSelective(msgNoticeUser);
    }

    /**
     * 信息报送----修改d
     * @param msgNoticeUpdateVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean update(MsgNoticeUpdateVO msgNoticeUpdateVO) {
        MsgNotice msgNotice=  msgNoticeMapper.selectByPrimaryKey(msgNoticeUpdateVO.getMsgNoticeVO().getIds());
        //创建时间
        msgNotice.setUpdateTime(new Date());
        //机构ID
        msgNotice.setUpdateBy(msgNoticeUpdateVO.getUpdateBy());

        msgNotice.setTitle(msgNoticeUpdateVO.getMsgNoticeVO().getTitle());
        msgNotice.setYear(msgNoticeUpdateVO.getMsgNoticeVO().getYear());
        msgNotice.setContent(msgNoticeUpdateVO.getMsgNoticeVO().getContent());
        msgNotice.setStatus(msgNoticeUpdateVO.getMsgNoticeVO().getStatus());
        //上传文件
        if(msgNoticeUpdateVO.getMsgNoticeVO().getFileId()!=null && msgNoticeUpdateVO.getMsgNoticeVO().getFileId().size()>0){
            String fileList= StringUtils.join(msgNoticeUpdateVO.getMsgNoticeVO().getFileId(), ",");
            msgNotice.setFileId(fileList);
        }
        msgNoticeMapper.updateByPrimaryKeySelective(msgNotice);
        return true;
    }

    /**
     * 信息报送----删除
     * @param deleteVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public Boolean deletes(DeleteVO deleteVO) {
        for(int i=0;i<deleteVO.getIds().length;i++){
            String id=deleteVO.getIds()[i];
            MsgNotice msgNotice=msgNoticeMapper.selectByPrimaryKey(id);
            if(msgNotice!=null){
                msgNotice.setDeleteTime(new Date());
                msgNotice.setDeleteBy(deleteVO.getDeleteBy());
                msgNoticeMapper.updateByPrimaryKeySelective(msgNotice);
            }
        }
        return true;
    }



}